/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 02755
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1997
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE skpmartl  1='(1) Respondent is 12-14 years old - SKIP'
                  2='(2) Respondent is 15 years old or older'
                  3='(3) 12-14 years old LOGICALLY ASSIGNED - SKI'
                  4='(4) 15 years or older LOGICALLY ASSIGNED' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Never been married' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nomarr    85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpmilt   1='(1) Respondent is 12-16 years old - SKIP'
                  2='(2) Respondent is 17 years old or older'
                  3='(3) 12-16 years old LOGICALLY ASSIGNED - SKI'
                  4='(4) 17 years or older LOGICALLY ASSIGNED' ;
  VALUE service   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE milstat   2='(2) In a reserves component'
                  3='(3) Now separated or retired from reserves/a'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE educ      0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) Freshman/13th year'
                  14='(14) Sophomore/14th year' 15='(15) Junior/15th year'
                  16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diploma   1='(1) High School Diploma' 2='(2) GED Certificate'
                  3='(3) Neither of the above'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE enroll9f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  51='(51) School not in session (RAW QD12 = 1)'
                  52='(52) School not in session (RAW QD12 = 2)'
                  55='(55) School not in session (RAW QD12 > 2 OR M'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE enrl949f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  5='(5) School not in session (RAW QD12 NOT 2)'
                  11='(11) QD12 marked Yes but QD16 marked not en'
                  15='(15) School not in session (RAW QD12 = 2)'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job but out: illness/leave/furlou'
                  4='(4) Have a job, but it is seasonal'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed and not looking for work'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled, not able to work' 11='(11) Other, not specified'
                  21='(21) Working full-time, 35 hours or more a we'
                  22='(22) Working part-time, less than 35 hours a'
                  23='(23) Have a job but out: illness/leave/furlou'
                  24='(24) Have a job, but it is seasonal'
                  25='(25) Unemployed or laid off and looking for w'
                  26='(26) Unemployed and not looking for work'
                  27='(27) Full-time homemaker' 28='(28) In school only' 29='(29) Retired'
                  30='(30) Disabled, not able to work' 31='(31) Other, in labor force'
                  32='(32) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE htininch  985='(985) BAD DATA Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE pounds    985='(985) BAD DATA Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE health    1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigtry    981='(981) NEVER USED CIGARETTES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cigtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cig30use  35='(35) Date specified within the past 30 days'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES IN PAST 30 DAYS L'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE avcig     1='(1) At least a puff but less than one cig ea'
                  2='(2) 1 to 5 cigarettes each day'
                  3='(3) 6 to 15 cigarettes (about 1/2 pack) each'
                  4='(4) 16 to 25 cigarettes (about 1 pack) each'
                  5='(5) 26 to 35 cigarettes (about 1 1/2 pk) eac'
                  6='(6) 35 or more cigarettes (about 2 packs) ea'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES PAST 30 DAYS Log'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cig30wok  1='(1) 5 minutes or less' 2='(2) 6 to 30 minutes'
                  3='(3) 31 to 60 minutes' 4='(4) 1 to 3 hours' 5='(5) 4 or more hours'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES IN PAST 30 DAYS L'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigevyda  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigage    981='(981) NEVER USED CIGARETTES Logically assigned'
                  983='(983) NEVER USED CIGARETTES EVERYDAY Log assn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES'
                  993='(993) NEVER USED CIGARETTES EVERYDAY' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cigyrs    0='(0) I smoked cigs every day but only for < o'
                  981='(981) NEVER USED CIGARETTES Logically assigned'
                  983='(983) NEVER USED CIGARETTES EVERYDAY Log assn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES'
                  993='(993) NEVER USED CIGARETTES EVERYDAY' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE snufever  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE snufrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SMOKELESS TOBACCO Logically a'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpalcrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE alctry    981='(981) NEVER USED ALCOHOL Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED ALCOHOL'
                  994='(994) DONT KNOW' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcpat    1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned'
                  90='(90) HAD A DRINK BUT DID NOT GET DRUNK PST 12'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    0='(0) None' 35='(35) Date specified within the past 30 days'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT DRINK ALCOHOL IN PAST 30 DAYS Lo'
                  85='(85) BAD DATA Logically assigned'
                  90='(90) HAD A DRINK BUT NEVER MORE THAN 5 PAST 3'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjever    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE mjage     981='(981) NEVER USED MARIJUANA Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED MARIJUANA' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjyrfreq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjday30a  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpcocrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cocever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE cocage    981='(981) NEVER USED COCAINE Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED COCAINE'
                  994='(994) DONT KNOW' 995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocus30a  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpcrkrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE crkever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkage    981='(981) NEVER USED CRACK Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED CRACK'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE crktot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED CRACK Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED CRACK Logically assigned'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PAST 12 MONTHS Log a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crkus30a  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpherrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE herever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herage    981='(981) NEVER USED HEROIN Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED HEROIN'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  91='(91) NEVER USED HEROIN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE heryrfrq  1='(1) More than 300 days (every day or almost'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN PAST 12 MONTHS Log as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN IN PAST 30 DAYS Log a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skphalrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lsd       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (LSDREC=1,2,3,4 o'
                  4='(4) No LOGICALLY ASSIGNED (LSDREC=81 or 91)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (PCPREC=1,2,3,4 o'
                  4='(4) No LOGICALLY ASSIGNED (PCPREC=81 or 91)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE haldknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   142='(142) Belladona'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople'
                  240='(240) Lithium carbonate, lithonate' 267='(267) Marezine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  334='(334) Crossroads, cross tops'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  386='(386) Herbal ecstacy, ma huang' 415='(415) Codeine'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>' 459='(459) Ketamine'
                  501='(501) Gasoline or lighter fluids' 503='(503) Other aerosol sprays'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,r'
                  506='(506) Amyl nitrate, poppers, locker room odo'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  511='(511) Markers, felt-tip pens, ink pens'
                  520='(520) Old paint, paint' 524='(524) see also 509'
                  594='(594) Starting fluid'
                  601='(601) LSD (acid, white lightning) [see als'
                  604='(604) Psilocybin (mushrooms), shooms'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  612='(612) Happy stick, sherm, sherman, shermstick'
                  614='(614) MDA, Methylenedioxy amphetamine'
                  616='(616) DET, Dimethyltryptamine, DMT'
                  617='(617) Morning glory seeds, morning glory tandr'
                  622='(622) Microdot(s), purple microdot'
                  624='(624) Orange sunshine, sunshine, yellow sunshi'
                  625='(625) Window pane'
                  627='(627) Hawaiian wood rose, Hawaiian Woodrow see'
                  635='(635) Ginseng seeds, ginseng weed' 636='(636) STP'
                  639='(639) Cloves, Nutmeg' 640='(640) Purple pyramid' 646='(646) sic'
                  658='(658) Special K' 698='(698) Nexus, 2C-B' 703='(703) Opium'
                  802='(802) THC, cannabinol, marinol' 803='(803) sic'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ' 823='(823) sic'
                  847='(847) sic' 852='(852) sic' 885='(885) Drixoral <OTC>' 6003='(6003) Cocahina'
                  6004='(6004) Hallucinogen seeds' 6005='(6005) Sassafras tea'
                  6006='(6006) Super X' 6007='(6007) Bathtub' 6008='(6008) 8-Ball'
                  6010='(6010) Atrepabelladona (flower)' 6011='(6011) Natural herb'
                  6012='(6012) Cloud 9' 6013='(6013) Lions tail' 6014='(6014) Indo' 6016='(6016) Nas'
                  6017='(6017) Meesha' 6018='(6018) Air horn' 6019='(6019) Black duct'
                  6020='(6020) Chocolate' 6021='(6021) Snake bite kit (antivenom)'
                  6022='(6022) Tequila worm' 6023='(6023) Euphoria'
                  8001='(8001) Robitussin elixir'
                  9981='(9981) NEVER USED HALLUCINOGENS Logically assig'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewb   171='(171) NyQuil <OTC>' 459='(459) Ketamine' 502='(502) Spray paints'
                  503='(503) Other aerosol sprays'
                  505='(505) Lacquer thinner or other paint solvents'
                  508='(508) Nitrous oxide, whippets, dentist gas' 588='(588) Antifreeze'
                  602='(602) Peyote' 604='(604) Psilocybin (mushrooms), shooms'
                  616='(616) DET, Dimethyltryptamine, DMT'
                  622='(622) Microdot(s), purple microdot' 648='(648) Designer drugs'
                  658='(658) Special K'
                  663='(663) Animal tranquilizer, horse tranquilizer'
                  691='(691) Maximum impact' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  852='(852) sic' 863='(863) Beetlenut'
                  864='(864) Dramamine <OTC>, Motion sickness pill <O' 876='(876) Glass'
                  6015='(6015) Crysta' 6024='(6024) Blue Jesus'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewc   355='(355) Crystal meth' 503='(503) Other aerosol sprays'
                  601='(601) LSD (acid, white lightning) [see als'
                  624='(624) Orange sunshine, sunshine, yellow sunshi' 803='(803) sic'
                  3017='(3017) Dayquil <OTC>' 6025='(6025) Yellow jell'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewd   9991='(9991) NEVER USED HALLUCINOGENS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewe   9991='(9991) NEVER USED HALLUCINOGENS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE hallage   981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halyrfrq  1='(1) More than 300 days (every day/almost eve'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGENS PST 12 MOS Log'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGENS IN PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE lsdrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED LSD Logically assigned' 91='(91) NEVER USED LSD'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PCP Logically assigned' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpinhrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE amylnit   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gas       1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas      1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdknam  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  377='(377) Albuterol, Proventil, Ventolin'
                  501='(501) Gasoline or lighter fluids' 502='(502) Spray paints'
                  503='(503) Other aerosol sprays'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,r'
                  506='(506) Amyl nitrate, poppers, locker room odo'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  509='(509) Corr flds, degreasers, cleaning flds, Li'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, felt-tip pens, ink pens' 515='(515) Vicks'
                  516='(516) Freon' 518='(518) Acetone, nail polish remover' 519='(519) Helium'
                  520='(520) Old paint, paint' 524='(524) see also 509' 526='(526) Nail polish'
                  528='(528) Whipped-cream can'
                  530='(530) Asthma inhaler, asthma med., bronchial d'
                  539='(539) ScotchGard' 540='(540) PAM'
                  548='(548) Cologne, isopropanol vapors, rubbing alc' 551='(551) sic'
                  553='(553) Pixie sticks' 556='(556) Energine' 578='(578) sic'
                  589='(589) Tire shine' 590='(590) Canned air'
                  591='(591) Air brush propellent'
                  592='(592) Computer air duster, computer cleaner' 593='(593) sic'
                  594='(594) Starting fluid' 595='(595) Chlorine' 596='(596) Femo clay'
                  597='(597) Trichlorolnitrate' 599='(599) Potpourri'
                  691='(691) Maximum impact' 803='(803) sic'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  5001='(5001) Bleach' 5002='(5002) Dust X' 5003='(5003) Methane'
                  5005='(5005) Cobra rush' 6009='(6009) Sulfer match smoke' 6018='(6018) Air horn'
                  9981='(9981) NEVER USED INHALANTS Logically assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED INHALANTS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewb   503='(503) Other aerosol sprays'
                  511='(511) Markers, felt-tip pens, ink pens'
                  518='(518) Acetone, nail polish remover' 524='(524) see also 509'
                  526='(526) Nail polish'
                  592='(592) Computer air duster, computer cleaner'
                  598='(598) Ethylene dichloride' 691='(691) Maximum impact'
                  9981='(9981) NEVER USED INHALANTS Logically assigned'
                  9991='(9991) NEVER USED INHALANTS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewc   526='(526) Nail polish' 5004='(5004) Ink print'
                  9991='(9991) NEVER USED INHALANTS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewd   518='(518) Acetone, nail polish remover'
                  9991='(9991) NEVER USED INHALANTS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewe   9991='(9991) NEVER USED INHALANTS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhage    981='(981) NEVER USED INHALANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED INHALANTS' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpanlrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anlread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE codeine   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  105='(105) Placidyl' 109='(109) Seconal' 110='(110) Tuinal, rainbows'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 129='(129) Reds'
                  138='(138) sic' 161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople'
                  201='(201) Valium' 207='(207) Ativan' 209='(209) Xanax' 228='(228) see also 239'
                  234='(234) Cyclobenzaprine, Flexeril'
                  240='(240) Lithium carbonate, lithonate' 241='(241) Prozac'
                  246='(246) Clonopin, Klonopin' 265='(265) Black Caddy'
                  278='(278) Benzodiazepines' 301='(301) Dexedrine'
                  318='(318) Ritalin, Methylphenidate' 354='(354) Vivarin <OTC>'
                  390='(390) Max Alert' 401='(401) Darvon' 402='(402) Dolene' 404='(404) Wygesic'
                  417='(417) Morphine' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  421='(421) USED ANALGESIC, DONT KNOW NAME' 422='(422) Motrin'
                  423='(423) Percocet' 425='(425) Advil'
                  426='(426) Butalbital, Esgic, Fiorinal, Phrenilin F'
                  427='(427) Darvocet' 430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  431='(431) Tylox' 434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  435='(435) Tylenol, Tylenol Extra Strength <OTC>'
                  438='(438) Anaprox, Naprosyn, Naproxen' 440='(440) Soma'
                  442='(442) Ibuprofen'
                  456='(456) Lorcet HD, Lorcet Plus, Lortab [see also'
                  470='(470) Cafergot' 477='(477) Neo-Melubrina (Spanish)'
                  481='(481) Acular, Ketorolactromethamine, Toradol' 493='(493) IBU'
                  496='(496) Tramadol, Ultram' 499='(499) Aleve <OTC>' 658='(658) Special K'
                  663='(663) Animal tranquilizer, horse tranquilizer'
                  802='(802) THC, cannabinol, marinol' 820='(820) Penicillin'
                  864='(864) Dramamine <OTC>, Motion sickness pill <O'
                  899='(899) Bromphen' 3016='(3016) Claritin, loratadine'
                  4001='(4001) Actron, Ketoprofen, Orudis, Oruvail'
                  4002='(4002) Imitrex, sumatriptan' 4003='(4003) sic'
                  4005='(4005) Etodolac, Iodine' 4006='(4006) Action' 4007='(4007) Happy pills'
                  4010='(4010) sic' 4011='(4011) Carbamazepine, epital, tegretol'
                  4012='(4012) sic' 4013='(4013) Fenoprofen, nalfron'
                  4014='(4014) Akineton biperiden' 4015='(4015) sic' 4016='(4016) sic'
                  9981='(9981) NEVER USED PAIN KILLERS Logically assign'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewb  109='(109) Seconal' 110='(110) Tuinal, rainbows'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople' 201='(201) Valium'
                  209='(209) Xanax' 250='(250) Aventyl, Nortriptyline, Pamelor' 279='(279) sic'
                  318='(318) Ritalin, Methylphenidate' 405='(405) Levo-Dromoran'
                  415='(415) Codeine' 419='(419) Stadol' 422='(422) Motrin' 423='(423) Percocet'
                  425='(425) Advil' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  435='(435) Tylenol, Tylenol Extra Strength <OTC>' 440='(440) Soma'
                  459='(459) Ketamine' 499='(499) Aleve <OTC>'
                  894='(894) Depakene, Depakote, Valproic acid'
                  4008='(4008) Brown gel pills'
                  9981='(9981) NEVER USED PAIN KILLERS Logically assign'
                  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewc  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 431='(431) Tylox'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  4002='(4002) Imitrex, sumatriptan' 4004='(4004) sic' 4009='(4009) Smilies'
                  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewd  407='(407) Demerol' 440='(440) Soma' 9991='(9991) NEVER USED PAIN KILLERS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewe  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analage   981='(981) NEVER USED PAIN KILLERS Logically assign'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED PAIN KILLERS' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  83='(83) DID NOT USE PAIN KILLERS IN PST 12 MONTH'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS'
                  93='(93) DID NOT USE PAIN KILLERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skptrnrd  1='(1) Yes, I think resp can complete answer sh'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE atarax    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnolst   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    108='(108) Nembutal' 112='(112) Rasepam, Restoril, Temaz, Temazepam'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor' 138='(138) sic'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople'
                  171='(171) NyQuil <OTC>' 202='(202) Librium, Chlordiazepoxide HCL'
                  203='(203) Libritabs, Limbitrol, Mitran [see also 2' 207='(207) Ativan'
                  209='(209) Xanax' 211='(211) Buspar' 212='(212) Miltown' 214='(214) Deprol'
                  222='(222) USED TRANQUILIZER, DONT KNOW NAME'
                  225='(225) Desyrel, Trazodone hydrochloride, Trazor'
                  240='(240) Lithium carbonate, lithonate' 241='(241) Prozac'
                  246='(246) Clonopin, Klonopin' 271='(271) Zoloft'
                  276='(276) Limbitrol DS (chlordiazepoxide and amitr'
                  277='(277) Altut (Spanish)' 281='(281) Blue ringer'
                  282='(282) Clozapine, Clozaril' 283='(283) Paroxetine, Paxil'
                  318='(318) Ritalin, Methylphenidate' 362='(362) Benadryl'
                  423='(423) Percocet'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  438='(438) Anaprox, Naprosyn, Naproxen' 440='(440) Soma' 459='(459) Ketamine'
                  658='(658) Special K' 802='(802) THC, cannabinol, marinol'
                  811='(811) Muscle relaxers' 3009='(3009) CAT, Ephedrone, Methcathinone'
                  4015='(4015) sic' 9981='(9981) NEVER USED TRANQUILIZERS Logically assig'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewb    135='(135) Mini Thins'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople' 205='(205) Serax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  234='(234) Cyclobenzaprine, Flexeril'
                  240='(240) Lithium carbonate, lithonate' 246='(246) Clonopin, Klonopin'
                  280='(280) sic' 318='(318) Ritalin, Methylphenidate'
                  811='(811) Muscle relaxers'
                  9981='(9981) NEVER USED TRANQUILIZERS Logically assig'
                  9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewc    658='(658) Special K' 9991='(9991) NEVER USED TRANQUILIZERS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewd    9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewe    9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranage   981='(981) NEVER USED TRANQUILIZERS Logically assig'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED TRANQUILIZERS' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  83='(83) DID NOT USE TRANQUILIZERS PAST 12 MOS Lo'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpstmrd  1='(1) Yes, I think respondent can complete it'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE benz      1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  135='(135) Mini Thins'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople'
                  202='(202) Librium, Chlordiazepoxide HCL'
                  306='(306) Desoxyn, Methamphetamine hydrochloride'
                  307='(307) Tenuate, Diethylpropion' 308='(308) Tepanil, Diethylpropion'
                  313='(313) Adipex-P, Fastin, Phentermine hydrochlor'
                  315='(315) Voranil' 318='(318) Ritalin, Methylphenidate'
                  322='(322) Methamphetamine (speed or ice or cr'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty' 328='(328) Pink hearts'
                  329='(329) Bird eggs, robins eggs, speckled eggs'
                  331='(331) Blancas, Whites' 332='(332) see also 346'
                  333='(333) 357 Magnum, Magnum 44' 334='(334) Crossroads, cross tops'
                  335='(335) Dexatrim' 339='(339) Amphetamines (speed generically)'
                  344='(344) Bennies' 345='(345) Black Molly' 348='(348) Crystal' 349='(349) sic'
                  354='(354) Vivarin <OTC>' 355='(355) Crystal meth' 356='(356) Dexies'
                  359='(359) Criss cross' 374='(374) Christmas tree(s)'
                  377='(377) Albuterol, Proventil, Ventolin' 394='(394) Debs'
                  459='(459) Ketamine' 648='(648) Designer drugs'
                  805='(805) Cocaine, coca, coke' 814='(814) Caffeine' 824='(824) Steroids'
                  896='(896) Catapres, Clonidine' 3012='(3012) Stud 100, Stud the rock'
                  3013='(3013) Tweek' 3014='(3014) Uptime'
                  3015='(3015) Fen-Phen (fenfluramine and phentermine)'
                  3018='(3018) Up-johns' 3020='(3020) White powder' 4015='(4015) sic'
                  9981='(9981) NEVER USED STIMULANTS Logically assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  135='(135) Mini Thins' 307='(307) Tenuate, Diethylpropion'
                  318='(318) Ritalin, Methylphenidate' 326='(326) White cross'
                  329='(329) Bird eggs, robins eggs, speckled eggs'
                  332='(332) see also 346' 334='(334) Crossroads, cross tops'
                  339='(339) Amphetamines (speed generically)' 353='(353) No-Doz <OTC>'
                  374='(374) Christmas tree(s)'
                  601='(601) LSD (acid, white lightning) [see als'
                  3015='(3015) Fen-Phen (fenfluramine and phentermine)'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  306='(306) Desoxyn, Methamphetamine hydrochloride'
                  330='(330) Blue birds, blue jays, blue robins, spec'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewd  314='(314) Pondimin, Fenfluramine HCL'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewe  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimage   981='(981) NEVER USED STIMULANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED STIMULANTS' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) DID NOT USE STIMULANTS IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpsedrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dalmane   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   102='(102) Buticaps' 104='(104) Mebaral' 107='(107) Noludar'
                  112='(112) Rasepam, Restoril, Temaz, Temazepam'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  121='(121) USED SEDATIVE, DONT KNOW NAME' 126='(126) sic' 129='(129) Reds'
                  173='(173) Wafers' 174='(174) Ambien, Zolpidem' 175='(175) sic'
                  176='(176) Melatonin <OTC>' 218='(218) Diazepam'
                  225='(225) Desyrel, Trazodone hydrochloride, Trazor'
                  318='(318) Ritalin, Methylphenidate' 326='(326) White cross'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T' 440='(440) Soma'
                  811='(811) Muscle relaxers'
                  864='(864) Dramamine <OTC>, Motion sickness pill <O'
                  3019='(3019) Peppies' 4009='(4009) Smilies' 4015='(4015) sic'
                  9981='(9981) NEVER USED SEDATIVES Logically assigned'
                  9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewb   172='(172) Dream Ease <OTC>' 201='(201) Valium'
                  9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewc   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewd   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewe   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedage    981='(981) NEVER USED SEDATIVES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  83='(83) DID NOT USE SEDATIVES IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE birmonth  98='(98) BLANK (NO ANSWER)' ;
  VALUE biryear   9998='(9998) BLANK (NO ANSWER)' ;
  VALUE eibdate   1='(1) Birthdate established from questionnaire'
                  2='(2) Portions of birthdate logically imputed'
                  3='(3) Birthdate missing' ;
  VALUE iiage     1='(1) Age from birthdate' 2='(2) Age from cover of questionnaire'
                  3='(3) Age from roster'
                  4='(4) Age statistically imputed using age gr f' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from questionnaire'
                  2='(2) Sex from relationship on roster' 3='(3) Sex from roster' ;
  VALUE irrace    1='(1) American Indian or Alaskan native'
                  2='(2) Asian or Pacific islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Race from questionnaire'
                  2='(2) Race from interview observation' 3='(3) Race from roster'
                  4='(4) Race statis imputed using race - Other'
                  5='(5) Race statistically imputed, no infor. fr' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Nonhispanic' ;
  VALUE iihoind   1='(1) Hispanicity derived from questionnaire'
                  2='(2) Hispanicity derived from roster' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questio'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE irhogrpf  1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  5='(5) Central American' 6='(6) South American' 7='(7) Caribbean'
                  99='(99) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE iihogrpf  1='(1) Hispanic-Origin Group taken from questio'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Questionnaire data' 2='(2) Screener data'
                  4='(4) Statistically imputed data'
                  9='(9) Less than or equal to 14 years old' ;
  VALUE ireduc    0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) Freshman/13th year'
                  14='(14) Sophomore/14th year' 15='(15) Junior/15th year'
                  16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhsgrad  1='(1) Yes, graduated from high school'
                  2='(2) No, did not graduate from high school' ;
  VALUE iihsgrad  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job, but not at work, illness/mat'
                  4='(4) Have a job but not at work b/c it is sea'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed or laid off and not looking f'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled for work' 11='(11) Other, in labor force'
                  12='(12) Other, not in labor force' ;
  VALUE iiworkst  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used smokeless tobacco' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircrkrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used crack' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irlsdrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used LSD' ;
  VALUE iilsdrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtrnrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstmrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjfq    1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircrkfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week past year'
                  3='(3) Used 3-4 days per week past year'
                  4='(4) Used 1-2 days per week past year'
                  5='(5) Used 3-4 days per month past year'
                  6='(6) Used 1-2 days per month past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iicrkfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherfq   1='(1) Used daily in past year'
                  3='(3) Used 3-4 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iiherfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iihalfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinhfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iiinhfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iianlfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irtrnfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iitrnfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irstmfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iistmfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iisedfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE catag2ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26+ years' ;
  VALUE catag3ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35-49 years' 5='(5) 50+ years' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND = 2)' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Nonhispanic Black' 3='(3) Nonhispanic Nonblack' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=0-11 and I'
                  2='(2) High school graduate (IREDUC = 12 and IR'
                  3='(3) Some college (IREDUC = 13-15 and IRAGE ='
                  4='(4) College graduate (IREDUC = 16-17 and IRA'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE empstatf  1='(1) Full-time (IRWORKST = 1,3 and IRAGE => 1'
                  2='(2) Part-time (IRWORKST = 2 and IRAGE => 18)'
                  3='(3) Unemployed (IRWORKST = 4,5,6,11 and IRAG'
                  4='(4) Other (IRWORKST = 7,8,9,10,12 and IRAGE'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE businesf  992='(992) UNEMPLOYED/NOT CLASSIFIED BY INDUSTRY' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE roccup2f  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE maristat  1='(1) Married (IRMARIT=1)' 2='(2) Not Married (IRMARIT=2,3,4)'
                  3='(3) LEGITIMATE SKIP (IRMARIT=99)' ;
  VALUE notmar    1='(1) Never Married (IRMARIT=4)'
                  2='(2) Divorced/Separated or Widowed (IRMARIT=2'
                  3='(3) Married/Legitimate Skip (IRMARIT=1,99)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-4)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC ='
                  1='(1) Used within the past year (IRCIGRC = 1,2' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC ='
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE smkflag   0='(0) Never used (IROTBRC = 9)' 1='(1) Ever used (IROTBRC = 1-4)' ;
  VALUE smkyr     0='(0) Did not use in the past year (IROTBRC ='
                  1='(1) Used within the past year (IROTBRC = 1,2' ;
  VALUE smkmon    0='(0) Did not use in the past month (IROTBRC ='
                  1='(1) Used within the past month (IROTBRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-4)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC ='
                  1='(1) Used within the past year (IRALCRC = 1,2' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC ='
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-4)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 3'
                  1='(1) Used within the past year (IRMJRC = 1,2)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC ='
                  1='(1) Used within the past month (IRMJRC = 1)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-4)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC ='
                  1='(1) Used within the past year (IRCOCRC = 1,2' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC ='
                  1='(1) Used within the past month (IRCOCRC = 1)' ;
  VALUE crkflag   0='(0) Never used (IRCRKRC = 9)' 1='(1) Ever used (IRCRKRC = 1-4)' ;
  VALUE crkyr     0='(0) Did not use in the past year (IRCRKRC= 3'
                  1='(1) Used within the past year (IRCRKRC = 1,2' ;
  VALUE crkmon    0='(0) Did not use in the past month (IRCRKRC ='
                  1='(1) Used within the past month (IRCRKRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-4)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC ='
                  1='(1) Used within the past year (IRHERRC = 1,2' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC ='
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-4)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC ='
                  1='(1) Used within the past year (IRHALRC = 1,2' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC ='
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE lsdflag   0='(0) Never used (IRLSDRC = 9)' 1='(1) Ever used (IRLSDRC = 1-4)' ;
  VALUE lsdyr     0='(0) Did not use in the past year (IRLSDRC ='
                  1='(1) Used within the past year (IRLSDRC = 1,2' ;
  VALUE lsdmon    0='(0) Did not use in the past month (IRLSDRC ='
                  1='(1) Used within the past month (IRLSDRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-4)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC ='
                  1='(1) Used within the past year (IRPCPRC = 1,2' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC ='
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE inhflag   0='(0) Never used (IRINHRC = 9)' 1='(1) Ever used (IRINHRC = 1-4)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC ='
                  1='(1) Used within the past year (IRINHRC = 1,2' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC ='
                  1='(1) Used within the past month (IRINHRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-4)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC ='
                  1='(1) Used within the past year (IRANLRC = 1,2' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC ='
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-4)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC ='
                  1='(1) Used within the past year (IRTRNRC = 1,2' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC ='
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-4)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC ='
                  1='(1) Used within the past year (IRSTMRC = 1,2' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC ='
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-4)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC ='
                  1='(1) Used within the past year (IRSEDRC = 1,2' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC ='
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRA'
                  1='(1) Any use within the past year (IRALCFQ=1-' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRAL'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE alcwkf    0='(0) Did not use weekly or more pst year (IRA'
                  1='(1) Used weekly or more in past year (IRALCF' ;
  VALUE alcoccf   0='(0) Used monthly/more or none pst yr (IRALCF'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE alcdlyf   0='(0) Did not use daily/almost dly pst yr(IRAL'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRMJFQ=1-9' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJ'
                  1='(1) Used monthly or more in past year (IRMJF' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJF'
                  1='(1) Used weekly or more in past year (IRMJFQ' ;
  VALUE mrjoccf   0='(0) Used monthly/more or none in pst yr(IRMJ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE mrjdlyf   0='(0) Did not use daily/almost daily pst yr(IR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE cocyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRCOCFQ =' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCO'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE cocwkf    0='(0) Did not use weekly or more pst year (IRC'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE cococcf   0='(0) Used monthly/more or none in pst yr(IRCO'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE cocdlyf   0='(0) Did not use daily/almost dly pst yr(IRCO'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE crkyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRCRKFQ =' ;
  VALUE crkmonf   0='(0) Did not use monthly/more past year (IRCR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE crkwkf    0='(0) Did not use weekly or more pst year (IRC'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE crkoccf   0='(0) Used monthly/more or none in pst yr(IRCR'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE crkdlyf   0='(0) Did not use daily/almost dly pst yr(IRCR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE heryrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRHERFQ=1-' ;
  VALUE hermonf   0='(0) Did not use monthly/more past year (IRHE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE herwkf    0='(0) Did not use weekly or more pst year (IRH'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE heroccf   0='(0) Used monthly/more or none pst yr(IRHERFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE herdlyf   0='(0) Did not use daily/almost daly pst yr(IRH'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE halyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRHALFQ=1-' ;
  VALUE halmonf   0='(0) Did not use monthly/more past year (IRHA'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE halwkf    0='(0) Did not use weekly or more pst year (IRH'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE haloccf   0='(0) Used monthly/more or none pst yr(IRHALFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE haldlyf   0='(0) Did not use daily/almost dly pst yr(IRHA'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE inhyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRINHFQ=1-' ;
  VALUE inhmonf   0='(0) Did not use monthly/more past year (IRIN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE inhwkf    0='(0) Did not use weekly or more pst year (IRI'
                  1='(1) Used weekly or more often past year (IRI' ;
  VALUE inhoccf   0='(0) Used monthly/more or none pst yr(IRINHFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE inhdlyf   0='(0) Did not use daily/almost dly pst yr(IRIN'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE anlyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRANLFQ=1-' ;
  VALUE anlmonf   0='(0) Did not use monthly/more past year (IRAN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE anlwkf    0='(0) Did not use weekly or more pst year (IRA'
                  1='(1) Used weekly or more often past year (IRA' ;
  VALUE anloccf   0='(0) Used monthly/more or none pst yr(IRANLFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE anldlyf   0='(0) Did not use daily/almost dly pst yr(IRAN'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE trqyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRTRNFQ=1-' ;
  VALUE trqmonf   0='(0) Did not use monthly/more past year (IRTR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE trqwkf    0='(0) Did not use weekly or more pst year (IRT'
                  1='(1) Used weekly or more often past year (IRT' ;
  VALUE trqoccf   0='(0) Used monthly/more or none pst yr(IRTRNFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE trqdlyf   0='(0) Did not use daily/almost dly pst yr(IRTR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE stmyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRSTMFQ=1-' ;
  VALUE stmmonf   0='(0) Did not use monthly/more past year (IRST'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE stmwkf    0='(0) Did not use weekly or more pst year (IRS'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE stmoccf   0='(0) Used monthly/more or none in pst yr(IRST'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE stmdlyf   0='(0) Did not use daily/almost dly pst yr(IRST'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE sedyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRSEDFQ=1-' ;
  VALUE sedmonf   0='(0) Did not use monthly/more past year (IRSE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE sedwkf    0='(0) Did not use weekly or more pst year (IRS'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE sedoccf   0='(0) Used monthly/more or none pst yr(IRSEDFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE seddlyf   0='(0) Did not use daily/almost dly pst yr(IRSE'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE'
                  1='(1) Used in past year (ANY SOURCE VARIABLE <' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VAR'
                  1='(1) Used in past year (ANY SOURCE VARIABLE =' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anothr'
                  1='(1) Marijuana is only (illicit) drug ever us' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug'
                  1='(1) Marijuana is only (illicit) drug in past' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr dr'
                  1='(1) Marijuana only (illicit) drug in past mo' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ev' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE bingedrk  0='(0) Never/No Binge ALC use (DR5DAY=0,81,83'
                  1='(1) Binge alcohol use (DR5DAY = 1-30)'
                  99='(99) Unknown (DR5DAY = 85,94,95,98)' ;
  VALUE hvydrk2f  0='(0) Never/No hvy ALC use(DR5DAY=0-4,35,81,83'
                  1='(1) Heavy alcohol use (DR5DAY = 5-30)'
                  99='(99) Unknown (DR5DAY = 85,94,95,98)' ;
  VALUE bingehvy  1='(1) Heavy alcohol use'
                  2='(2) Binge alcohol use but not heavy use'
                  3='(3) Past 30 day alcohol use but not binge'
                  4='(4) Did not use alcohol in the past 30 days' 99='(99) Unknown' ;
  VALUE peyote2f  0='(0) No/Unknown (PEYOTE=2,81,91,98)' 1='(1) Yes (PEYOTE=1)' ;
  VALUE mesc2fff  0='(0) No/Unknown (MESC=2,81,91,98)' 1='(1) Yes (MESC=1)' ;
  VALUE psilcy2f  0='(0) No/Unknown (PSILCY=2,81,91,98)' 1='(1) Yes (PSILCY=1,3)' ;
  VALUE ecstasyf  0='(0) No/Unknown (ECSTASY=2,81,91,98)' 1='(1) Yes (ECSTASY=1)' ;
  VALUE methampf  0='(0) No/Unknown (METHAMP=2,81,91,97,98)'
                  1='(1) Yes (METHAMP=1,3)' ;
  VALUE amylnitf  0='(0) No/Unknown (AMYLNIT=2,81,91,98)' 1='(1) Yes (AMYLNIT=1,3)' ;
  VALUE cleflu2f  0='(0) No/Unknown (CLEFLU=2,81,91,98)' 1='(1) Yes (CLEFLU=1,3)' ;
  VALUE gas2ffff  0='(0) No/Unknown (GAS=2,81,91,98)' 1='(1) Yes (GAS=1)' ;
  VALUE glue2fff  0='(0) No/Unknown (GLUE=2,81,91,98)' 1='(1) Yes (GLUE=1,3)' ;
  VALUE ether2ff  0='(0) No/Unknown (ETHER=2,81,91,98)' 1='(1) Yes (ETHER=1)' ;
  VALUE solventf  0='(0) No/Unknown (SOLVENT=2,81,91,98)' 1='(1) Yes (SOLVENT=1)' ;
  VALUE lgas2fff  0='(0) No/Unknown (LGAS=2,81,91,98)' 1='(1) Yes (LGAS=1)' ;
  VALUE nitoxidf  0='(0) No/Unknown (NITOXID=2,81,91,98)' 1='(1) Yes (NITOXID=1,3)' ;
  VALUE sppaintf  0='(0) No/Unknown (SPPAINT=2,81,91,98)' 1='(1) Yes (SPPAINT=1)' ;
  VALUE aeros2ff  0='(0) No/Unknown (AEROS=2,81,91,98)' 1='(1) Yes (AEROS=1,3)' ;
  VALUE mjdy30af  1='(1) 1-2 Days (MJDAY30A = 1-2)' 2='(2) 3-4 Days (MJDAY30A = 3-4)'
                  3='(3) 5-19 Days (MJDAY30A = 5-19)'
                  4='(4) 20-30 Days (MJDAY30A = 20-30)'
                  5='(5) None/Never used MRJ (MJDAY30A = 35,81,83'
                  6='(6) Unknown (MJDAY30A = 85,95,98)' ;
  VALUE cg04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cg12ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE al03ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE al04ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mj04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  91='(91) NEVER USED MARIJUANA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mj05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cc04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED COCAINE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cc05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) NEVER USED COCAINE Logically assigned'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ck04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CRACK' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ck05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE he04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE he05ffff  1='(1) More than 300 days (every day or almost'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls05ffff  1='(1) More than 300 days (every day/almost eve'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than 1 day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls07ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  91='(91) NEVER USED LSD' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls08ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  91='(91) NEVER USED PCP' 98='(98) BLANK (NO ANSWER)' ;
  VALUE in04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE in05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pk04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pk05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE PAIN KILLERS IN THE PAST 12' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tr04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tr05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE st04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE se04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically Assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE se05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpsdrd   1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sdread    1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hranyfrm  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hersmoke  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hrsmkrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  83='(83) USED HEROIN BUT NEVER SMOKED IT Logicall'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN'
                  93='(93) USED HEROIN BUT NEVER SMOKED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hersniff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hrsnfrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  83='(83) USED HEROIN BUT NEVER SNIFFED IT Log ass'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN'
                  93='(93) USED HEROIN BUT NEVER SNIFFED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE gnndllif  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocneedl  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  83='(83) USED COCAINE BUT NEVER WITH A NEEDLE Log'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE condlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) USED COCAINE BUT NEVER WITH A NEEDLE Log'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE herneedl  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE hrndlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE stneedle  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) USED STIMULANTS BUT NEVER WITH A NEEDLE'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) USED STIMULANTS BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE stndlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) USED STIMULANTS BUT NEVER WITH A NEEDLE'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) USED STIMULANTS BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndreus  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndlshf  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndclen  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndls0f  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndget   1='(1) I bought the needle from a pharmacy'
                  2='(2) I got the needle from a needle exchange'
                  3='(3) I bought the needle on the street'
                  4='(4) I got the needle in a shooting gallery'
                  5='(5) I got the needle some other way'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndgtsp  6='(6) Given by, stolen from a friend'
                  7='(7) Given by, stolen from a relative'
                  8='(8) Given by, stolen from someone, relation'
                  9='(9) Came with drugs'
                  11='(11) I bought the needle from a pharmacy'
                  15='(15) Given by, stolen from medical facility/p'
                  18='(18) Bought, given, stolen from place/locatio'
                  20='(20) Given by, stolen from athletic trainer/c'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE skprskrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrylsd  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rklsdreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskdifmj  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdiflsd  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcoc  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcrk  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifher  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rsksell   1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqdngr  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqrsky  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqpblt  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqdblt  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  91='(91) I dont drive' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpdrgrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drgread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE usedcig   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedmrj   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedcoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedher   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedhal   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedinh   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedanl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedtrn   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedstm   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedsed   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nodrugyr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE grtmcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtminh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamther   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamthal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamttrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btoltrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdcig    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdalc    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdmrj    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdcoc    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdher    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdhal    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdinh    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdanl    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdtrn    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdstm    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdsed    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE skpsptrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt it alo'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sptread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxrcvd  1='(1) Yes' 2='(2) No' 5='(5) Yes (NDTXNEED=YES) LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ndtxneed  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXRCVD=1)'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXRCVD=1)' ;
  VALUE ndtxalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxmj    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxcoc   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxher   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxhal   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxinh   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxanl   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtran  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxstim  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsed   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsod   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxdrgf  322='(322) Methamphetamine (speed or ice or cr' 348='(348) Crystal'
                  355='(355) Crystal meth'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr0f  339='(339) Amphetamines (speed generically)' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr1f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr2f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr3f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxstep  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtrsp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtfar  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxbdhr  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxopen  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtype  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxmony  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxhcap  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtcmp  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxlang  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxspsv  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsor   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxrscf  5='(5) Programs did not offer what I wanted'
                  12='(12) Did not need it'
                  14='(14) Do not want to (quit/get treatment)'
                  15='(15) Was using at the time/not ready/unmotiva'
                  16='(16) Can do it myself'
                  17='(17) Do not know where to go/did not look for'
                  18='(18) Do not use/infrequently use drugs and al'
                  19='(19) Lack of time'
                  20='(20) Shame/wanted to hide problem (from paren'
                  22='(22) Conflict with spouse'
                  23='(23) Only smoke cigs/not ready to quit smokin'
                  24='(24) Can do it with the support of my family/'
                  27='(27) No one cares'
                  28='(28) I have problems in addition to alcohol/d'
                  29='(29) Too heavy a user to seek treatment at th'
                  30='(30) Completed treatment in the past, success'
                  31='(31) No specific reason' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE booked    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nobookyr  83='(83) NOT BEEN ARRSTD & BKD PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (BOOK'
                  93='(93) NOT ARRESTED AND BOOKED PAST 12 MONTHS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (BOOKED=2)' ;
  VALUE bklarcny  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkburgl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkagaslt  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bksmaslt  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkmvthft  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkrob     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkrape    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkmurder  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkarson   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrvinf  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrunk   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrug    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkpros    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkvandal  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkoth     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkothoff  1='(1) Larceny or theft' 2='(2) Burglary or breaking and entering'
                  3='(3) Aggravated assault'
                  4='(4) Other assault, such as simple assault or'
                  5='(5) Motor vehicle theft' 6='(6) Robbery' 7='(7) Forcible rape'
                  9='(9) Arson' 10='(10) Driving under the influence'
                  11='(11) Drunkenness or other liquor law violatio'
                  12='(12) Possession or sale of drugs'
                  14='(14) Oth proprty offns:- fraud, poss stln goo'
                  16='(16) Weapons offenses'
                  18='(18) Violation of court order, parole, probat'
                  19='(19) Public order offenses' 20='(20) Juvenile status offenses'
                  21='(21) Other offenses, not elsewhere classified'
                  22='(22) Traffic violations' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE probaton  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE parole    1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drvaldr   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE driveal   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drivedr   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skptmtrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tmtread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE txever    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE txstrtlf  975='(975) Indicated treatment received at least on'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned (TXEV'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txstrtyr  0='(0) None' 975='(975) Indicated treatment received at least on'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned (TXEV'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalhosp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTHOSP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalrfin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFIN'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalrfop  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalmhc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTMHC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalemrg  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txaldoc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTDOC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txaljail  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalshg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSHG'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  10='(10) Church or religious influence' 12='(12) Friends'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 18='(18) Homeless shelter' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center' 26='(26) Self-help group'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrhosp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTHOSP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrfin   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFIN'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrfop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrmhc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTMHC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdremrg  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTEMRG or'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrdoc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTDOC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrjail  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTJAIL'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrshg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSHG'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  9='(9) Within myself (self-treatment)'
                  10='(10) Church or religious influence' 12='(12) Friends'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 18='(18) Homeless shelter'
                  20='(20) Camp/Outward Bound Program' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center' 26='(26) Self-help group'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txyremrg  0='(0) None' 985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned (TXEV'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txadgrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Treatment in past year LOGICALLY ASSIGNE'
                  9='(9) Treatment in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED ALCOHOL OR DRUGS Logically as'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  91='(91) NEVER USED ALCOHOL OR DRUGS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlthosp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltrfin  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltrfop  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltmhc   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltemrg  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltdoc   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltjail  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltshg   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsop   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  9='(9) Within myself (self-treatment)'
                  10='(10) Church or religious influence' 12='(12) Friends'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 18='(18) Homeless shelter'
                  19='(19) Alternative medicine' 20='(20) Camp/Outward Bound Program'
                  22='(22) Hospital' 24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltmj    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltcoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlther   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlthal   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltinh   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltanl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltran   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltstim  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsed   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsod   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Treatment drug unknown, LOGICALLY ASSIGN'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlta     247='(247) Adapin, Doxepin, Sinequan'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 415='(415) Codeine' 606='(606) sic'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coca, coke'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  9900='(9900) Not a drug' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltb     229='(229) Librax' 321='(321) Methedrine' 806='(806) Crack, rock'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltc     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltd     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txlte     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrga    103='(103) Amytal' 120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  207='(207) Ativan' 209='(209) Xanax'
                  250='(250) Aventyl, Nortriptyline, Pamelor'
                  318='(318) Ritalin, Methylphenidate'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  501='(501) Gasoline or lighter fluids'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  604='(604) Psilocybin (mushrooms), shooms'
                  605='(605) PCP (angel dust, phencyclidine)' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coca, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  899='(899) Bromphen' 9900='(9900) Not a drug' 9995='(9995) BAD DATA'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgb    201='(201) Valium' 284='(284) Tofranil' 321='(321) Methedrine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED' 348='(348) Crystal'
                  355='(355) Crystal meth' 423='(423) Percocet'
                  601='(601) LSD (acid, white lightning) [see als' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coca, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgc    348='(348) Crystal' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  805='(805) Cocaine, coca, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgd    606='(606) sic' 803='(803) sic' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrge    9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txoutc    1='(1) Still in treatment' 2='(2) Successfully completed treatment'
                  3='(3) Had a problem with program'
                  4='(4) Couldnt afford to continue treatment'
                  5='(5) Family needed me' 6='(6) Began using drug(s) again'
                  7='(7) Other outcome, not specified' 8='(8) Didnt need treatment'
                  10='(10) Successful because of own efforts, not t'
                  12='(12) Kicked out of program' 13='(13) Moved'
                  14='(14) Successful because of religious reasons'
                  15='(15) Discontinued treatment, success unknown'
                  16='(16) Completed treatment, outcome unknown'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txtime    0='(0) None' 9975='(9975) Indicated treatment received at least on'
                  9989='(9989) LEGITIMATE SKIP Logically assigned (TXEV'
                  9994='(9994) DONT KNOW' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdins   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdcare  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdcaid  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsave  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdfmly  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdempl  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdfree  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsos   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes, payment source not specified LOGICA'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsp    1='(1) Health Insurance' 2='(2) Own savings or earnings'
                  3='(3) Family member' 6='(6) Free' 8='(8) Friend/Sponsor'
                  9='(9) State/city public assistance/welfare/rel' 10='(10) Court'
                  11='(11) Church' 12='(12) School' 13='(13) Hospital'
                  14='(14) Veterans administration/military service'
                  16='(16) Indian Health Service' 17='(17) Social Security'
                  19='(19) Medicare' 21='(21) Bartered Services'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txenroll  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE skpwrkrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wrkread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wkevracc  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wkyracc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wkyrtest  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wk30acc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wk30test  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wkyrvol   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wkyrfire  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wkyrloff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wkyrothr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wkyrspec  1='(1) Fired' 2='(2) Permanently laid off'
                  4='(4) Better job/pay/benefits/opportunities'
                  5='(5) New job/career change' 6='(6) Union/labor dispute'
                  7='(7) Too few hours/poor pay/lack of benefits'
                  8='(8) Too demanding'
                  9='(9) Family and child care responsibilities'
                  10='(10) Personal or domestic problems'
                  11='(11) Transportation problems'
                  12='(12) Health reasons/accident/injury unascribe'
                  13='(13) Bus. closed/bankruptcy/relocated/reorgan'
                  14='(14) Communication problems/conflicts at work'
                  15='(15) Sexual harassment/racism' 16='(16) Seasonal/short-term job'
                  17='(17) Temporary agency/temporary job'
                  18='(18) Job locale was too far from home'
                  19='(19) Moved away from area/job' 20='(20) Temporary lay off'
                  21='(21) Pregnancy/maternity-related reasons'
                  22='(22) Job-related injury/workmans compensatio'
                  23='(23) Self-employed'
                  24='(24) Student/interfered wth schl activities o'
                  25='(25) Alcohol/drug abuse' 26='(26) Criminal/legal problems'
                  27='(27) Voluntarily left/quit/resigned'
                  28='(28) Not old enough to work'
                  29='(29) Unemployed/have not worked past 12 month'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpdexrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxversn   1='(1) Yes (Type 19A)' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dxcgrlf   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dxcg50lf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxcg30us  0='(0) None' 35='(35) Date specified within the past 30 days'
                  83='(83) DID NOT USE CIGARS IN THE PAST 30 DAYS L'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT USE CIGARS IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjoffr  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dxmjever  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dxmjpaln  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and >=1 other response'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpsps  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpfrn  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpmet  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpsib  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpdad  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpmom  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjprel  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpsop  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXMJPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjpsp   84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  91='(91) Other Non-Relative, Gender not specified'
                  181='(181) Other Male God Relative' 191='(191) Other Male Non-Relative'
                  291='(291) Other Female Non-Relative'
                  384='(384) Neighbors/Co-Workers/Visitors/Employees/'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified'
                  600='(600) Teacher(s)' 605='(605) Police/law enforcement'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dxmjpnr   10='(10) BOY/GIRLFRIEND OF PARENT'
                  11='(11) OTHER FRIEND(S) OF PARENT(S)'
                  12='(12) BOY/GIRLFRIEND OF SIBLING(S)'
                  13='(13) OTHER FRIEND(S) OF SIBLING(S)'
                  14='(14) IN-LAW(S) OF SIBLING(S)' 15='(15) FRIEND(S) OF FAMILY'
                  16='(16) FRIEND(S) OF OTHER RELATIVE(S)'
                  20='(20) FRIEND(S) OF SPOUSE'
                  21='(21) SIBLING(S) OF BOY/GIRLFRIEND/EX'
                  22='(22) FRIEND(S) OF BOY/GIRLFRIEND/EX'
                  30='(30) PARENT(S) OF FRIEND(S)' 31='(31) SIBLING(S) OF FRIEND(S)'
                  32='(32) FRIEND(S) OF FRIEND(S)' 40='(40) MANAGER/BOSS/EMPLOYER'
                  41='(41) EMPLOYEE(S)/SUPERVISEE(S)'
                  42='(42) CO-WORKER(S), RELATIONSHIP UNSPECIFIED'
                  50='(50) NEIGHBOR(S)' 51='(51) FAMILY MEMBER(S) OF NEIGHBOR'
                  60='(60) PARTY/COLLEGE PARTY' 61='(61) OTHER SCHOOL-RELATED'
                  62='(62) IN THE MILITARY' 63='(63) IN A GROUP, PARTY NOT SPECIFIED'
                  70='(70) BABYSITTER' 71='(71) CASUAL ACQUAINTANCE(S)'
                  72='(72) DRUG DEALER' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE dxmjfsee  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjffgd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjffrn  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjfsps  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjfesc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjfnew  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjfreb  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjfsor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjfsp   9='(9) Thought it would be fun/exciting'
                  10='(10) Pressured by others/afraid to say no'
                  11='(11) To be cool/to be with the in crowd'
                  12='(12) My parent(s) offered it to me/my parent('
                  13='(13) My sibling(s) offered it to me/my siblin'
                  14='(14) Forced to use against will'
                  15='(15) Other outside influence'
                  16='(16) For physical/medical reasons'
                  17='(17) To relax/sleep/relieve stress'
                  18='(18) To keep awake/give me energy' 19='(19) For sexual reasons'
                  20='(20) Enlightenment/spiritual reasons' 21='(21) Liked the smell'
                  22='(22) To replace another drug/enhance a drug h'
                  24='(24) Under the influence of another drug'
                  25='(25) Unaware I was using it/deception'
                  26='(26) I was young/stupid/didnt know better'
                  27='(27) It just happened/it was available/normal'
                  28='(28) To get it over with' 29='(29) Always around it'
                  30='(30) Did not think it was as dangerous as oth'
                  32='(32) As part of a special occasion'
                  33='(33) Used it to get rid of it'
                  34='(34) I wanted to prove that it is harmful'
                  35='(35) Because I wanted to/just felt like it'
                  36='(36) Part of a dare/bet' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjyr    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjyfrn  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjysps  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjyesc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjyrlx  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjydrs  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjydrx  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjyrlf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjysor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjysp   9='(9) Experimenting/curiosity'
                  10='(10) Because I wanted to/just felt like it'
                  11='(11) It was there' 12='(12) Influenced by others'
                  13='(13) Its fun/I like it/I like the way it mak'
                  14='(14) Partying/to enhance an experience'
                  15='(15) Celebrating/special occasion'
                  16='(16) Enlightenment/spiritual reasons'
                  17='(17) I like the way it smells'
                  18='(18) Im addicted/it is a habit' 19='(19) Bored'
                  20='(20) To give me energy' 21='(21) Increase my appetite'
                  22='(22) Unaware I was using it/deception'
                  23='(23) To replace another drug/enhance a drug h'
                  24='(24) Under the influence of another drug/alco'
                  26='(26) Good for you' 27='(27) Prefer it over other drugs'
                  29='(29) To remind myself why I had stopped using'
                  30='(30) To be cool/be with the in crowd'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjretf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdni   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdphy  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdsck  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdblf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdtst  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdpsy  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjddgs  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdadd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdprg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdkid  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdpar  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdsps  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdfrn  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdcos  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdget  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjddlr  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdigl  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdcrm  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdsor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjdsp   20='(20) It is stupid/dumb' 21='(21) It is disgusting'
                  22='(22) I dont use drugs anymore/I am drug-free'
                  23='(23) Dont like it/I dont like its effect'
                  24='(24) Would interfere with medical care'
                  25='(25) I enjoy life without drugs/happy without'
                  26='(26) Self-respect/want to be my best/in contr'
                  27='(27) People just use it to cover up/hide from'
                  28='(28) Drugs are the downfall of society'
                  29='(29) Ive seen what it could do to family mem'
                  30='(30) Ive seen what it could do to friends/no'
                  32='(32) Could interfere w/ job/career/sports/sch'
                  33='(33) Could hurt others/those around me'
                  34='(34) No benefit to me/too much to lose/would'
                  35='(35) Have too many responsibilities/need to s'
                  36='(36) Afraid to use anymore/not sure what woul'
                  38='(38) On probation/could get in trouble'
                  39='(39) Have not had the opportunity to use'
                  40='(40) Matured out of it/too old now'
                  42='(42) Do not want to support other countries'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjre0f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnni   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnphy  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnlik  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnblf  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjntst  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnpsy  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjndgs  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnadd  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnprg  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnkid  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnpar  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnsps  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnfrn  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjncos  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnget  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjndlr  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnigl  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjncrm  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnsor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjnsp   20='(20) It is stupid/dumb' 21='(21) It is disgusting'
                  22='(22) I just dont use drugs/not the type who'
                  23='(23) Dont like it/makes me sick'
                  24='(24) Would interfere with medical care'
                  25='(25) I enjoy life without drugs/happy without'
                  26='(26) Self-respect/want to be my best/in contr'
                  27='(27) People just use it to cover up/hide from'
                  28='(28) Drugs are the downfall of society'
                  29='(29) Ive seen what it could do to family mem'
                  30='(30) Ive seen what it could do to friends/no'
                  31='(31) Hate it/could ruin my life/bad/dangerous'
                  32='(32) Could interfere w/ job/career/sports/sch'
                  33='(33) Could hurt others/those around me'
                  34='(34) No benefit to me/too much to lose/would'
                  35='(35) Have too many responsibilities/need to s'
                  36='(36) Afraid to use/not sure what would happen'
                  37='(37) Could lead to other criminal activity/be'
                  38='(38) Not old enough to use yet'
                  39='(39) Never had the opportunity to use'
                  40='(40) Too old now/experimental days in the pas'
                  41='(41) Dont know anything about it' 44='(44) It is unnatural'
                  45='(45) TV, radio and newspaper ads'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccoffr  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dxccever  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dxccpaln  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and >=1 other response'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpsps  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpfrn  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpmet  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpsib  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpdad  6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpmom  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccprel  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpsop  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and DXCCPALN marked)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccpsp   84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  191='(191) Other Male Non-Relative'
                  384='(384) Neighbors/Co-Workers/Visitors/Employees/'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified'
                  610='(610) Doctor(s)/nurse(s)/health care professio'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) BLEGITIMATE SKIP' ;
  VALUE dxccpnr   10='(10) BOY/GIRLFRIEND OF PARENT'
                  13='(13) OTHER FRIEND(S) OF SIBLING(S)'
                  30='(30) PARENT(S) OF FRIEND(S)' 31='(31) SIBLING(S) OF FRIEND(S)'
                  41='(41) EMPLOYEE(S)/SUPERVISEE(S)'
                  42='(42) CO-WORKER(S), RELATIONSHIP UNSPECIFIED'
                  61='(61) OTHER SCHOOL-RELATED' 64='(64) PEOPLE AT A CONCERT'
                  71='(71) CASUAL ACQUAINTANCE(S)' 72='(72) DRUG DEALER' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dxccfsee  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccffgd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccffrn  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccfsps  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccfesc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccfnew  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccfreb  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccfsor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccfsp   9='(9) Thought it would be fun/exciting'
                  10='(10) Pressured by others/afraid to say no'
                  11='(11) To be cool/to be with the in crowd'
                  12='(12) My parent(s) offered it to me/my parent('
                  13='(13) My sibling(s) offered it to me/my siblin'
                  14='(14) Forced to use against will'
                  15='(15) Other outside influence'
                  16='(16) For physical/medical reasons'
                  18='(18) To keep awake/give me energy' 19='(19) For sexual reasons'
                  21='(21) Liked the smell'
                  22='(22) To replace another drug/enhance a drug h'
                  23='(23) To counteract another drugs effects'
                  24='(24) Under the influence of another drug'
                  25='(25) Unaware I was using it/deception'
                  26='(26) I was young/stupid/didnt know better'
                  27='(27) It just happened/it was available/normal'
                  31='(31) Was going to start selling it/already se'
                  32='(32) As part of a special occasion'
                  35='(35) Because I wanted to/just felt like it'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccyr    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccyfrn  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccysps  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccyesc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccyrlx  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccydrs  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccydrx  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccyrlf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccysor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccysp   9='(9) Experimenting/curiosity'
                  10='(10) Because I wanted to/just felt like it'
                  11='(11) It was there'
                  13='(13) Its fun/I like it/I like the way it mak'
                  14='(14) Partying/to enhance an experience'
                  18='(18) Im addicted/it is a habit' 20='(20) To give me energy'
                  22='(22) Unaware I was using it/deception'
                  25='(25) Lose weight/decrease my appetite'
                  28='(28) I wanted to disobey the people who told'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccretf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdni   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdphy  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdsck  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdblf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdtst  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdpsy  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccddgs  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdadd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdprg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdkid  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdpar  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdsps  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdfrn  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdcos  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdget  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccddlr  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdigl  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdcrm  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdsor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccdsp   20='(20) It is stupid/dumb' 21='(21) It is disgusting'
                  22='(22) I dont use drugs anymore/I am drug-free'
                  23='(23) Dont like it/I dont like its effect'
                  25='(25) I enjoy life without drugs/happy without'
                  26='(26) Self-respect/want to be my best/in contr'
                  30='(30) Ive seen what it could do to friends/no'
                  31='(31) Hate it/could ruin my life/bad/dangerous'
                  32='(32) Could interfere w/ job/career/sports/sch'
                  33='(33) Could hurt others/those around me'
                  34='(34) No benefit to me/too much to lose/would'
                  35='(35) Have too many responsibilities/need to s'
                  38='(38) On probation/could get in trouble'
                  39='(39) Have not had the opportunity to use'
                  40='(40) Matured out of it/too old now'
                  41='(41) Prefer a different drug'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccre0f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  92='(92) Question not administered' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnni   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnphy  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnlik  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnblf  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccntst  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnpsy  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccndgs  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnadd  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnprg  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnkid  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnpar  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnsps  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnfrn  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccncos  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnget  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccndlr  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnigl  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccncrm  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnsor  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dxccnsp   20='(20) It is stupid/dumb' 21='(21) It is disgusting'
                  22='(22) I just dont use drugs/not the type who'
                  23='(23) Dont like it/makes me sick'
                  24='(24) Would interfere with medical care'
                  25='(25) I enjoy life without drugs/happy without'
                  26='(26) Self-respect/want to be my best/in contr'
                  27='(27) People just use it to cover up/hide from'
                  28='(28) Drugs are the downfall of society'
                  29='(29) Ive seen what it could do to family mem'
                  30='(30) Ive seen what it could do to friends/no'
                  31='(31) Hate it/could ruin my life/bad/dangerous'
                  32='(32) Could interfere with job/career/sports/s'
                  33='(33) Could hurt others/those around me'
                  34='(34) No benefit to me/too much to lose/would'
                  35='(35) Have too many responsibilities/need to s'
                  36='(36) Afraid to use/not sure what would happen'
                  37='(37) Could lead to other criminal activity/be'
                  39='(39) Never had the opportunity to use'
                  40='(40) Too old now/experimental days in the pas'
                  41='(41) Dont know anything about it'
                  42='(42) I prefer a different drug' 43='(43) I sell it'
                  44='(44) It is unnatural' 45='(45) TV, radio and newspaper ads'
                  46='(46) Dont want to support other countries'
                  47='(47) racial epithet group' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpyeans  1='(1) Respondent is 18 years or older - SKIP'
                  2='(2) Respondent is 12-17 years old'
                  3='(3) Respondent is 18 years or older LOG ASSN'
                  4='(4) Respondent is 12-17 years old LOG ASSN' ;
  VALUE skpyexrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yexread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeenrlyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepubsch  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeprvsch  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yehomsch  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ye4yrcol  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ye2yrcol  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yevocsch  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeschoth  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeschsp   7='(7) GED program/night school/adult ed'
                  8='(8) Graduate or post-graduate school' 9='(9) Alternative school'
                  10='(10) Performing arts school'
                  11='(11) School for learning disabled/phys handic'
                  12='(12) Extracurricular activity schooling' 13='(13) Summer school'
                  14='(14) Tutoring' 15='(15) Correspondence courses'
                  16='(16) School for behavior problems/continuatio'
                  18='(18) Post-high school level, school type unsp'
                  19='(19) Technical/vocational course, school type'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yegrades  1='(1) Mostly As or Bs' 2='(2) Mostly Bs or Cs' 3='(3) Mostly Cs or Ds'
                  4='(4) Mostly Ds or below'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) My school does not give those grades' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yescouts  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeprvles  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetemspt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ye4hclub  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeband    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeschclb  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yestgovt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yevolunt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yechoir   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeactoth  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeactsp   10='(10) Church-related/religious activity other'
                  11='(11) Job/internship'
                  12='(12) Drama/acting/theater/dance/performing ar'
                  13='(13) Band/music/chorus, unascribed to school'
                  14='(14) Art class/art program/photography'
                  15='(15) Cheerleading/colorguard/drill team'
                  16='(16) Chores/family responsibilities'
                  17='(17) Leisure/recreation (hunting, fishing, be'
                  18='(18) After school program/study group/schooli'
                  19='(19) Club/youth group, unascribed to school o'
                  20='(20) YMCA/YWCA'
                  21='(21) ROTC/JROTC/military or civic-oriented pr'
                  22='(22) Sports/exercise, unascribed to school' 23='(23) Hobbies'
                  24='(24) Camp/upward bound'
                  25='(25) Academic activities/club/group, unascrib'
                  26='(26) Cosmetic/physical appearance-related act'
                  27='(27) Multiple activities' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yejobyr   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yejobscd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yedetchr  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yedentch  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yedespcl  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yedeoth   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yedesp    4='(4) Special course/class; instructor unspeci'
                  5='(5) Law enforcement/court rep spoke on drugs'
                  6='(6) Former addict spoke on drug/alcohol abus'
                  7='(7) Substance abuse person/counselor/med pro'
                  8='(8) Other students spoke on drugs/alcohol ab'
                  9='(9) Teacher(s)/coach(es) discussed (no speci'
                  10='(10) Speaker (unidentified) spoke on drugs/al'
                  11='(11) School Assembly/presentation/health fair'
                  12='(12) Simulation (e.g. drunk driving simulator'
                  13='(13) GREAT [Gang Resistance Education and Tra'
                  14='(14) A play/skit/quiz/concert about alcohol/d'
                  15='(15) Parents/family members have talked to me'
                  16='(16) Anti-drug day/week at schl (e.g. Red Rib'
                  17='(17) Part of drivers education class'
                  18='(18) Part of health/physical/science/sex ed c'
                  19='(19) Church/religious-affiliated class'
                  20='(20) Students/Mothers Against Drunk Driving ('
                  21='(21) Camp/Upward Bound/club/conference'
                  22='(22) Viewed a video/movie about drug/alcohol'
                  23='(23) Personal experiences'
                  24='(24) Written materials on drug/alcohol abuse'
                  25='(25) Special course taught by military'
                  26='(26) Part of life skills/life management clas'
                  27='(27) YMCA/sports-affiliated class/course'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemsgyr   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeparyr   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeppkcig  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepmjevr  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepmjocc  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepmjreg  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepinevr  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepheevr  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepccocc  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepbinge  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefpkcig  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefmjevr  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefmjocc  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefmjreg  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefinevr  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefheevr  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefccocc  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefbinge  1='(1) Not upset at all' 2='(2) Somewhat upset' 3='(3) Very upset'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdpkcg  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdmjev  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdmjoc  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdmjrg  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdinev  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdheev  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdccoc  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdbing  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetlknon  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSNON=1)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and other responses in'
                  13='(13) Resp markd LOG ASSN (>1 ans in Y-13 & Y'
                  15='(15) Resp markd LOG ASSN (>1 ans in Y-13 & Y'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkmom  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSMOM=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSMOM=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSMOM=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkdad  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSDAD=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSDAD=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSDAD=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkbgf  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSBGF=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSBGF=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSBGF=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksib  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSSIB=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSSIB=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSSIB=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksor  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSSOR=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSSOR=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSSOR=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkfrn  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSFRN=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSFRN=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKFRN=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSFRN=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlktch  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSTCH=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSTCH=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSTCH=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkclg  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSCLG=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSCLG=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSCLG=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksop  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSSOP=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSSOP=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSSOP=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksp   84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  181='(181) Other Male God Relative' 191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified'
                  281='(281) Other Female God Relative'
                  291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified'
                  381='(381) Other God Relatives'
                  384='(384) Neighbors/Co-Workers/Visitors/Employees/'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified'
                  605='(605) Police/law enforcement'
                  606='(606) Counselor(s), type unspecified'
                  607='(607) Other church worker(s)/member(s)'
                  608='(608) Teacher(s), non-school'
                  609='(609) Psychologist(s)/psychiatrist(s)/therapis'
                  610='(610) Doctor(s)/nurse(s)/health care professio'
                  611='(611) Hotline' 900='(900) NOT A PERSON' 901='(901) God/Heavenly Father'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE yetlknr   10='(10) BOY/GIRLFRIEND OF PARENT'
                  11='(11) OTHER FRIEND(S) OF PARENT(S)'
                  12='(12) BOY/GIRLFRIEND OF SIBLING(S)'
                  13='(13) OTHER FRIEND(S) OF SIBLING(S)' 15='(15) FRIEND(S) OF FAMILY'
                  16='(16) FRIEND(S) OF OTHER RELATIVE(S)'
                  23='(23) PARENT OF BOY/GIRLFRIEND' 30='(30) PARENT(S) OF FRIEND(S)'
                  40='(40) MANAGER/BOSS/EMPLOYER' 41='(41) EMPLOYEE(S)/SUPERVISEE(S)'
                  42='(42) CO-WORKER(S), RELATIONSHIP UNSPECIFIED'
                  50='(50) NEIGHBOR(S)' 62='(62) IN THE MILITARY' 70='(70) BABYSITTER'
                  71='(71) CASUAL ACQUAINTANCE(S)' 73='(73) SELF-HELP GROUP MEMBER(S)'
                  74='(74) SCOUT LEADER/MASTER'
                  75='(75) YOUTH WORKER, CHURCH NOT SPECIFIED'
                  76='(76) MENTOR/PERSON BEING MENTORED'
                  77='(77) ANOTHER ADULT/OLDER PERSON'
                  78='(78) SOMEONE KNOWN TO R, RELATIONSHIP UNSPEC'
                  80='(80) ANYBODY/EVERYBODY'
                  81='(81) PERSON(S) W/DESIRED CHARACTERISTICS/EXPE'
                  90='(90) SPECIFIC NAME MENTIONED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE yemosnon  1='(1) Response marked' 6='(6) Response not marked'
                  15='(15) Response marked (and other responses in'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosmom  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosdad  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosbgf  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossib  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossor  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)YEMOSFR'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosfrn  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response marked' 15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemostch  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosclg  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossop  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossp   84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  142='(142) Brother In-Law' 181='(181) Other Male God Relative'
                  281='(281) Other Female God Relative'
                  291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified'
                  381='(381) Other God Relatives'
                  384='(384) Neighbors/Co-Workers/Visitors/Employees/'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  605='(605) Police/law enforcement'
                  606='(606) Counselor(s), type unspecified'
                  607='(607) Other church worker(s)/member(s)'
                  608='(608) Teacher(s), non-school'
                  609='(609) Psychologist(s)/psychiatrist(s)/therapis'
                  610='(610) Doctor(s)/nurse(s)/health care professio'
                  611='(611) Hotline' 900='(900) NOT A PERSON' 901='(901) God/Heavenly Father'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE yemosnr   12='(12) BOY/GIRLFRIEND OF SIBLING(S)'
                  13='(13) OTHER FRIEND(S) OF SIBLING(S)'
                  30='(30) PARENT(S) OF FRIEND(S)' 71='(71) CASUAL ACQUAINTANCE(S)'
                  73='(73) SELF-HELP GROUP MEMBER(S)'
                  75='(75) YOUTH WORKER, CHURCH NOT SPECIFIED'
                  76='(76) MENTOR/PERSON BEING MENTORED'
                  77='(77) ANOTHER ADULT/OLDER PERSON'
                  81='(81) PERSON(S) W/DESIRED CHARACTERISTICS/EXPE'
                  90='(90) SPECIFIC NAME MENTIONED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE yestdres  1='(1) Not at all strict' 2='(2) Just strict enough' 3='(3) Too strict'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yestlate  1='(1) Not at all strict' 2='(2) Just strict enough' 3='(3) Too strict'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yesthwrk  1='(1) Not at all strict' 2='(2) Just strict enough' 3='(3) Too strict'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeargup   1='(1) Every day' 2='(2) Several times a week'
                  3='(3) About once a week' 4='(4) About once a month'
                  5='(5) Rarely or never' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yegfite   1='(1) Never' 2='(2) 1 or 2 times' 3='(3) 3 or 4 times'
                  4='(4) 5 or more times' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeshplft  1='(1) Never' 2='(2) 1 or 2 times' 3='(3) 3 or 4 times'
                  4='(4) 5 or more times' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE movespyr  0='(0) None' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE educ2ndq  0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) Freshman/13th year'
                  14='(14) Sophomore/14th year' 15='(15) Junior/15th year'
                  16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE studnt9f  1='(1) A full-time student' 2='(2) A part-time student'
                  3='(3) Not now enrolled in any school'
                  4='(4) A full-time/part-time student LOG ASSN'
                  6='(6) Not now enrolled in any school LOG ASSN'
                  51='(51) School not in session (RAW QD16 = 1)'
                  52='(52) School not in session (RAW QD16 = 2)'
                  53='(53) School not in session (RAW QD16 = 3)'
                  54='(54) School not in session (RAW QD16 = 98)'
                  55='(55) School not in session (RAW QD16=RECODE O'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stdt949f  1='(1) A full-time student' 2='(2) A part-time student'
                  3='(3) Not now enrolled in any school'
                  5='(5) School not in session (RAW QD16 NOT 3)'
                  6='(6) Not now enrolled in any school LOG ASSN'
                  13='(13) QD16 marked not enrld, but QD12 marked'
                  15='(15) School not in session (RAW QD16 = 3)'
                  85='(85) BAD DATA Logically assigned' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpschgr  1='(1) EDUC2NDQ = 0 THROUGH 11 AND STUDNT97= 3,'
                  2='(2) EDUC2NDQ = 12 THROUGH 17 AND STUDNT97= 3'
                  3='(3) EDUC2NDQ = 0 THROUGH 11 AND STUDNT97= 3,'
                  4='(4) EDUC2NDQ = 12 THROUGH 17 AND STUDNT97= 3'
                  51='(51) School not in session (EDUC2NDQ = 0-11)'
                  52='(52) School not in session (EDUC2NDQ = 12-17)'
                  53='(53) School not in session (EDUC2NDQ undefine'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skpschag  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSINGED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lftschrs  1='(1) I was getting bad grades' 2='(2) School was boring'
                  3='(3) I got expelled for selling drugs'
                  4='(4) I got expelled for using drugs'
                  5='(5) I got expelled for some other reason' 6='(6) I got pregnant'
                  7='(7) I had to get a job because I needed the'
                  8='(8) I wasnt learning anything' 9='(9) I went to jail/prison'
                  10='(10) I quit school for some other reason'
                  11='(11) I was getting bad grades' 12='(12) School was boring'
                  15='(15) I got expelled for some other reason'
                  16='(16) I got pregnant'
                  17='(17) I had to get a job because I needed the'
                  18='(18) I wasnt learning anything'
                  20='(20) I was ill/sick/injured/needed medical ca'
                  21='(21) Family member became ill/sick/died'
                  22='(22) Responsibilities at home/family/personal'
                  23='(23) Parents/guardian would not allow me to a'
                  24='(24) Ran away from/put out of/placed out of h'
                  25='(25) Too stressful/couldnt adjust' 26='(26) Learning disabled'
                  27='(27) Couldnt get along with students/teacher'
                  28='(28) Race-related problems'
                  29='(29) Was sexually abuse/assaulted'
                  30='(30) Running with the wrong crowd/getting in'
                  31='(31) Afraid of gangs/fear of violence/crime'
                  32='(32) Abusing drugs/alcohol'
                  33='(33) Skipping school/excessive absenteeism'
                  34='(34) Too expensive/couldnt afford'
                  35='(35) Didnt like it/didnt want to go/not int'
                  36='(36) No transportation/school too far away'
                  37='(37) Wasnt able to play sports so quit'
                  38='(38) Grade or credit discrepancies/lacked cre'
                  39='(39) Advised to quit by guidance counselor/ad'
                  40='(40) All the schooling that was available'
                  41='(41) Wasnt required/didnt have to go/not ne'
                  42='(42) Against my religion' 43='(43) To sell drugs'
                  44='(44) War/political problems in my country'
                  45='(45) I was stupid/foolish' 46='(46) Needed a break'
                  47='(47) Got married/moved in with boyfriend'
                  48='(48) Joined military' 49='(49) Too old'
                  50='(50) Wanted to work/do apprenticeship instead'
                  51='(51) Moved away/didnt re-enroll'
                  52='(52) Just quit; reason unspecified'
                  53='(53) I got suspended for fighting'
                  54='(54) I got suspended, reason unspecified'
                  68='(68) Graduated/completed high school or highe'
                  69='(69) Never went to school/no school available'
                  77='(77) Summer/school not in session' 78='(78) I am still in school'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 92='(92) ILLEGIBLE'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lftschag  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE schdys9f  0='(0) None' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) School was not in session' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE schd949f  0='(0) None' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) School was not in session' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skippd9f  0='(0) None' 35='(35) Date specified within the past 30 days'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) School was not in session' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skip949f  0='(0) None' 35='(35) Date specified within the past 30 days'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) School was not in session' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE njobspyr  0='(0) None' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wrkstatf  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job but out: illness/leave/furlou'
                  4='(4) Have a job, but it is seasonal'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed and not looking for work'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled, not able to work' 11='(11) Other, not specified'
                  21='(21) Working full-time, 35 hours or more a we'
                  22='(22) Working part-time, less than 35 hours a'
                  23='(23) Have a job but out: illness/leave/furlou'
                  24='(24) Have a job, but it is seasonal'
                  25='(25) Unemployed or laid off and looking for w'
                  26='(26) Unemployed and not looking for work'
                  27='(27) Full-time homemaker' 28='(28) In school only' 29='(29) Retired'
                  30='(30) Disabled, not able to work' 31='(31) Other, in labor force'
                  32='(32) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wkst2ndq  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job but out: illness/leave/furlou'
                  4='(4) Have a job, but it is seasonal'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed and not looking for work'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled, not able to work' 11='(11) Other, not specified'
                  21='(21) Working full-time, 35 hours or more a we'
                  22='(22) Working part-time, less than 35 hours a'
                  23='(23) Have a job but out: illness/leave/furlou'
                  24='(24) Have a job, but it is seasonal'
                  25='(25) Unemployed or laid off and looking for w'
                  26='(26) Unemployed and not looking for work'
                  27='(27) Full-time homemaker' 28='(28) In school only' 29='(29) Retired'
                  30='(30) Disabled, not able to work' 31='(31) Other, in labor force'
                  32='(32) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wkswkst   0='(0) None' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpwkstf  1='(1) WORK STATUS = 1,2,3, or 4'
                  2='(2) WORK STATUS = 5,6,7,8,9,10, or 11'
                  3='(3) WORK STATUS = 1,2,3, or 4 LOG ASSN'
                  4='(4) WORK STATUS = 5,6,7,8,9,10, or 11 LOG AS'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE bussize   1='(1) Less than 10 people' 2='(2) 10-24 people' 3='(3) 25-99 people'
                  4='(4) 100-499 people' 5='(5) 500 people or more'
                  12='(12) 10-24 people LOGICALLY ASSIGNED'
                  13='(13) 25-99 people LOGICALLY ASSIGNED'
                  14='(14) 100-499 people LOGICALLY ASSIGNED'
                  15='(15) 500 people or more LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE locsize   1='(1) Less than 10 people' 2='(2) 10-24 people' 3='(3) 25-99 people'
                  4='(4) 100-499 people' 5='(5) 500 people or more'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE drginfo   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) Dont remember'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE drgplcy   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) Dont remember'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE plcycov   1='(1) Only alochol' 2='(2) Only drugs' 3='(3) Both alcohol and drugs'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) Dont Know'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE drgprgm   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) Dont Know' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE usalctst  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) Dont Know'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE usdrgtst  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) Dont Know'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skpwktst  1='(1) USALCTST = No or DK and USDRGTST = No or'
                  2='(2) USALCTST or USDRGTST = Yes'
                  3='(3) USALCTST = No or DK and USDRGTST = No/DK'
                  4='(4) USALCTST or USDRGTST = Yes LOG ASSN'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tsthire   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) Dont Know' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE tstrand   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) Dont Know' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tstsusp   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) Dont Know' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tstaccd   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) Dont Know' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tsttrmt   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) Dont know' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wrkhire   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wrkrand   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wrksusp   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wrkaccd   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE paymo     89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER WORKED FOR PAY' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE payyr     985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  991='(991) NEVER WORKED FOR PAY' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE skpwks0f  1='(1) Work stat=Now in labor force (codes 1-4,'
                  2='(2) Work stat=Not in labor frc (5-11,25-32)'
                  3='(3) Work stat=Now in labor force LOGICALLY A'
                  4='(4) Work stat=Not in labor frc LOG ASSN - SK' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE workdays  0='(0) None' 89='(89) LEGITIMATE SKIP Logically assigned'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  0='(0) None' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skppreg   1='(1) Respondent is female less than 45 years'
                  2='(2) Respondent is female 45 years or older -'
                  3='(3) Respondent is male - SKIP'
                  4='(4) Female less than 45 LOGICALLY ASSIGNED'
                  5='(5) Female 45 years or older LOGICALLY ASSIG'
                  6='(6) Male LOGICALLY ASSIGNED - SKIP' ;
  VALUE pregnant  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pregmos   85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpcwe    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (specify)'
                  3='(3) Income equally by resp and someone else' 4='(4) No one'
                  6='(6) Someone else LOGICALLY ASSIGNED'
                  7='(7) Income eql by resp and someone else LOG'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwesc1ff  8='(8) Respondent' 9='(9) Head of Household' 10='(10) Spouse'
                  20='(20) Parent/Guardian' 37='(37) Child, Relation Unspecified'
                  60='(60) Live-In Partner' 61='(61) Friend/Roommate/Companion'
                  71='(71) Cousin/Cousins Spouse'
                  82='(82) Housekeeper/Maid/Caretaker/Butler'
                  84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  85='(85) Landlord/Home Owner'
                  91='(91) Other Non-Relative, Gender not specified'
                  109='(109) Male Head of Household' 110='(110) Husband' 111='(111) Ex-Husband'
                  113='(113) Childs Father' 120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F'
                  122='(122) Father/Step Father/Future Father In-Law' 130='(130) Son'
                  132='(132) Son In-Law' 140='(140) Brother/Half Brother'
                  141='(141) Step/Adopted/Foster Brother/Future Step'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  160='(160) Male Live-In Partner'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 171='(171) Male Cousin'
                  172='(172) Nephew' 181='(181) Other Male God Relative'
                  184='(184) Male Neighbor/Co-Worker/Visitor/Employee'
                  190='(190) Other Male Relative' 191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  211='(211) Ex-Wife' 220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 231='(231) Step/Adopted/Foster Daughter'
                  232='(232) Daughter In-Law' 233='(233) Granddaughter'
                  240='(240) Sister/Half Sister'
                  241='(241) Step/Adopted/Foster Sister/Future Step S'
                  242='(242) Sister In-Law' 250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  272='(272) Niece' 291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified'
                  309='(309) Head of Household' 315='(315) In-Laws'
                  320='(320) Parents/Guardians'
                  321='(321) Step/Adopted/Foster Parents/Future Step'
                  337='(337) Children, Relation Unspecified' 340='(340) Siblings'
                  350='(350) Grandparents/Great+ Grandparents'
                  361='(361) Friends/Roommates/Companions'
                  371='(371) Cousins/Cousins Spouses'
                  382='(382) Housekeepers/Maids/Caretakers/Butlers'
                  390='(390) Other Relatives, Gender not specified'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified'
                  410='(410) Husbands' 420='(420) Fathers/Male Guardians' 430='(430) Sons'
                  440='(440) Brothers/Half Brothers'
                  461='(461) Male Fiances/Boyfriends/Roommates/Compan'
                  492='(492) Other Males, Relation Unspecified'
                  540='(540) Sisters/Half Sisters' 900='(900) NOT A PERSON'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cwesc2ff  8='(8) Respondent' 9='(9) Head of Household' 20='(20) Parent/Guardian'
                  50='(50) Grandparent/Great+ Grandparent' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin/Cousins Spouse'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  109='(109) Male Head of Household' 110='(110) Husband'
                  120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F'
                  122='(122) Father/Step Father/Future Father In-Law' 130='(130) Son'
                  132='(132) Son In-Law' 133='(133) Grandson' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 172='(172) Nephew'
                  191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  272='(272) Niece' 291='(291) Other Female Non-Relative'
                  320='(320) Parents/Guardians'
                  322='(322) Parents/Step Parents/Future Parents In-L'
                  337='(337) Children, Relation Unspecified'
                  361='(361) Friends/Roommates/Companions'
                  440='(440) Brothers/Half Brothers' 540='(540) Sisters/Half Sisters'
                  550='(550) Grandmothers/Great+ Grandmothers'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE fullpart  1='(1) Full time' 2='(2) Part time'
                  3='(3) Chief wage earner does not work'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE rlgsvcfq  1='(1) Never attended religious services'
                  2='(2) Attended about once or twice in the past'
                  3='(3) Attended about once or twice a month'
                  4='(4) Attended every week' 5='(5) Attended several times a week'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rlgimprt  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Agree'
                  4='(4) Strongly Agree' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rlgdecsn  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Agree'
                  4='(4) Strongly Agree' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rlgfrnds  1='(1) Strongly disagree' 2='(2) Disagree' 3='(3) Agree'
                  4='(4) Strongly Agree' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpmhc    1='(1) Respondent is 18 years or older'
                  2='(2) Respondent is 12-17 years old - SKIP'
                  3='(3) 18 or older LOGICALLY ASSIGNED'
                  4='(4) 12 to 17 LOGICALLY ASSIGNED - SKIP' ;
  VALUE depress   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depdays   1='(1) All day long' 2='(2) Most of the day' 3='(3) About half the day'
                  4='(4) Less than half the day'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depfreq   1='(1) Every day' 2='(2) Almost every day' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lostintf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE tired1ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wtchng1f  1='(1) Gained weight' 2='(2) Lost weight'
                  3='(3) Both gained and lost weight' 4='(4) Stayed the same'
                  5='(5) Respondent was on a diet'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lbschngf  0='(0) None' 989='(989) LEGITIMATE SKIP Logically assigned'
                  994='(994) DONT KNOW' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE slplossf  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE slpfreqf  1='(1) Every night' 2='(2) Nearly every night' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE concen1f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE down1fff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ideat1ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpdep1f  1='(1) Yes' 2='(2) No - SKIP' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED - SKIP'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depwks1f  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE depmo1ff  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE depyr1ff  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE lostin0f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE losinday  1='(1) All day long' 2='(2) Most of the day' 3='(3) About half the day'
                  4='(4) Less than half the day'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE losinfrq  1='(1) Every day' 2='(2) Almost every day' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tired2ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wtchng2f  1='(1) Gained weight' 2='(2) Lost weight'
                  3='(3) Both gained and lost weight' 4='(4) Stayed the same'
                  5='(5) Respondent was on a diet'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lbschn0f  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE slplos0f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE slpfre0f  1='(1) Every night' 2='(2) Nearly every night' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE concen2f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE down2fff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ideat2ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpdep2f  1='(1) Yes' 2='(2) No - SKIP' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED - SKIP'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depwks2f  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depmo2ff  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depyr2ff  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE worried   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worend    1='(1) Ended' 2='(2) Still going on' 3='(3) Ended LOGICALLY ASSIGNED'
                  4='(4) Still going on LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wornomof  9989='(9989) LEGITIMATE SKIP Logically assigned' 9994='(9994) DONT KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE worhapnf  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worserif  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wordifff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wornom0f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9994='(9994) DONT KNOW'
                  9995='(9995) BAD DATA' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE worhap0f  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worser0f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wordif0f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpwor    1='(1) WORNOMO1 or WORNOMO2 = 6 months or more'
                  2='(2) WORNOMO1 or WORNOMO2 < 6 mo. - SKIP'
                  3='(3) WORNOMO1 or WORNOMO2 = 6 mo. or more LOG'
                  4='(4) WORNOMO1 or WORNOMO2 < 6 mo. LOG ASSN -'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worrest   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE woredge   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worirrit  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worheart  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wortired  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worsleep  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worfaint  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearpub   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fearout   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearbrdg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpfearf  1='(1) Any yes answer' 2='(2) All answered no - SKIP'
                  3='(3) Any yes answer LOGICALLY ASSIGNED'
                  4='(4) All answered no LOGICALLY ASSIGNED - SKI'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearoft   1='(1) Every time' 2='(2) Most of the time' 3='(3) Some of the time'
                  4='(4) Only one or two times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearyrs   1='(1) Less than 1 year' 2='(2) Between 1 and 5 years'
                  3='(3) More than 5 years'
                  5='(5) Between 1 and 5 yrs LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearmos   85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fearfant  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE feartrap  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fearhelp  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panic1ff  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panic2ff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panicnum  0='(0) None' 985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE panicmo   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panicyr   985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE panidang  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skpfea0f  1='(1) Any yes answer' 2='(2) All answered no - SKIP'
                  3='(3) Any yes answer LOGICALLY ASSIGNED'
                  4='(4) All answered no LOGICALLY ASSIGNED - SKI'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panifear  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE paninofr  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panihart  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panipain  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE paniswet  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panishak  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panihot   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE paniunrl  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nuertmt   0='(0) None' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nuhspov   0='(0) None' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nuhsppe   0='(0) None' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE outptpe   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE proxable  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (FAMS'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (FAMSKIP=1)' ;
  VALUE proxyrel  1='(1) Respondents spouse/live-in partner'
                  2='(2) Respondents father' 3='(3) Respondents mother'
                  4='(4) Respondents brother' 5='(5) Respondents sister'
                  6='(6) Other family member (specify relation to'
                  20='(20) Parent/Guardian' 50='(50) Grandparent/Great+ Grandparent'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin/Cousins Spouse'
                  91='(91) Other Non-Relative, Gender not specified' 110='(110) Husband'
                  120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F' 130='(130) Son'
                  140='(140) Brother/Half Brother'
                  150='(150) Grandfather/Great+ Grandfather'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 171='(171) Male Cousin'
                  210='(210) Wife' 220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 232='(232) Daughter In-Law' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  281='(281) Other Female God Relative'
                  291='(291) Other Female Non-Relative'
                  350='(350) Grandparents/Great+ Grandparents'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE proxhome  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxjoin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE careusu   1='(1) Yes' 2='(2) No' 3='(3) Dont know'
                  4='(4) There is more than one place' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ncarersn  1='(1) Two or more usual doctors/places' 2='(2) Dont need a doctor'
                  3='(3) Dont like/trust/believe in doctors'
                  4='(4) Dont know where to go'
                  5='(5) Previous doctor is not available/moved'
                  6='(6) No insurance/cant afford it'
                  7='(7) Speak a different language'
                  8='(8) No care available/care too far away/inco'
                  9='(9) Other specify (see NCRRSNSP & NCRRSNSC)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ncrrsnsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ncrrsnsc  1='(1) Two or more usual doctors/places' 2='(2) Dont need a doctor'
                  3='(3) Dont like/trust/believe in doctors'
                  4='(4) Dont know where to go'
                  5='(5) Previous doctor is not available/moved'
                  6='(6) No insurance/cant afford it'
                  8='(8) No care available/care too far away or i'
                  10='(10) New to area/recently moved'
                  11='(11) Do not have a regular doctor'
                  12='(12) Self treatment/treatment by family membe'
                  13='(13) Religious reasons'
                  14='(14) Health care plan determines source'
                  15='(15) Hospital/urgent care/clinic' 16='(16) School/workplace'
                  18='(18) Alternative medicine' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE careoft   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcare   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtyp  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room' 7='(7) HMO'
                  8='(8) Psychiatric hosptial or clinic'
                  9='(9) VA hospital or clinic'
                  10='(10) Military health care facility'
                  11='(11) Some other place specified (see PYRCRTSP' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtsc  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  7='(7) HMO (Health maintenance organization/pre'
                  12='(12) Self treatment/family member'
                  14='(14) Urgent care/walk-in medical facility'
                  16='(16) Alternative medicine' 18='(18) Family planning clinic'
                  19='(19) Indian clinic or hospital'
                  20='(20) Drug treatment/rehab center'
                  23='(23) Prison/correctional facility'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE carenow   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnncr  1='(1) Respondent changed residence/moved'
                  2='(2) Respondent changed jobs'
                  3='(3) Employer changed insurance companies'
                  5='(5) Owed money to former usual source'
                  6='(6) Dissatsfd with frmr source/like new sour'
                  7='(7) Medical care needs changed'
                  8='(8) Frmr usual source stopped taking ins/cov'
                  9='(9) Other reason specified (see MNRSNNSP/SC)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnnsp  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnnsc  1='(1) Respondent changed residence/moved'
                  3='(3) Employer change insurance companies'
                  4='(4) Former usual source left area'
                  6='(6) Dissatsfd with frmr source/liked new sou'
                  7='(7) Medical care needs changed'
                  10='(10) Gynecological/obstetric care only'
                  11='(11) Medical care received through workmans'
                  12='(12) Do not need/like doctors'
                  13='(13) Cannot afford it/no insurance' 15='(15) Military'
                  16='(16) Former student' 19='(19) Different insurance coverage now'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ucaretyp  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room' 7='(7) HMO'
                  8='(8) Psychiatric hospital or clinic'
                  9='(9) VA hospital or clinic'
                  10='(10) Military health care facility'
                  11='(11) Some other place specified (see UCRTYPSP'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ucrtypsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ucrtypsc  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  6='(6) Hospital emergency room'
                  7='(7) HMO (Health maintenance organization/pre'
                  10='(10) Military health care facility'
                  12='(12) Self treatment/family member' 13='(13) Friend'
                  14='(14) Urgent care/walk-in medical facility'
                  15='(15) Religion/church' 16='(16) Alternative medicine'
                  17='(17) Non-physician health care professional'
                  18='(18) Family planning clinic' 19='(19) Indian clinic or hospital'
                  24='(24) Health-related camp/program'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE medicare  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE medicaid  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE champus   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE prvhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE grphltin  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE pdhinprm  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hltinalc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltindrg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinmnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE soc1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soc2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ssi1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ssi2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE pub1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pub2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE afdc      1='(1) AFDC/ADC' 2='(2) OTHER' 3='(3) BOTH'
                  4='(4) AFDC/ADC Logically assigned'
                  5='(5) OTHER Logically assigned' 6='(6) BOTH Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE int1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE int2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE chd1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chd2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oth1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE oth2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fstamp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pinc1fff  1='(1) $20,000 or more' 2='(2) Less than $20,000' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pinc2fff  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skptfmin  1='(1) Yes' 2='(2) No - SKIP' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE finc1fff  1='(1) $20,000 or more' 2='(2) Less than $20,000'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE finc2fff  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE telno     0='(0) None' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE irpinsur  1='(1) Yes, respondent does have private health'
                  2='(2) No, respondent does not have private hea' ;
  VALUE iipinsur  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinsur   1='(1) Yes, respondent does have health insuran'
                  2='(2) No, respondent does not have health insu' ;
  VALUE iiinsur   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsoc1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irssi1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpub1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iipub1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irafdc    1='(1) AFDC/ADC' 2='(2) OTHER' 3='(3) BOTH'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iiafdc    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irint1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irchd1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iroth1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irfstamp  1='(1) Yes' 2='(2) No' ;
  VALUE iifstamp  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpinc1f  1='(1) $20,000 or more' 2='(2) Less than $20,000' ;
  VALUE iipinc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irfinc1f  1='(1) $20,000 or more' 2='(2) Less than $20,000'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iifinc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irsoc2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irssi2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irpub2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iipub2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irint2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irchd2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iroth2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irpinc2f  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more' ;
  VALUE iipinc2f  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irfinc2f  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iifinc2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE edirkids  91='(91) No children under 12' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE irkids    0='(0) No children under 12' ;
  VALUE parstat   1='(1) Respondent has no children'
                  2='(2) Respondent has at least one child < 2 yr'
                  3='(3) Resp has at least 1 child < 17, none < 2' ;
  VALUE fembaby   0='(0) No' 1='(1) Yes' ;
  VALUE femkids   0='(0) No' 1='(1) Yes' ;
  VALUE malebaby  0='(0) No' 1='(1) Yes' ;
  VALUE malekids  0='(0) No' 1='(1) Yes' ;
  VALUE f15_44ff  0='(0) Otherwise' 1='(1) Female age 15-44' ;
  VALUE m15_44ff  0='(0) Otherwise' 1='(1) Male age 15-44' ;
  VALUE relinthh  0='(0) Second interviewed person does not exist' 10='(10) Spouse'
                  20='(20) Parent/Guardian' 21='(21) Step/Adopted/Foster Parent'
                  22='(22) Parent In-Law (Also step-)' 25='(25) Parents Sibling'
                  30='(30) Child' 31='(31) Step/Adopted/Foster Child' 32='(32) Child In-Law'
                  35='(35) Siblings Child' 36='(36) Cousin' 37='(37) Grandchild'
                  40='(40) Sibling' 41='(41) Step/Adopted/Foster Sibling'
                  42='(42) Sibling In-Law' 50='(50) Grandparent'
                  60='(60) Live in partner, fiancee' 61='(61) Friend/Roommate'
                  62='(62) Tenant/Boarder/Exchange Student' 70='(70) Other, Relative'
                  71='(71) Other, Non-Relative' 99='(99) Other, Relation Unspecified' ;
  VALUE preg      0='(0) Otherwise' 1='(1) Pregnant female age 12-44' ;
  VALUE preg2fff  1='(1) Pregnant (PREGNANT = 1,3)'
                  2='(2) Not pregnant (PREGNANT = 2)'
                  3='(3) Males/Females not age 12-44 (PREGNANT ='
                  99='(99) Unknown (PREGNANT = 94,97,98)' ;
  VALUE trimest   1='(1) 1st 3 months of pregnancy (PREG=1 & PRE'
                  2='(2) 2nd 3 months of pregnancy (PREG=1 & PRE'
                  3='(3) Last 3 months of pregnancy (PREG=1 & PR'
                  4='(4) Males/Not pregnant females (PREG=0)'
                  99='(99) Unknown (PREG=1 and PREGMOS=85,94,98)' ;
  VALUE indcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE perinc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,999' 5='(5) $75,000+' ;
  VALUE perinc2f  1='(1) $0-9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE perinc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years Old' ;
  VALUE totcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE faminc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,000' 5='(5) $75,000+' ;
  VALUE faminc2f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE faminc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years old' ;
  VALUE welfare   1='(1) Yes, respondent or another fam member on'
                  2='(2) No, there was no one in the family on we' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 12 m'
                  3='(3) 12 or more months ago but less than 3 ye'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE V' ;
  VALUE nedflagf  0='(0) Never used (GNNDLLIF=2,85,97,98)'
                  1='(1) Ever Used (GNNDLLIF=1,3)' ;
  VALUE nedyr4ff  0='(0) Never used (NEEDLREC=3,4,9,91,98)'
                  1='(1) Ever Used (NEEDLREC=1,2)' ;
  VALUE hersmokf  0='(0) No/Unknown (HERSMOKE=2,4,85,89,97,98,99)'
                  1='(1) Yes (HERSMOKE=1,3)' ;
  VALUE hersni0f  0='(0) No/Unknown (HERSNIFF=2,4,85,89,97,98,99)'
                  1='(1) Yes (HERSNIFF=1,3)' ;
  VALUE cigarmon  1='(1) Used in past 30 days' 2='(2) Did not use in past 30 days'
                  4='(4) Did not use in past 30 days, LOGICALLY A'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircgrlf   1='(1) Used in lifetime' 9='(9) Never used cigars' ;
  VALUE ircgrmn   1='(1) Used in past 30 days' 2='(2) Did not use in past 30 days'
                  9='(9) Never used cigars' ;
  VALUE iicgrlf   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iicgrmn   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE cgrflag   0='(0) Never used (IRCGRLF = 9)' 1='(1) Ever used (IRCGRLF = 1)' ;
  VALUE cgrmon    0='(0) Did not use in the past month (IRCGRMN ='
                  1='(1) Used within the past month (IRCGRMN = 1)' ;
  VALUE mjformer  0='(0) Otherwise' 1='(1) Used marijuana in lifetime, but not in p' ;
  VALUE mjnever   0='(0) Otherwise' 1='(1) Did not use marijuana in lifetime or pas' ;
  VALUE ccformer  0='(0) Otherwise' 1='(1) Used cocaine in lifetime, but not in pas' ;
  VALUE ccnever   0='(0) Otherwise' 1='(1) Did not use cocaine in lifetime or past' ;
  VALUE mdesfs1f  99='(99) LEGITIMATE SKIP' ;
  VALUE mdesfs3f  99='(99) LEGITIMATE SKIP' ;
  VALUE probmdef  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE probmd0f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE mde1ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE mde3ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE gadsfs1f  99='(99) LEGITIMATE SKIP' ;
  VALUE gadsfs3f  99='(99) LEGITIMATE SKIP' ;
  VALUE probgadf  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE probga0f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE gad1ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE gad3ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE agpsfs1f  99='(99) LEGITIMATE SKIP' ;
  VALUE agpsfs3f  99='(99) LEGITIMATE SKIP' ;
  VALUE probagpf  99='(99) LEGITIMATE SKIP' ;
  VALUE probag0f  99='(99) LEGITIMATE SKIP' ;
  VALUE agp1ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE agp3ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE pasfs1ff  99='(99) LEGITIMATE SKIP' ;
  VALUE pasfs3ff  99='(99) LEGITIMATE SKIP' ;
  VALUE probpa1f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE probpa3f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE pa1fffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE pa3fffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE eiidate   1='(1) Interview date established from question'
                  2='(2) Interview date logically imputed' ;
  VALUE bhour     96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE bmin      96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE bap       1='(1) AM' 2='(2) PM' 98='(98) BLANK (NO ANSWER)' ;
  VALUE etimehr   96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE etimemn   96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eap       1='(1) AM' 2='(2) PM' 98='(98) BLANK (NO ANSWER)' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' ;
  VALUE undint    1='(1) No difficulty--no language or reading pr'
                  2='(2) Just a little difficulty--almost no lang'
                  3='(3) A fair amount of difficulty--some lang/r'
                  4='(4) A lot of difficulty--considerable lang/r' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able t'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in the room or listening 1/3 o'
                  7='(7) Serious interruption of privacy more tha'
                  9='(9) Constant presence of other person(s)'
                  85='(85) BAD DATA Logically assigned' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE spres     2='(2) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE parpres   3='(3) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oarpres   4='(4) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oapres    5='(5) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cpres     6='(6) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresnsp  7='(7) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresspa  10='(10) Spouse' 20='(20) Parent/Guardian'
                  30='(30) Own Child/Own Half Child' 33='(33) Grandchild'
                  37='(37) Child, Relation Unspecified' 40='(40) Sibling'
                  50='(50) Grandparent/Great+ Grandparent'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin/Cousins Spouse'
                  83='(83) Nurse/Health Care Aide/Home Care Worker'
                  84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  90='(90) Other Relative, Gender not specified'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  111='(111) Ex-Husband' 120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F'
                  122='(122) Father/Step Father/Future Father In-Law' 130='(130) Son'
                  132='(132) Son In-Law' 133='(133) Grandson' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 172='(172) Nephew'
                  191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 231='(231) Step/Adopted/Foster Daughter'
                  232='(232) Daughter In-Law' 233='(233) Granddaughter'
                  237='(237) Female child, Relation Unspecified'
                  240='(240) Sister/Half Sister'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  272='(272) Niece' 282='(282) Female Housekeeper/Maid/Caretaker/Butler'
                  291='(291) Other Female Non-Relative'
                  337='(337) Children, Relation Unspecified' 340='(340) Siblings'
                  350='(350) Grandparents/Great+ Grandparents'
                  361='(361) Friends/Roommates/Companions'
                  371='(371) Cousins/Cousins Spouses'
                  384='(384) Neighbors/Co-Workers/Visitors/Employees/'
                  390='(390) Other Relatives, Gender not specified'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified' 430='(430) Sons'
                  440='(440) Brothers/Half Brothers'
                  492='(492) Other Males, Relation Unspecified' 530='(530) Daughters'
                  533='(533) Granddaughters' 540='(540) Sisters/Half Sisters'
                  561='(561) Female Fiancees/Girlfriends/Roommates/Co'
                  900='(900) NOT A PERSON' 985='(985) BAD DATA Logically assigned'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE opresspb  61='(61) Friend/Roommate/Companion'
                  91='(91) Other Non-Relative, Gender not specified' 130='(130) Son'
                  140='(140) Brother/Half Brother'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 172='(172) Nephew'
                  240='(240) Sister/Half Sister'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa'
                  291='(291) Other Female Non-Relative'
                  337='(337) Children, Relation Unspecified'
                  361='(361) Friends/Roommates/Companions'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  540='(540) Sisters/Half Sisters' 900='(900) NOT A PERSON'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE whomarkd  1='(1) Respondent marked all the Answer Sheet r'
                  2='(2) Interviewer marked all the Answer Sheet'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE quarter   1='(1) Quarter 1' 2='(2) Quarter 2' 3='(3) Quarter 3' 4='(4) Quarter 4' ;
  VALUE famskip   0='(0) Respondent has other family members in h'
                  1='(1) Respondent didnt have other family in h' ;
  VALUE gqtype    1='(1) Halfway House' 2='(2) Boarding House' 3='(3) College Dorm'
                  4='(4) Shelter' 5='(5) Other' 9='(9) Not Group Quarters' ;
  VALUE pden      1='(1) Segment in a MSA with 1 million or more'
                  2='(2) Segment in a MSA with fewer than 1 milli'
                  3='(3) Segment not in MSA' ;
  VALUE pden2fff  1='(1) Segment in MSA with 1 million or more pe'
                  2='(2) Segm. in a MSA from 250000 to 999999 per'
                  3='(3) Segment in a MSA with fewer than 250000'
                  4='(4) Segment not in a MSA and not in a rural'
                  5='(5) Segment not in a MSA and in a rural area' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE hsphconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE hsppconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE nhbhconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE nhbpconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE ownoconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 pcnt' ;
  VALUE rurorurb  1='(1) Rural' 2='(2) Urban' ;
  VALUE alcdaysf  1='(1) None or never used alcohol (ALCDAYS=81,8'
                  2='(2) 1-2 days (ALCDAYS = 1-2)' 3='(3) 3-4 days (ALCDAYS = 3-4)'
                  4='(4) 5-19 days (ALCDAYS = 5-19)'
                  5='(5) 20-30 days (ALCDAYS = 20-30)'
                  6='(6) UNKNOWN (ALCDAYS = 85,94,95,97,98)' ;
  VALUE alcday0f  1='(1) 0 (ALCDAYS2 = 1)' 2='(2) 1-4 (ALCDAYS2 = 2,3)'
                  3='(3) 5-19 (ALCDAYS2 = 4)' 4='(4) 20-30 (ALCDAYS2 = 5)'
                  6='(6) UNKNOWN (ALCDAYS2 = 6)' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes (ALCFLAG = 1 AND SUMFLAG = 1)' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes (ALCMON = 1 AND SUMMON = 1)' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes (ALCYR = 1 AND SUMYR = 1)' ;
  VALUE alcmrjl   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjm   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjy   0='(0) No' 1='(1) Yes' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=0)' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=0)' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=0)' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes' ;
  VALUE alcprbsf  0='(0) No' 1='(1) Yes (ANY SOURCE VARIABLE = 1)' ;
  VALUE alc2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE alc3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE alcpsyl   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsym   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsyy   0='(0) No' 1='(1) Yes' ;
  VALUE alctry2f  99='(99) NEVER USED/UNKNOWN (ALCTRY = 981-998)' ;
  VALUE alcuse    1='(1) Less than 12 days (IRALCFQ=7-9)'
                  2='(2) 12-50 days (1-4 days/month) (IRALCFQ=5-6'
                  3='(3) 51-300 days (1-7 days/week) (IRALCFQ=2-4'
                  4='(4) More than 300 days (daily or almost) (IR'
                  5='(5) HAS NOT USED IN PAST YEAR (IRALCFQ=10)' ;
  VALUE analagef  99='(99) NEVER USED/UNKNOWN (ANALAGE = 981-998)' ;
  VALUE any4ment  0='(0) No' 1='(1) Yes (MDE3 or GAD3 or PA3 or AGP3 = 1)'
                  99='(99) Children age 12-17 (CATAGE = 1)' ;
  VALUE avcig2ff  1='(1) 0 (AVCIG = 81,83,91,93)'
                  2='(2) 15 cigarettes or less (AVCIG = 1-3)'
                  3='(3) 16 cigarettes or more (AVCIG = 4-6)'
                  4='(4) UNKNOWN (AVCIG = 85,94,98)' ;
  VALUE avcig3ff  0='(0) No (AVCIG = 1-3,81,83,85,91,93,94,98)'
                  1='(1) Yes (AVCIG = 4-6)' ;
  VALUE bingdrkf  0='(0) No (BINGEDRK = 99 OR BINGEDRK = 0)'
                  1='(1) Yes (BINGEDRK = 1)' ;
  VALUE bkagaslf  0='(0) No (BKAGASLT = 2,85,89,97,98,99)'
                  1='(1) Yes (BKAGASLT = 1,3)' ;
  VALUE bkarsonf  0='(0) No (BKARSON = 2,85,89,97,98,99)' 1='(1) Yes (BKARSON = 1)' ;
  VALUE bkburglf  0='(0) No (BKBURGL = 2,85,89,97,98,99)' 1='(1) Yes (BKBURGL = 1,3)' ;
  VALUE bkdrug2f  0='(0) No (BKDRUG = 2,85,89,97,98,99)' 1='(1) Yes (BKDRUG = 1)' ;
  VALUE bkdrunkf  0='(0) No (BKDRUNK = 2,85,89,97,98,99)' 1='(1) Yes (BKRUNK = 1,3)' ;
  VALUE bkdrvi0f  0='(0) No (BKDRVINF = 2,85,89,97,98,99)'
                  1='(1) Yes (BKDRVINF = 1,3)' ;
  VALUE bklarcnf  0='(0) No (BKLARCNY = 2,85,89,97,98,99)'
                  1='(1) Yes (BKLARCNY = 1,3)' ;
  VALUE bkmvthff  0='(0) No (BKMVTHFT = 2,85,89,97,98,99)' 1='(1) Yes (BKMVTHFT = 1)' ;
  VALUE bkrob2ff  0='(0) No (BKROB = 2,85,89,97,98,99)' 1='(1) Yes (BKROB = 1,3)' ;
  VALUE bksmaslf  0='(0) No (BKSMASLT = 2,85,89,97,98,99)'
                  1='(1) Yes (BKMASLT = 1,3)' ;
  VALUE cigprbsf  0='(0) No' 1='(1) Yes (ANY SOURCE VARIABLE = 1)' ;
  VALUE cig2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE cig3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE cigtry2f  99='(99) NEVER USED/UNKNOWN (CIGTRY = 981-998)' ;
  VALUE cocage2f  99='(99) NEVER USED/UNKNOWN (COCAGE = 981-998)' ;
  VALUE cocprbsf  0='(0) No' 1='(1) Yes (ANY SOURCE VARIABLE = 1)' ;
  VALUE coc2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE coc3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE coctot3f  1='(1) 1-2 days (COCTOT = 5)' 2='(2) 3-11 days (COCTOT = 4)'
                  3='(3) 12-100 days (COCTOT = 3)' 4='(4) 101+ days (COCTOT = 1,2)'
                  5='(5) NEVER USED (COCTOT = 81,91)'
                  99='(99) UNKNOWN (COCTOT = 85,98)' ;
  VALUE cocuse    1='(1) Less than 12 days (IRCOCFQ=7-9)'
                  2='(2) 12-50 days (1-4 days/month) (IRCOCFQ=5-6'
                  3='(3) 51-300 days (1-7 days/week) (IRCOCFQ=2-4'
                  4='(4) More than 300 days (daily or almost) (IR'
                  5='(5) Has not used in past year (IRCOCFQ=10)' ;
  VALUE dralhlpf  0='(0) No (TRMTHLP3=0 and DRNKHLP3=0)'
                  1='(1) Yes (TRMTHLP3=1 or DRNKHLP3=1)' 99='(99) UNKNOWN (Otherwise)' ;
  VALUE drinkerf  0='(0) No' 1='(1) Yes (DR5DAY=1-30,90 OR ALCMON=1)' ;
  VALUE drnkhlpf  0='(0) No (Otherwise)'
                  1='(1) Yes (ANY SOURCE VAR=1,3,5 and ALCFLAG=1)'
                  99='(99) NON USER/TRT (ANY SOURCE VAR=1,3,5 and A' ;
  VALUE drunkyrf  1='(1) Yes (DRUNKYR = 1,2,3,4)'
                  2='(2) No (DRUNKYR=5,6,7,8,9,81,83,85,90,91,93,' ;
  VALUE drunky0f  0='(0) No (DRUNKYR GT 8)' 1='(1) Yes (DRUNKYR LE 8)'
                  99='(99) Children age 12-17 (CATAGE = 1)' ;
  VALUE dui       0='(0) No' 1='(1) Yes (ANY SOURCE VAR=1)& (ALCYR=1 or SUMY' ;
  VALUE fertage   1='(1) Women ages 15-25 (CATAG3 = 1,2 AND F15_4'
                  2='(2) Women ages 16-44 (CATAG3 = 3,4 AND F15_4'
                  99='(99) MEN/WOMEN AGE 12-14 and 45+ (F15_44=0)' ;
  VALUE hallagef  99='(99) NEVER USED/UNKNOWN (HALLAGE = 981-998)' ;
  VALUE herage2f  99='(99) NEVER USED/UNKNOWN (HERAGE = 981-998)' ;
  VALUE herneedf  0='(0) No (HERNEEDL=81,85,89,91,93,97,98,99)'
                  1='(1) Yes (HERNEEDL=1,3)' ;
  VALUE hvydrk3f  0='(0) No (HVYDRK2 = 99 OR HVYDRK2 = 0)' 1='(1) Yes (HVYDRK2 = 1)' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes (SUMFLAG=1 AND ALCFLAG=0)' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes (SUMMON=1 AND ALCMON=0)' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes (SUMYR=1 AND ALCYR=0)' ;
  VALUE inhage2f  99='(99) NEVER USED/UNKNOWN (INHAGE = 981-998)' ;
  VALUE iracalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and ACRDALC = 1)' ;
  VALUE iraccigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and ACRDCIG = 1)' ;
  VALUE iraccocf  0='(0) No' 1='(1) Yes (COCYR = 1 and ACRDCOC = 1)' ;
  VALUE iracmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and ACRDMRJ = 1)' ;
  VALUE irbtalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and BTOLALC = 1)' ;
  VALUE irbtcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and BTOLCIG = 1)' ;
  VALUE irbtcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and BTOLCOC = 1)' ;
  VALUE irbtmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and BTOLMRJ = 1)' ;
  VALUE iremalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and EMPBALC = 1)' ;
  VALUE iremcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and EMPBCIG = 1)' ;
  VALUE iremcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and EMPBCOC = 1)' ;
  VALUE iremmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and EMPBMRJ = 1)' ;
  VALUE irgralcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and GRTMALC = 1)' ;
  VALUE irgrcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and GRTMCIG = 1)' ;
  VALUE irgrcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and GRTMCOC = 1)' ;
  VALUE irgrmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and GRTMMRJ = 1)' ;
  VALUE irhlalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and HLPBALC = 1)' ;
  VALUE irhlcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and HLPBCIG = 1)' ;
  VALUE irhlcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and HLPBCOC = 1)' ;
  VALUE irhlmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and HLPBMRJ = 1)' ;
  VALUE irlaalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and LAMTALC = 1)' ;
  VALUE irlacigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and LAMTCIG = 1)' ;
  VALUE irlacocf  0='(0) No' 1='(1) Yes (COCYR = 1 and LAMTCOC = 1)' ;
  VALUE irlamrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and LAMTMRJ = 1)' ;
  VALUE irucalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and UCDALC = 1)' ;
  VALUE iruccigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and UCDCIG = 1)' ;
  VALUE iruccocf  0='(0) No' 1='(1) Yes (COCYR = 1 and UCDCOC = 1)' ;
  VALUE irucmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and UCDMRJ = 1)' ;
  VALUE maruse    1='(1) Less than 12 days (IRMJFQ = 7-9)'
                  2='(2) 12-50 days (1-4 days/month) (IRMJFQ = 5-'
                  3='(3) 51-300 days (1-7 days/week) (IRMJFQ = 2-'
                  4='(4) More than 300 days (daily or almost) (IR'
                  5='(5) Did not use in past year (IRMJFQ = 10)' ;
  VALUE mjage2ff  99='(99) NEVER USED/UNKNOWN (MJAGE = 981-998)' ;
  VALUE mrjprbsf  0='(0) No' 1='(1) (ANY SOURCE VARIABLE = 1)' ;
  VALUE mrj2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE mrj3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE mjtot3ff  1='(1) 1-2 days (MJTOT = 5)' 2='(2) 3-11 days (MJTOT = 4)'
                  3='(3) 12-100 days (MJTOT = 3)' 4='(4) 101+ days (MJTOT = 1,2)'
                  5='(5) NEVER USED (MJTOT = 81,91)'
                  99='(99) UNKNOWN (MJTOT = 85,97,98)' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes (MJOFLAG=1 AND ALCFLAG=0)' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes (MJOMON2=1 AND ALCMON=0)' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes (MJOYR2=1 AND ALCYR=0)' ;
  VALUE notmarj   0='(0) No (All Source Variables = 0)'
                  1='(1) Yes (All Source Variables = 1)' ;
  VALUE othonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE othonlym  0='(0) No' 1='(1) Yes' ;
  VALUE othonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE preg3fff  1='(1) Pregnant (PREG2 = 1 and F15_44 = 1)'
                  2='(2) Not pregnant (PREG2 = 2 and F15_44 = 1)'
                  99='(99) Men/Women 12-14 and 45+ (F14_44=0)' ;
  VALUE psyage    99='(99) NEVER USED/UNKNOWN (ALL SOURCE VARS = 98' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE racesex   1='(1) White male (IRSEX = 1 AND RACE = 1)'
                  2='(2) Black male (IRSEX = 1 AND RACE = 2)'
                  3='(3) Hispanic male (IRSEX = 1 AND RACE = 3)'
                  4='(4) White female (IRSEX = 2 AND RACE = 1)'
                  5='(5) Black female (IRSEX = 2 AND RACE = 2)'
                  6='(6) Hispanic female (IRSEX = 2 AND RACE = 3)'
                  99='(99) Other Males and Females (IRSEX=1,2 and R' ;
  VALUE racesexf  1='(1) White male (IRSEX = 1 AND RACE = 1)'
                  2='(2) Black male (IRSEX = 1 AND RACE = 2)'
                  3='(3) Hispanic male (IRSEX = 1 AND RACE = 3)'
                  4='(4) Other male (IRSEX = 1 AND RACE = 4)'
                  5='(5) White female (IRSEX = 2 AND RACE = 1)'
                  6='(6) Black female (IRSEX = 2 AND RACE = 2)'
                  7='(7) Hispanic female (IRSEX = 2 AND RACE = 3)'
                  8='(8) Other female (IRSEX = 2 AND RACE = 4)' ;
  VALUE rdifcoc   0='(0) Not easy (RKDIFCOC = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFCOC'
                  99='(99) UNKNOWN (RKDIFCOC = 94,96,97,98)' ;
  VALUE rdifcrk   0='(0) Not easy (RKDIFCRK = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFCRK'
                  99='(99) UNKNOWN (RKDIFCRK = 94,96,97,98)' ;
  VALUE rdifher   0='(0) Not easy (RKDIFHER = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFHER'
                  99='(99) UNKNOWN (RKDIFHER = 94,96,97,98)' ;
  VALUE rdiflsd   0='(0) Not easy (RKDIFLSD = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFLSD'
                  99='(99) UNKNOWN (RKDIFLSD = 94,96,97,98)' ;
  VALUE rdifmj    0='(0) Not easy (RKDIFMJ = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFMJ ='
                  99='(99) UNKNOWN (RKDIFMJ = 94,96,97,98)' ;
  VALUE rskalc1f  0='(0) No (RK5DRINK = 1,2,3)' 1='(1) Yes (RK5DRINK = 4)'
                  99='(99) UNKNOWN (RK5DRINK = 94,96,97,98)' ;
  VALUE rskalc2f  0='(0) No (RSKBINGE = 1,2,3)' 1='(1) Yes (RSKBINGE = 4)'
                  99='(99) UNKNOWN (RSKBINGE = 94,96,97,98)' ;
  VALUE rskcig    0='(0) No (RSKPKCIG = 1,2,3)' 1='(1) Yes (RSKPKCIG = 4)'
                  99='(99) UNKNOWN (RSKPKCIG = 94,96,97,98)' ;
  VALUE rskcoc1f  0='(0) No (RKCOCOCC = 1,2,3)' 1='(1) Yes (RKCOCOCC = 4)'
                  99='(99) UNKNOWN (RKCOCOCC = 94,96,97,98)' ;
  VALUE rskcoc2f  0='(0) No (RKCOCREG = 1,2,3)' 1='(1) Yes (RKCOCREG = 4)'
                  99='(99) UNKNOWN (RKCOCREG = 94,96,97,98)' ;
  VALUE rskher1f  0='(0) No (RKTRYHER = 1,2,3)' 1='(1) Yes (RKTRYHER = 4)'
                  99='(99) UNKNOWN (RKTRYHER = 94,96,97,98)' ;
  VALUE rskher2f  0='(0) No (RKHERREG = 1,2,3)' 1='(1) Yes (RKHERREG = 4)'
                  99='(99) UNKNOWN (RKHERREG = 94,96,97,98)' ;
  VALUE rsklsd1f  0='(0) No (RKTRYLSD = 1,2,3)' 1='(1) Yes (RKTRYLSD = 4)'
                  99='(99) UNKNOWN (RKTRYLSD = 94,96,97,98)' ;
  VALUE rskmj1ff  0='(0) No (RSKMJOCC = 1,2,3)' 1='(1) Yes (RSKMJOCC = 4)'
                  99='(99) UNKNOWN (RSKMJOCC = 94,96,97,98)' ;
  VALUE rskmj2ff  0='(0) No (RSKMJREG = 1,2,3)' 1='(1) Yes (RSKMJREG = 4)'
                  99='(99) UNKNOWN (RSKMJREG = 94,96,97,98)' ;
  VALUE rsksellf  0='(0) No (RSKSELL = 2,96,97,98)' 1='(1) Yes (RSKSELL = 1)' ;
  VALUE sbeltrsk  0='(0) No' 1='(1) Yes (RKFQPBLT = 1,2 or RKFQDBLT = 1,2)' ;
  VALUE sedage2f  99='(99) NEVER USED/UNKNOWN (SEDAGE = 981-998)' ;
  VALUE stimagef  99='(99) NEVER USED/UNKNOWN (STIMAGE = 981-998)' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes (Only one Source Var=1)' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes (Only one Source Var=1)' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes (Only one Source Var=1)' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes (Only two Source Vars=1)' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes (Only two Source Vars=1)' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes (Only two Source Vars=1)' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes (3 or More Source Vars=1)' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes (3 or More Source Vars=1)' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes (3 or More Source Vars=1)' ;
  VALUE tranagef  99='(99) NEVER USED/UNKNOWN (TRANAGE = 981-998)' ;
  VALUE trimestf  1='(1) 1st 3 mos of pregnancy (TRIMEST=1 AND F1'
                  2='(2) 2nd 3 mos of pregnancy (TRIMEST=2 AND F1'
                  3='(3) Last 3 mos of pregnancy (TRIMEST=3 AND F'
                  99='(99) Otherwise (TRIMEST NE 1,2,3 or F15_44=0)' ;
  VALUE trmthlpf  0='(0) No (Otherwise)'
                  1='(1) Yes (ANY SOURCE VAR=1,3,5 and SUMFLAG=1)'
                  99='(99) NON USER/TRT (ANY SOURCE VAR=1,3,5 and S' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (ENCPSU >= 981) THEN ENCPSU = .;
   IF (SKPMARTL = 9) THEN SKPMARTL = .;
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (NOMARR >= 81) THEN NOMARR = .;
   IF (SKPMILT = 9) THEN SKPMILT = .;
   IF (SERVICE >= 81) THEN SERVICE = .;
   IF (MILSTAT >= 81) THEN MILSTAT = .;
   IF (EDUC >= 81) THEN EDUC = .;
   IF (DIPLOMA >= 81) THEN DIPLOMA = .;
   IF (ENROLL97 >= 81) THEN ENROLL97 = .;
   IF (ENRL9497 >= 81) THEN ENRL9497 = .;
   IF (WORKSTAT >= 81) THEN WORKSTAT = .;
   IF (HTININCH >= 981) THEN HTININCH = .;
   IF (POUNDS >= 981) THEN POUNDS = .;
   IF (HEALTH >= 81) THEN HEALTH = .;
   IF (CIGEVER >= 81) THEN CIGEVER = .;
   IF (CIGTRY >= 981) THEN CIGTRY = .;
   IF (CIGTOT >= 81) THEN CIGTOT = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (CIG30USE >= 35) THEN CIG30USE = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (CIG30WOK >= 81) THEN CIG30WOK = .;
   IF (CIGEVYDA >= 81) THEN CIGEVYDA = .;
   IF (CIGAGE >= 981) THEN CIGAGE = .;
   IF (CIGYRS >= 981) THEN CIGYRS = .;
   IF (SNUFEVER >= 81) THEN SNUFEVER = .;
   IF (SNUFREC >= 81) THEN SNUFREC = .;
   IF (SKPALCRD >= 81) THEN SKPALCRD = .;
   IF (ALCREAD >= 81) THEN ALCREAD = .;
   IF (ALCEVER = 9) THEN ALCEVER = .;
   IF (ALCTRY >= 981) THEN ALCTRY = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (ALCPAT >= 81) THEN ALCPAT = .;
   IF (DRUNKYR >= 81) THEN DRUNKYR = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (NODR30A >= 81) THEN NODR30A = .;
   IF (DR5DAY >= 35) THEN DR5DAY = .;
   IF (MJEVER = 9) THEN MJEVER = .;
   IF (MJAGE >= 981) THEN MJAGE = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (MJYRFREQ >= 81) THEN MJYRFREQ = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (SKPCOCRD >= 81) THEN SKPCOCRD = .;
   IF (COCREAD >= 81) THEN COCREAD = .;
   IF (COCEVER = 9) THEN COCEVER = .;
   IF (COCAGE >= 981) THEN COCAGE = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (COCYRFRQ >= 81) THEN COCYRFRQ = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (SKPCRKRD >= 81) THEN SKPCRKRD = .;
   IF (CRKREAD >= 81) THEN CRKREAD = .;
   IF (CRKEVER >= 81) THEN CRKEVER = .;
   IF (CRKAGE >= 981) THEN CRKAGE = .;
   IF (CRKTOT >= 81) THEN CRKTOT = .;
   IF (CRAKREC >= 81) THEN CRAKREC = .;
   IF (CRKYRFRQ >= 81) THEN CRKYRFRQ = .;
   IF (CRKUS30A >= 81) THEN CRKUS30A = .;
   IF (SKPHERRD >= 81) THEN SKPHERRD = .;
   IF (HERREAD >= 81) THEN HERREAD = .;
   IF (HEREVER >= 81) THEN HEREVER = .;
   IF (HERAGE >= 981) THEN HERAGE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HERYRFRQ >= 81) THEN HERYRFRQ = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (SKPHALRD >= 81) THEN SKPHALRD = .;
   IF (HALREAD >= 81) THEN HALREAD = .;
   IF (LSD >= 81) THEN LSD = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (PEYOTE >= 81) THEN PEYOTE = .;
   IF (MESC >= 81) THEN MESC = .;
   IF (PSILCY >= 81) THEN PSILCY = .;
   IF (ECSTASY >= 81) THEN ECSTASY = .;
   IF (HALDKNAM >= 81) THEN HALDKNAM = .;
   IF (HALNOLST >= 81) THEN HALNOLST = .;
   IF (HALNEWA >= 9981) THEN HALNEWA = .;
   IF (HALNEWB >= 9981) THEN HALNEWB = .;
   IF (HALNEWC >= 9981) THEN HALNEWC = .;
   IF (HALNEWD >= 9981) THEN HALNEWD = .;
   IF (HALNEWE >= 9981) THEN HALNEWE = .;
   IF (HALLAGE >= 981) THEN HALLAGE = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HALYRFRQ >= 81) THEN HALYRFRQ = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (LSDREC >= 81) THEN LSDREC = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (SKPINHRD >= 81) THEN SKPINHRD = .;
   IF (INHREAD >= 81) THEN INHREAD = .;
   IF (AMYLNIT >= 81) THEN AMYLNIT = .;
   IF (CLEFLU >= 81) THEN CLEFLU = .;
   IF (GAS >= 81) THEN GAS = .;
   IF (GLUE >= 81) THEN GLUE = .;
   IF (ETHER >= 81) THEN ETHER = .;
   IF (SOLVENT >= 81) THEN SOLVENT = .;
   IF (LGAS >= 81) THEN LGAS = .;
   IF (NITOXID >= 81) THEN NITOXID = .;
   IF (SPPAINT >= 81) THEN SPPAINT = .;
   IF (AEROS >= 81) THEN AEROS = .;
   IF (INHDKNAM >= 81) THEN INHDKNAM = .;
   IF (INHNOLST >= 81) THEN INHNOLST = .;
   IF (INHNEWA >= 9981) THEN INHNEWA = .;
   IF (INHNEWB >= 9981) THEN INHNEWB = .;
   IF (INHNEWC >= 9981) THEN INHNEWC = .;
   IF (INHNEWD >= 9981) THEN INHNEWD = .;
   IF (INHNEWE >= 9981) THEN INHNEWE = .;
   IF (INHAGE >= 981) THEN INHAGE = .;
   IF (INHTOT >= 81) THEN INHTOT = .;
   IF (INHREC >= 81) THEN INHREC = .;
   IF (INHYRFRQ >= 81) THEN INHYRFRQ = .;
   IF (INHDY30A >= 81) THEN INHDY30A = .;
   IF (SKPANLRD >= 81) THEN SKPANLRD = .;
   IF (ANLREAD >= 81) THEN ANLREAD = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (METHDON >= 81) THEN METHDON = .;
   IF (MORPHINE >= 81) THEN MORPHINE = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (TALWIN >= 81) THEN TALWIN = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (ANLDKNAM >= 81) THEN ANLDKNAM = .;
   IF (ANLNOLST >= 81) THEN ANLNOLST = .;
   IF (ANALNEWA >= 9981) THEN ANALNEWA = .;
   IF (ANALNEWB >= 9981) THEN ANALNEWB = .;
   IF (ANALNEWC >= 9981) THEN ANALNEWC = .;
   IF (ANALNEWD >= 9981) THEN ANALNEWD = .;
   IF (ANALNEWE >= 9981) THEN ANALNEWE = .;
   IF (ANALNONE >= 81) THEN ANALNONE = .;
   IF (ANALAGE >= 981) THEN ANALAGE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (ANLYRFRQ >= 81) THEN ANLYRFRQ = .;
   IF (SKPTRNRD >= 81) THEN SKPTRNRD = .;
   IF (TRNREAD >= 81) THEN TRNREAD = .;
   IF (ATARAX >= 81) THEN ATARAX = .;
   IF (ATIVAN >= 81) THEN ATIVAN = .;
   IF (DIAZEPAM >= 81) THEN DIAZEPAM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (XANAX >= 81) THEN XANAX = .;
   IF (TRDKNAM >= 81) THEN TRDKNAM = .;
   IF (TRNOLST >= 81) THEN TRNOLST = .;
   IF (TRNEWA >= 9981) THEN TRNEWA = .;
   IF (TRNEWB >= 9981) THEN TRNEWB = .;
   IF (TRNEWC >= 9981) THEN TRNEWC = .;
   IF (TRNEWD >= 9981) THEN TRNEWD = .;
   IF (TRNEWE >= 9981) THEN TRNEWE = .;
   IF (NOTRANQ >= 81) THEN NOTRANQ = .;
   IF (TRANAGE >= 981) THEN TRANAGE = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (TRNYRFRQ >= 81) THEN TRNYRFRQ = .;
   IF (SKPSTMRD >= 81) THEN SKPSTMRD = .;
   IF (STMREAD >= 81) THEN STMREAD = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (FASTIN >= 81) THEN FASTIN = .;
   IF (IONAMIN >= 81) THEN IONAMIN = .;
   IF (METHAMP >= 81) THEN METHAMP = .;
   IF (METHI >= 81) THEN METHI = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (STMDKNAM >= 81) THEN STMDKNAM = .;
   IF (STMNOLST >= 81) THEN STMNOLST = .;
   IF (STIMNEWA >= 9981) THEN STIMNEWA = .;
   IF (STIMNEWB >= 9981) THEN STIMNEWB = .;
   IF (STIMNEWC >= 9981) THEN STIMNEWC = .;
   IF (STIMNEWD >= 9981) THEN STIMNEWD = .;
   IF (STIMNEWE >= 9981) THEN STIMNEWE = .;
   IF (NOSTIMS >= 81) THEN NOSTIMS = .;
   IF (STIMAGE >= 981) THEN STIMAGE = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STMYRFRQ >= 81) THEN STMYRFRQ = .;
   IF (SKPSEDRD >= 81) THEN SKPSEDRD = .;
   IF (SEDREAD >= 81) THEN SEDREAD = .;
   IF (DALMANE >= 81) THEN DALMANE = .;
   IF (HALCION >= 81) THEN HALCION = .;
   IF (METHAQ >= 81) THEN METHAQ = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (PHENOBAR >= 81) THEN PHENOBAR = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (SEDDKNAM >= 81) THEN SEDDKNAM = .;
   IF (SEDNOLST >= 81) THEN SEDNOLST = .;
   IF (SEDNEWA >= 9981) THEN SEDNEWA = .;
   IF (SEDNEWB >= 9981) THEN SEDNEWB = .;
   IF (SEDNEWC >= 9981) THEN SEDNEWC = .;
   IF (SEDNEWD >= 9981) THEN SEDNEWD = .;
   IF (SEDNEWE >= 9981) THEN SEDNEWE = .;
   IF (NOSEDAT >= 81) THEN NOSEDAT = .;
   IF (SEDAGE >= 981) THEN SEDAGE = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (SEDYRFRQ >= 81) THEN SEDYRFRQ = .;
   IF (BIRMONTH >= 81) THEN BIRMONTH = .;
   IF (BIRYEAR >= 9981) THEN BIRYEAR = .;
   IF (EIBDATE = 9) THEN EIBDATE = .;
   IF (IIAGE = 9) THEN IIAGE = .;
   IF (IRSEX = 9) THEN IRSEX = .;
   IF (IISEX = 9) THEN IISEX = .;
   IF (IRRACE = 9) THEN IRRACE = .;
   IF (IIRACE = 9) THEN IIRACE = .;
   IF (IRHOIND = 9) THEN IRHOIND = .;
   IF (IIHOIND = 9) THEN IIHOIND = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP = 9) THEN IIHOGRP = .;
   IF (IRHOGRP2 >= 81) THEN IRHOGRP2 = .;
   IF (IIHOGRP2 = 9) THEN IIHOGRP2 = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT = 9) THEN IIMARIT = .;
   IF (IREDUC >= 81) THEN IREDUC = .;
   IF (IIEDUC = 9) THEN IIEDUC = .;
   IF (IRHSGRAD = 9) THEN IRHSGRAD = .;
   IF (IIHSGRAD = 9) THEN IIHSGRAD = .;
   IF (IRWORKST >= 81) THEN IRWORKST = .;
   IF (IIWORKST = 9) THEN IIWORKST = .;
   IF (IRCIGRC = 9) THEN IRCIGRC = .;
   IF (IICIGRC = 9) THEN IICIGRC = .;
   IF (IROTBRC = 9) THEN IROTBRC = .;
   IF (IIOTBRC = 9) THEN IIOTBRC = .;
   IF (IRALCRC = 9) THEN IRALCRC = .;
   IF (IIALCRC = 9) THEN IIALCRC = .;
   IF (IRMJRC = 9) THEN IRMJRC = .;
   IF (IIMJRC = 9) THEN IIMJRC = .;
   IF (IRCOCRC = 9) THEN IRCOCRC = .;
   IF (IICOCRC = 9) THEN IICOCRC = .;
   IF (IRCRKRC = 9) THEN IRCRKRC = .;
   IF (IICRKRC = 9) THEN IICRKRC = .;
   IF (IRHERRC = 9) THEN IRHERRC = .;
   IF (IIHERRC = 9) THEN IIHERRC = .;
   IF (IRHALRC = 9) THEN IRHALRC = .;
   IF (IIHALRC = 9) THEN IIHALRC = .;
   IF (IRLSDRC = 9) THEN IRLSDRC = .;
   IF (IILSDRC = 9) THEN IILSDRC = .;
   IF (IRPCPRC = 9) THEN IRPCPRC = .;
   IF (IIPCPRC = 9) THEN IIPCPRC = .;
   IF (IRINHRC = 9) THEN IRINHRC = .;
   IF (IIINHRC = 9) THEN IIINHRC = .;
   IF (IRANLRC = 9) THEN IRANLRC = .;
   IF (IIANLRC = 9) THEN IIANLRC = .;
   IF (IRTRNRC = 9) THEN IRTRNRC = .;
   IF (IITRNRC = 9) THEN IITRNRC = .;
   IF (IRSTMRC = 9) THEN IRSTMRC = .;
   IF (IISTMRC = 9) THEN IISTMRC = .;
   IF (IRSEDRC = 9) THEN IRSEDRC = .;
   IF (IISEDRC = 9) THEN IISEDRC = .;
   IF (IRALCFQ >= 81) THEN IRALCFQ = .;
   IF (IIALCFQ = 9) THEN IIALCFQ = .;
   IF (IRMJFQ >= 81) THEN IRMJFQ = .;
   IF (IIMJFQ = 9) THEN IIMJFQ = .;
   IF (IRCOCFQ >= 81) THEN IRCOCFQ = .;
   IF (IICOCFQ = 9) THEN IICOCFQ = .;
   IF (IRCRKFQ >= 81) THEN IRCRKFQ = .;
   IF (IICRKFQ = 9) THEN IICRKFQ = .;
   IF (IRHERFQ >= 81) THEN IRHERFQ = .;
   IF (IIHERFQ = 9) THEN IIHERFQ = .;
   IF (IRHALFQ >= 81) THEN IRHALFQ = .;
   IF (IIHALFQ = 9) THEN IIHALFQ = .;
   IF (IRINHFQ >= 81) THEN IRINHFQ = .;
   IF (IIINHFQ = 9) THEN IIINHFQ = .;
   IF (IRANLFQ >= 81) THEN IRANLFQ = .;
   IF (IIANLFQ = 9) THEN IIANLFQ = .;
   IF (IRTRNFQ >= 81) THEN IRTRNFQ = .;
   IF (IITRNFQ = 9) THEN IITRNFQ = .;
   IF (IRSTMFQ >= 81) THEN IRSTMFQ = .;
   IF (IISTMFQ = 9) THEN IISTMFQ = .;
   IF (IRSEDFQ >= 81) THEN IRSEDFQ = .;
   IF (IISEDFQ = 9) THEN IISEDFQ = .;
   IF (CATAGE = 9) THEN CATAGE = .;
   IF (CATAG2 = 9) THEN CATAG2 = .;
   IF (CATAG3 = 9) THEN CATAG3 = .;
   IF (RACE = 9) THEN RACE = .;
   IF (HISPRACE = 9) THEN HISPRACE = .;
   IF (EDUCCAT2 = 9) THEN EDUCCAT2 = .;
   IF (EMPSTAT2 = 9) THEN EMPSTAT2 = .;
   IF (BUSINES2 >= 981) THEN BUSINES2 = .;
   IF (ROCCUP2 >= 981) THEN ROCCUP2 = .;
   IF (MARISTAT = 9) THEN MARISTAT = .;
   IF (NOTMAR = 9) THEN NOTMAR = .;
   IF (CIGFLAG = 9) THEN CIGFLAG = .;
   IF (CIGYR = 9) THEN CIGYR = .;
   IF (CIGMON = 9) THEN CIGMON = .;
   IF (SMKFLAG = 9) THEN SMKFLAG = .;
   IF (SMKYR = 9) THEN SMKYR = .;
   IF (SMKMON = 9) THEN SMKMON = .;
   IF (ALCFLAG = 9) THEN ALCFLAG = .;
   IF (ALCYR = 9) THEN ALCYR = .;
   IF (ALCMON = 9) THEN ALCMON = .;
   IF (MRJFLAG = 9) THEN MRJFLAG = .;
   IF (MRJYR = 9) THEN MRJYR = .;
   IF (MRJMON = 9) THEN MRJMON = .;
   IF (COCFLAG = 9) THEN COCFLAG = .;
   IF (COCYR = 9) THEN COCYR = .;
   IF (COCMON = 9) THEN COCMON = .;
   IF (CRKFLAG = 9) THEN CRKFLAG = .;
   IF (CRKYR = 9) THEN CRKYR = .;
   IF (CRKMON = 9) THEN CRKMON = .;
   IF (HERFLAG = 9) THEN HERFLAG = .;
   IF (HERYR = 9) THEN HERYR = .;
   IF (HERMON = 9) THEN HERMON = .;
   IF (HALFLAG = 9) THEN HALFLAG = .;
   IF (HALYR = 9) THEN HALYR = .;
   IF (HALMON = 9) THEN HALMON = .;
   IF (LSDFLAG = 9) THEN LSDFLAG = .;
   IF (LSDYR = 9) THEN LSDYR = .;
   IF (LSDMON = 9) THEN LSDMON = .;
   IF (PCPFLAG = 9) THEN PCPFLAG = .;
   IF (PCPYR = 9) THEN PCPYR = .;
   IF (PCPMON = 9) THEN PCPMON = .;
   IF (INHFLAG = 9) THEN INHFLAG = .;
   IF (INHYR = 9) THEN INHYR = .;
   IF (INHMON = 9) THEN INHMON = .;
   IF (ANLFLAG = 9) THEN ANLFLAG = .;
   IF (ANLYR = 9) THEN ANLYR = .;
   IF (ANLMON = 9) THEN ANLMON = .;
   IF (TRQFLAG = 9) THEN TRQFLAG = .;
   IF (TRQYR = 9) THEN TRQYR = .;
   IF (TRQMON = 9) THEN TRQMON = .;
   IF (STMFLAG = 9) THEN STMFLAG = .;
   IF (STMYR = 9) THEN STMYR = .;
   IF (STMMON = 9) THEN STMMON = .;
   IF (SEDFLAG = 9) THEN SEDFLAG = .;
   IF (SEDYR = 9) THEN SEDYR = .;
   IF (SEDMON = 9) THEN SEDMON = .;
   IF (ALCYRF = 9) THEN ALCYRF = .;
   IF (ALCMONF = 9) THEN ALCMONF = .;
   IF (ALCWKF = 9) THEN ALCWKF = .;
   IF (ALCOCCF = 9) THEN ALCOCCF = .;
   IF (ALCDLYF = 9) THEN ALCDLYF = .;
   IF (MRJYRF = 9) THEN MRJYRF = .;
   IF (MRJMONF = 9) THEN MRJMONF = .;
   IF (MRJWKF = 9) THEN MRJWKF = .;
   IF (MRJOCCF = 9) THEN MRJOCCF = .;
   IF (MRJDLYF = 9) THEN MRJDLYF = .;
   IF (COCYRF = 9) THEN COCYRF = .;
   IF (COCMONF = 9) THEN COCMONF = .;
   IF (COCWKF = 9) THEN COCWKF = .;
   IF (COCOCCF = 9) THEN COCOCCF = .;
   IF (COCDLYF = 9) THEN COCDLYF = .;
   IF (CRKYRF = 9) THEN CRKYRF = .;
   IF (CRKMONF = 9) THEN CRKMONF = .;
   IF (CRKWKF = 9) THEN CRKWKF = .;
   IF (CRKOCCF = 9) THEN CRKOCCF = .;
   IF (CRKDLYF = 9) THEN CRKDLYF = .;
   IF (HERYRF = 9) THEN HERYRF = .;
   IF (HERMONF = 9) THEN HERMONF = .;
   IF (HERWKF = 9) THEN HERWKF = .;
   IF (HEROCCF = 9) THEN HEROCCF = .;
   IF (HERDLYF = 9) THEN HERDLYF = .;
   IF (HALYRF = 9) THEN HALYRF = .;
   IF (HALMONF = 9) THEN HALMONF = .;
   IF (HALWKF = 9) THEN HALWKF = .;
   IF (HALOCCF = 9) THEN HALOCCF = .;
   IF (HALDLYF = 9) THEN HALDLYF = .;
   IF (INHYRF = 9) THEN INHYRF = .;
   IF (INHMONF = 9) THEN INHMONF = .;
   IF (INHWKF = 9) THEN INHWKF = .;
   IF (INHOCCF = 9) THEN INHOCCF = .;
   IF (INHDLYF = 9) THEN INHDLYF = .;
   IF (ANLYRF = 9) THEN ANLYRF = .;
   IF (ANLMONF = 9) THEN ANLMONF = .;
   IF (ANLWKF = 9) THEN ANLWKF = .;
   IF (ANLOCCF = 9) THEN ANLOCCF = .;
   IF (ANLDLYF = 9) THEN ANLDLYF = .;
   IF (TRQYRF = 9) THEN TRQYRF = .;
   IF (TRQMONF = 9) THEN TRQMONF = .;
   IF (TRQWKF = 9) THEN TRQWKF = .;
   IF (TRQOCCF = 9) THEN TRQOCCF = .;
   IF (TRQDLYF = 9) THEN TRQDLYF = .;
   IF (STMYRF = 9) THEN STMYRF = .;
   IF (STMMONF = 9) THEN STMMONF = .;
   IF (STMWKF = 9) THEN STMWKF = .;
   IF (STMOCCF = 9) THEN STMOCCF = .;
   IF (STMDLYF = 9) THEN STMDLYF = .;
   IF (SEDYRF = 9) THEN SEDYRF = .;
   IF (SEDMONF = 9) THEN SEDMONF = .;
   IF (SEDWKF = 9) THEN SEDWKF = .;
   IF (SEDOCCF = 9) THEN SEDOCCF = .;
   IF (SEDDLYF = 9) THEN SEDDLYF = .;
   IF (PSYFLAG2 = 9) THEN PSYFLAG2 = .;
   IF (PSYYR2 = 9) THEN PSYYR2 = .;
   IF (PSYMON2 = 9) THEN PSYMON2 = .;
   IF (SUMFLAG = 9) THEN SUMFLAG = .;
   IF (SUMYR = 9) THEN SUMYR = .;
   IF (SUMMON = 9) THEN SUMMON = .;
   IF (MJOFLAG = 9) THEN MJOFLAG = .;
   IF (MJOYR2 = 9) THEN MJOYR2 = .;
   IF (MJOMON2 = 9) THEN MJOMON2 = .;
   IF (IEMFLAG = 9) THEN IEMFLAG = .;
   IF (IEMYR = 9) THEN IEMYR = .;
   IF (IEMMON = 9) THEN IEMMON = .;
   IF (BINGEDRK >= 81) THEN BINGEDRK = .;
   IF (HVYDRK2 >= 81) THEN HVYDRK2 = .;
   IF (BINGEHVY >= 81) THEN BINGEHVY = .;
   IF (PEYOTE2 = 9) THEN PEYOTE2 = .;
   IF (MESC2 = 9) THEN MESC2 = .;
   IF (PSILCY2 = 9) THEN PSILCY2 = .;
   IF (ECSTASY2 = 9) THEN ECSTASY2 = .;
   IF (METHAMP2 = 9) THEN METHAMP2 = .;
   IF (AMYLNIT2 = 9) THEN AMYLNIT2 = .;
   IF (CLEFLU2 = 9) THEN CLEFLU2 = .;
   IF (GAS2 = 9) THEN GAS2 = .;
   IF (GLUE2 = 9) THEN GLUE2 = .;
   IF (ETHER2 = 9) THEN ETHER2 = .;
   IF (SOLVENT2 = 9) THEN SOLVENT2 = .;
   IF (LGAS2 = 9) THEN LGAS2 = .;
   IF (NITOXID2 = 9) THEN NITOXID2 = .;
   IF (SPPAINT2 = 9) THEN SPPAINT2 = .;
   IF (AEROS2 = 9) THEN AEROS2 = .;
   IF (MJDY30A3 = 9) THEN MJDY30A3 = .;
   IF (CG04 >= 81) THEN CG04 = .;
   IF (CG12 >= 81) THEN CG12 = .;
   IF (AL03 >= 81) THEN AL03 = .;
   IF (AL04 >= 81) THEN AL04 = .;
   IF (MJ04 >= 81) THEN MJ04 = .;
   IF (MJ05 >= 81) THEN MJ05 = .;
   IF (CC04 >= 81) THEN CC04 = .;
   IF (CC05 >= 81) THEN CC05 = .;
   IF (CK04 >= 81) THEN CK04 = .;
   IF (CK05 >= 81) THEN CK05 = .;
   IF (HE04 >= 81) THEN HE04 = .;
   IF (HE05 >= 81) THEN HE05 = .;
   IF (LS04 >= 81) THEN LS04 = .;
   IF (LS05 >= 81) THEN LS05 = .;
   IF (LS07 >= 81) THEN LS07 = .;
   IF (LS08 >= 81) THEN LS08 = .;
   IF (IN04 >= 81) THEN IN04 = .;
   IF (IN05 >= 81) THEN IN05 = .;
   IF (PK04 >= 81) THEN PK04 = .;
   IF (PK05 >= 81) THEN PK05 = .;
   IF (TR04 >= 81) THEN TR04 = .;
   IF (TR05 >= 81) THEN TR05 = .;
   IF (ST04 >= 81) THEN ST04 = .;
   IF (ST05 >= 81) THEN ST05 = .;
   IF (SE04 >= 81) THEN SE04 = .;
   IF (SE05 >= 81) THEN SE05 = .;
   IF (SKPSDRD >= 81) THEN SKPSDRD = .;
   IF (SDREAD >= 81) THEN SDREAD = .;
   IF (HRANYFRM >= 81) THEN HRANYFRM = .;
   IF (HERSMOKE >= 81) THEN HERSMOKE = .;
   IF (HRSMKREC >= 81) THEN HRSMKREC = .;
   IF (HERSNIFF >= 81) THEN HERSNIFF = .;
   IF (HRSNFREC >= 81) THEN HRSNFREC = .;
   IF (GNNDLLIF >= 81) THEN GNNDLLIF = .;
   IF (COCNEEDL >= 81) THEN COCNEEDL = .;
   IF (CONDLREC >= 81) THEN CONDLREC = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (HRNDLREC >= 81) THEN HRNDLREC = .;
   IF (STNEEDLE >= 81) THEN STNEEDLE = .;
   IF (STNDLREC >= 81) THEN STNDLREC = .;
   IF (GNNDREUS >= 81) THEN GNNDREUS = .;
   IF (GNNDLSH1 >= 81) THEN GNNDLSH1 = .;
   IF (GNNDCLEN >= 81) THEN GNNDCLEN = .;
   IF (GNNDLSH2 >= 81) THEN GNNDLSH2 = .;
   IF (GNNDGET >= 81) THEN GNNDGET = .;
   IF (GNNDGTSP >= 81) THEN GNNDGTSP = .;
   IF (SKPRSKRD >= 81) THEN SKPRSKRD = .;
   IF (RSKREAD >= 81) THEN RSKREAD = .;
   IF (RSKPKCIG >= 81) THEN RSKPKCIG = .;
   IF (RSKMJOCC >= 81) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 81) THEN RSKMJREG = .;
   IF (RKTRYLSD >= 81) THEN RKTRYLSD = .;
   IF (RKLSDREG >= 81) THEN RKLSDREG = .;
   IF (RKTRYHER >= 81) THEN RKTRYHER = .;
   IF (RKHERREG >= 81) THEN RKHERREG = .;
   IF (RKCOCOCC >= 81) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 81) THEN RKCOCREG = .;
   IF (RK5DRINK >= 81) THEN RK5DRINK = .;
   IF (RSKBINGE >= 81) THEN RSKBINGE = .;
   IF (RSKDIFMJ >= 81) THEN RSKDIFMJ = .;
   IF (RKDIFLSD >= 81) THEN RKDIFLSD = .;
   IF (RKDIFCOC >= 81) THEN RKDIFCOC = .;
   IF (RKDIFCRK >= 81) THEN RKDIFCRK = .;
   IF (RKDIFHER >= 81) THEN RKDIFHER = .;
   IF (RSKSELL >= 81) THEN RSKSELL = .;
   IF (RKFQDNGR >= 81) THEN RKFQDNGR = .;
   IF (RKFQRSKY >= 81) THEN RKFQRSKY = .;
   IF (RKFQPBLT >= 81) THEN RKFQPBLT = .;
   IF (RKFQDBLT >= 81) THEN RKFQDBLT = .;
   IF (SKPDRGRD >= 81) THEN SKPDRGRD = .;
   IF (DRGREAD >= 81) THEN DRGREAD = .;
   IF (USEDCIG >= 81) THEN USEDCIG = .;
   IF (USEDALC >= 81) THEN USEDALC = .;
   IF (USEDMRJ >= 81) THEN USEDMRJ = .;
   IF (USEDCOC >= 81) THEN USEDCOC = .;
   IF (USEDHER >= 81) THEN USEDHER = .;
   IF (USEDHAL >= 81) THEN USEDHAL = .;
   IF (USEDINH >= 81) THEN USEDINH = .;
   IF (USEDANL >= 81) THEN USEDANL = .;
   IF (USEDTRN >= 81) THEN USEDTRN = .;
   IF (USEDSTM >= 81) THEN USEDSTM = .;
   IF (USEDSED >= 81) THEN USEDSED = .;
   IF (NODRUGYR >= 81) THEN NODRUGYR = .;
   IF (GRTMCIG >= 81) THEN GRTMCIG = .;
   IF (GRTMALC >= 81) THEN GRTMALC = .;
   IF (GRTMMRJ >= 81) THEN GRTMMRJ = .;
   IF (GRTMCOC >= 81) THEN GRTMCOC = .;
   IF (GRTMHER >= 81) THEN GRTMHER = .;
   IF (GRTMHAL >= 81) THEN GRTMHAL = .;
   IF (GRTMINH >= 81) THEN GRTMINH = .;
   IF (GRTMANL >= 81) THEN GRTMANL = .;
   IF (GRTMTRN >= 81) THEN GRTMTRN = .;
   IF (GRTMSTM >= 81) THEN GRTMSTM = .;
   IF (GRTMSED >= 81) THEN GRTMSED = .;
   IF (LAMTCIG >= 81) THEN LAMTCIG = .;
   IF (LAMTALC >= 81) THEN LAMTALC = .;
   IF (LAMTMRJ >= 81) THEN LAMTMRJ = .;
   IF (LAMTCOC >= 81) THEN LAMTCOC = .;
   IF (LAMTHER >= 81) THEN LAMTHER = .;
   IF (LAMTHAL >= 81) THEN LAMTHAL = .;
   IF (LAMTINH >= 81) THEN LAMTINH = .;
   IF (LAMTANL >= 81) THEN LAMTANL = .;
   IF (LAMTTRN >= 81) THEN LAMTTRN = .;
   IF (LAMTSTM >= 81) THEN LAMTSTM = .;
   IF (LAMTSED >= 81) THEN LAMTSED = .;
   IF (BTOLCIG >= 81) THEN BTOLCIG = .;
   IF (BTOLALC >= 81) THEN BTOLALC = .;
   IF (BTOLMRJ >= 81) THEN BTOLMRJ = .;
   IF (BTOLCOC >= 81) THEN BTOLCOC = .;
   IF (BTOLHER >= 81) THEN BTOLHER = .;
   IF (BTOLHAL >= 81) THEN BTOLHAL = .;
   IF (BTOLINH >= 81) THEN BTOLINH = .;
   IF (BTOLANL >= 81) THEN BTOLANL = .;
   IF (BTOLTRN >= 81) THEN BTOLTRN = .;
   IF (BTOLSTM >= 81) THEN BTOLSTM = .;
   IF (BTOLSED >= 81) THEN BTOLSED = .;
   IF (ACRDCIG >= 81) THEN ACRDCIG = .;
   IF (ACRDALC >= 81) THEN ACRDALC = .;
   IF (ACRDMRJ >= 81) THEN ACRDMRJ = .;
   IF (ACRDCOC >= 81) THEN ACRDCOC = .;
   IF (ACRDHER >= 81) THEN ACRDHER = .;
   IF (ACRDHAL >= 81) THEN ACRDHAL = .;
   IF (ACRDINH >= 81) THEN ACRDINH = .;
   IF (ACRDANL >= 81) THEN ACRDANL = .;
   IF (ACRDTRN >= 81) THEN ACRDTRN = .;
   IF (ACRDSTM >= 81) THEN ACRDSTM = .;
   IF (ACRDSED >= 81) THEN ACRDSED = .;
   IF (EMPBCIG >= 81) THEN EMPBCIG = .;
   IF (EMPBALC >= 81) THEN EMPBALC = .;
   IF (EMPBMRJ >= 81) THEN EMPBMRJ = .;
   IF (EMPBCOC >= 81) THEN EMPBCOC = .;
   IF (EMPBHER >= 81) THEN EMPBHER = .;
   IF (EMPBHAL >= 81) THEN EMPBHAL = .;
   IF (EMPBINH >= 81) THEN EMPBINH = .;
   IF (EMPBANL >= 81) THEN EMPBANL = .;
   IF (EMPBTRN >= 81) THEN EMPBTRN = .;
   IF (EMPBSTM >= 81) THEN EMPBSTM = .;
   IF (EMPBSED >= 81) THEN EMPBSED = .;
   IF (HLPBCIG >= 81) THEN HLPBCIG = .;
   IF (HLPBALC >= 81) THEN HLPBALC = .;
   IF (HLPBMRJ >= 81) THEN HLPBMRJ = .;
   IF (HLPBCOC >= 81) THEN HLPBCOC = .;
   IF (HLPBHER >= 81) THEN HLPBHER = .;
   IF (HLPBHAL >= 81) THEN HLPBHAL = .;
   IF (HLPBINH >= 81) THEN HLPBINH = .;
   IF (HLPBANL >= 81) THEN HLPBANL = .;
   IF (HLPBTRN >= 81) THEN HLPBTRN = .;
   IF (HLPBSTM >= 81) THEN HLPBSTM = .;
   IF (HLPBSED >= 81) THEN HLPBSED = .;
   IF (UCDCIG >= 81) THEN UCDCIG = .;
   IF (UCDALC >= 81) THEN UCDALC = .;
   IF (UCDMRJ >= 81) THEN UCDMRJ = .;
   IF (UCDCOC >= 81) THEN UCDCOC = .;
   IF (UCDHER >= 81) THEN UCDHER = .;
   IF (UCDHAL >= 81) THEN UCDHAL = .;
   IF (UCDINH >= 81) THEN UCDINH = .;
   IF (UCDANL >= 81) THEN UCDANL = .;
   IF (UCDTRN >= 81) THEN UCDTRN = .;
   IF (UCDSTM >= 81) THEN UCDSTM = .;
   IF (UCDSED >= 81) THEN UCDSED = .;
   IF (SKPSPTRD >= 81) THEN SKPSPTRD = .;
   IF (SPTREAD >= 81) THEN SPTREAD = .;
   IF (NDTXRCVD >= 81) THEN NDTXRCVD = .;
   IF (NDTXNEED >= 81) THEN NDTXNEED = .;
   IF (NDTXALC >= 81) THEN NDTXALC = .;
   IF (NDTXMJ >= 81) THEN NDTXMJ = .;
   IF (NDTXCOC >= 81) THEN NDTXCOC = .;
   IF (NDTXHER >= 81) THEN NDTXHER = .;
   IF (NDTXHAL >= 81) THEN NDTXHAL = .;
   IF (NDTXINH >= 81) THEN NDTXINH = .;
   IF (NDTXANL >= 81) THEN NDTXANL = .;
   IF (NDTXTRAN >= 81) THEN NDTXTRAN = .;
   IF (NDTXSTIM >= 81) THEN NDTXSTIM = .;
   IF (NDTXSED >= 81) THEN NDTXSED = .;
   IF (NDTXSOD >= 81) THEN NDTXSOD = .;
   IF (NDTXDRG1 >= 9981) THEN NDTXDRG1 = .;
   IF (NDTXDRG2 >= 9981) THEN NDTXDRG2 = .;
   IF (NDTXDRG3 >= 9981) THEN NDTXDRG3 = .;
   IF (NDTXDRG4 >= 9981) THEN NDTXDRG4 = .;
   IF (NDTXDRG5 >= 9981) THEN NDTXDRG5 = .;
   IF (NDTXSTEP >= 81) THEN NDTXSTEP = .;
   IF (NDTXTRSP >= 81) THEN NDTXTRSP = .;
   IF (NDTXTFAR >= 81) THEN NDTXTFAR = .;
   IF (NDTXBDHR >= 81) THEN NDTXBDHR = .;
   IF (NDTXOPEN >= 81) THEN NDTXOPEN = .;
   IF (NDTXTYPE >= 81) THEN NDTXTYPE = .;
   IF (NDTXMONY >= 81) THEN NDTXMONY = .;
   IF (NDTXHCAP >= 81) THEN NDTXHCAP = .;
   IF (NDTXTCMP >= 81) THEN NDTXTCMP = .;
   IF (NDTXLANG >= 81) THEN NDTXLANG = .;
   IF (NDTXSPSV >= 81) THEN NDTXSPSV = .;
   IF (NDTXSOR >= 81) THEN NDTXSOR = .;
   IF (NDTXRSC1 >= 81) THEN NDTXRSC1 = .;
   IF (BOOKED >= 81) THEN BOOKED = .;
   IF (NOBOOKYR >= 81) THEN NOBOOKYR = .;
   IF (BKLARCNY >= 81) THEN BKLARCNY = .;
   IF (BKBURGL >= 81) THEN BKBURGL = .;
   IF (BKAGASLT >= 81) THEN BKAGASLT = .;
   IF (BKSMASLT >= 81) THEN BKSMASLT = .;
   IF (BKMVTHFT >= 81) THEN BKMVTHFT = .;
   IF (BKROB >= 81) THEN BKROB = .;
   IF (BKRAPE >= 81) THEN BKRAPE = .;
   IF (BKMURDER >= 81) THEN BKMURDER = .;
   IF (BKARSON >= 81) THEN BKARSON = .;
   IF (BKDRVINF >= 81) THEN BKDRVINF = .;
   IF (BKDRUNK >= 81) THEN BKDRUNK = .;
   IF (BKDRUG >= 81) THEN BKDRUG = .;
   IF (BKPROS >= 81) THEN BKPROS = .;
   IF (BKVANDAL >= 81) THEN BKVANDAL = .;
   IF (BKOTH >= 81) THEN BKOTH = .;
   IF (BKOTHOFF >= 81) THEN BKOTHOFF = .;
   IF (PROBATON >= 81) THEN PROBATON = .;
   IF (PAROLE >= 81) THEN PAROLE = .;
   IF (DRVALDR >= 81) THEN DRVALDR = .;
   IF (DRIVEAL >= 81) THEN DRIVEAL = .;
   IF (DRIVEDR >= 81) THEN DRIVEDR = .;
   IF (SKPTMTRD >= 81) THEN SKPTMTRD = .;
   IF (TMTREAD >= 81) THEN TMTREAD = .;
   IF (TXEVER >= 81) THEN TXEVER = .;
   IF (TXSTRTLF >= 981) THEN TXSTRTLF = .;
   IF (TXSTRTYR >= 981) THEN TXSTRTYR = .;
   IF (TXALHOSP >= 81) THEN TXALHOSP = .;
   IF (TXALRFIN >= 81) THEN TXALRFIN = .;
   IF (TXALRFOP >= 81) THEN TXALRFOP = .;
   IF (TXALMHC >= 81) THEN TXALMHC = .;
   IF (TXALEMRG >= 81) THEN TXALEMRG = .;
   IF (TXALDOC >= 81) THEN TXALDOC = .;
   IF (TXALJAIL >= 81) THEN TXALJAIL = .;
   IF (TXALSHG >= 81) THEN TXALSHG = .;
   IF (TXALSOP >= 81) THEN TXALSOP = .;
   IF (TXALSP >= 81) THEN TXALSP = .;
   IF (TXDRHOSP >= 81) THEN TXDRHOSP = .;
   IF (TXDRFIN >= 81) THEN TXDRFIN = .;
   IF (TXDRFOP >= 81) THEN TXDRFOP = .;
   IF (TXDRMHC >= 81) THEN TXDRMHC = .;
   IF (TXDREMRG >= 81) THEN TXDREMRG = .;
   IF (TXDRDOC >= 81) THEN TXDRDOC = .;
   IF (TXDRJAIL >= 81) THEN TXDRJAIL = .;
   IF (TXDRSHG >= 81) THEN TXDRSHG = .;
   IF (TXDRSOP >= 81) THEN TXDRSOP = .;
   IF (TXDRSP >= 81) THEN TXDRSP = .;
   IF (TXYREMRG >= 981) THEN TXYREMRG = .;
   IF (TXADGREC >= 81) THEN TXADGREC = .;
   IF (TXLTHOSP >= 81) THEN TXLTHOSP = .;
   IF (TXLTRFIN >= 81) THEN TXLTRFIN = .;
   IF (TXLTRFOP >= 81) THEN TXLTRFOP = .;
   IF (TXLTMHC >= 81) THEN TXLTMHC = .;
   IF (TXLTEMRG >= 81) THEN TXLTEMRG = .;
   IF (TXLTDOC >= 81) THEN TXLTDOC = .;
   IF (TXLTJAIL >= 81) THEN TXLTJAIL = .;
   IF (TXLTSHG >= 81) THEN TXLTSHG = .;
   IF (TXLTSOP >= 81) THEN TXLTSOP = .;
   IF (TXLTSP >= 81) THEN TXLTSP = .;
   IF (TXLTALC >= 81) THEN TXLTALC = .;
   IF (TXLTMJ >= 81) THEN TXLTMJ = .;
   IF (TXLTCOC >= 81) THEN TXLTCOC = .;
   IF (TXLTHER >= 81) THEN TXLTHER = .;
   IF (TXLTHAL >= 81) THEN TXLTHAL = .;
   IF (TXLTINH >= 81) THEN TXLTINH = .;
   IF (TXLTANL >= 81) THEN TXLTANL = .;
   IF (TXLTRAN >= 81) THEN TXLTRAN = .;
   IF (TXLTSTIM >= 81) THEN TXLTSTIM = .;
   IF (TXLTSED >= 81) THEN TXLTSED = .;
   IF (TXLTSOD >= 81) THEN TXLTSOD = .;
   IF (TXLTA >= 9981) THEN TXLTA = .;
   IF (TXLTB >= 9981) THEN TXLTB = .;
   IF (TXLTC >= 9981) THEN TXLTC = .;
   IF (TXLTD >= 9981) THEN TXLTD = .;
   IF (TXLTE >= 9981) THEN TXLTE = .;
   IF (TXDRGA >= 9981) THEN TXDRGA = .;
   IF (TXDRGB >= 9981) THEN TXDRGB = .;
   IF (TXDRGC >= 9981) THEN TXDRGC = .;
   IF (TXDRGD >= 9981) THEN TXDRGD = .;
   IF (TXDRGE >= 9981) THEN TXDRGE = .;
   IF (TXOUTC >= 81) THEN TXOUTC = .;
   IF (TXTIME >= 9981) THEN TXTIME = .;
   IF (TXPDINS >= 81) THEN TXPDINS = .;
   IF (TXPDCARE >= 81) THEN TXPDCARE = .;
   IF (TXPDCAID >= 81) THEN TXPDCAID = .;
   IF (TXPDSAVE >= 81) THEN TXPDSAVE = .;
   IF (TXPDFMLY >= 81) THEN TXPDFMLY = .;
   IF (TXPDEMPL >= 81) THEN TXPDEMPL = .;
   IF (TXPDFREE >= 81) THEN TXPDFREE = .;
   IF (TXPDSOS >= 81) THEN TXPDSOS = .;
   IF (TXPDSP >= 81) THEN TXPDSP = .;
   IF (TXENROLL >= 81) THEN TXENROLL = .;
   IF (SKPWRKRD >= 81) THEN SKPWRKRD = .;
   IF (WRKREAD >= 81) THEN WRKREAD = .;
   IF (WKEVRACC >= 81) THEN WKEVRACC = .;
   IF (WKYRACC >= 81) THEN WKYRACC = .;
   IF (WKYRTEST >= 81) THEN WKYRTEST = .;
   IF (WK30ACC >= 81) THEN WK30ACC = .;
   IF (WK30TEST >= 81) THEN WK30TEST = .;
   IF (WKYRVOL >= 81) THEN WKYRVOL = .;
   IF (WKYRFIRE >= 81) THEN WKYRFIRE = .;
   IF (WKYRLOFF >= 81) THEN WKYRLOFF = .;
   IF (WKYROTHR >= 81) THEN WKYROTHR = .;
   IF (WKYRSPEC >= 81) THEN WKYRSPEC = .;
   IF (SKPDEXRD >= 81) THEN SKPDEXRD = .;
   IF (DEXREAD >= 81) THEN DEXREAD = .;
   IF (DXVERSN >= 81) THEN DXVERSN = .;
   IF (DXCGRLF >= 81) THEN DXCGRLF = .;
   IF (DXCG50LF >= 81) THEN DXCG50LF = .;
   IF (DXCG30US >= 35) THEN DXCG30US = .;
   IF (DXMJOFFR >= 81) THEN DXMJOFFR = .;
   IF (DXMJEVER >= 81) THEN DXMJEVER = .;
   IF (DXMJPALN >= 81) THEN DXMJPALN = .;
   IF (DXMJPSPS >= 81) THEN DXMJPSPS = .;
   IF (DXMJPFRN >= 81) THEN DXMJPFRN = .;
   IF (DXMJPMET >= 81) THEN DXMJPMET = .;
   IF (DXMJPSIB >= 81) THEN DXMJPSIB = .;
   IF (DXMJPDAD >= 81) THEN DXMJPDAD = .;
   IF (DXMJPMOM >= 81) THEN DXMJPMOM = .;
   IF (DXMJPREL >= 81) THEN DXMJPREL = .;
   IF (DXMJPSOP >= 81) THEN DXMJPSOP = .;
   IF (DXMJPSP >= 981) THEN DXMJPSP = .;
   IF (DXMJPNR >= 981) THEN DXMJPNR = .;
   IF (DXMJFSEE >= 81) THEN DXMJFSEE = .;
   IF (DXMJFFGD >= 81) THEN DXMJFFGD = .;
   IF (DXMJFFRN >= 81) THEN DXMJFFRN = .;
   IF (DXMJFSPS >= 81) THEN DXMJFSPS = .;
   IF (DXMJFESC >= 81) THEN DXMJFESC = .;
   IF (DXMJFNEW >= 81) THEN DXMJFNEW = .;
   IF (DXMJFREB >= 81) THEN DXMJFREB = .;
   IF (DXMJFSOR >= 81) THEN DXMJFSOR = .;
   IF (DXMJFSP >= 81) THEN DXMJFSP = .;
   IF (DXMJYR >= 81) THEN DXMJYR = .;
   IF (DXMJYFRN >= 81) THEN DXMJYFRN = .;
   IF (DXMJYSPS >= 81) THEN DXMJYSPS = .;
   IF (DXMJYESC >= 81) THEN DXMJYESC = .;
   IF (DXMJYRLX >= 81) THEN DXMJYRLX = .;
   IF (DXMJYDRS >= 81) THEN DXMJYDRS = .;
   IF (DXMJYDRX >= 81) THEN DXMJYDRX = .;
   IF (DXMJYRLF >= 81) THEN DXMJYRLF = .;
   IF (DXMJYSOR >= 81) THEN DXMJYSOR = .;
   IF (DXMJYSP >= 81) THEN DXMJYSP = .;
   IF (DXMJRET1 >= 81) THEN DXMJRET1 = .;
   IF (DXMJDNI >= 81) THEN DXMJDNI = .;
   IF (DXMJDPHY >= 81) THEN DXMJDPHY = .;
   IF (DXMJDSCK >= 81) THEN DXMJDSCK = .;
   IF (DXMJDBLF >= 81) THEN DXMJDBLF = .;
   IF (DXMJDTST >= 81) THEN DXMJDTST = .;
   IF (DXMJDPSY >= 81) THEN DXMJDPSY = .;
   IF (DXMJDDGS >= 81) THEN DXMJDDGS = .;
   IF (DXMJDADD >= 81) THEN DXMJDADD = .;
   IF (DXMJDPRG >= 81) THEN DXMJDPRG = .;
   IF (DXMJDKID >= 81) THEN DXMJDKID = .;
   IF (DXMJDPAR >= 81) THEN DXMJDPAR = .;
   IF (DXMJDSPS >= 81) THEN DXMJDSPS = .;
   IF (DXMJDFRN >= 81) THEN DXMJDFRN = .;
   IF (DXMJDCOS >= 81) THEN DXMJDCOS = .;
   IF (DXMJDGET >= 81) THEN DXMJDGET = .;
   IF (DXMJDDLR >= 81) THEN DXMJDDLR = .;
   IF (DXMJDIGL >= 81) THEN DXMJDIGL = .;
   IF (DXMJDCRM >= 81) THEN DXMJDCRM = .;
   IF (DXMJDSOR >= 81) THEN DXMJDSOR = .;
   IF (DXMJDSP >= 81) THEN DXMJDSP = .;
   IF (DXMJRET2 >= 81) THEN DXMJRET2 = .;
   IF (DXMJNNI >= 81) THEN DXMJNNI = .;
   IF (DXMJNPHY >= 81) THEN DXMJNPHY = .;
   IF (DXMJNLIK >= 81) THEN DXMJNLIK = .;
   IF (DXMJNBLF >= 81) THEN DXMJNBLF = .;
   IF (DXMJNTST >= 81) THEN DXMJNTST = .;
   IF (DXMJNPSY >= 81) THEN DXMJNPSY = .;
   IF (DXMJNDGS >= 81) THEN DXMJNDGS = .;
   IF (DXMJNADD >= 81) THEN DXMJNADD = .;
   IF (DXMJNPRG >= 81) THEN DXMJNPRG = .;
   IF (DXMJNKID >= 81) THEN DXMJNKID = .;
   IF (DXMJNPAR >= 81) THEN DXMJNPAR = .;
   IF (DXMJNSPS >= 81) THEN DXMJNSPS = .;
   IF (DXMJNFRN >= 81) THEN DXMJNFRN = .;
   IF (DXMJNCOS >= 81) THEN DXMJNCOS = .;
   IF (DXMJNGET >= 81) THEN DXMJNGET = .;
   IF (DXMJNDLR >= 81) THEN DXMJNDLR = .;
   IF (DXMJNIGL >= 81) THEN DXMJNIGL = .;
   IF (DXMJNCRM >= 81) THEN DXMJNCRM = .;
   IF (DXMJNSOR >= 81) THEN DXMJNSOR = .;
   IF (DXMJNSP >= 81) THEN DXMJNSP = .;
   IF (DXCCOFFR >= 81) THEN DXCCOFFR = .;
   IF (DXCCEVER >= 81) THEN DXCCEVER = .;
   IF (DXCCPALN >= 81) THEN DXCCPALN = .;
   IF (DXCCPSPS >= 81) THEN DXCCPSPS = .;
   IF (DXCCPFRN >= 81) THEN DXCCPFRN = .;
   IF (DXCCPMET >= 81) THEN DXCCPMET = .;
   IF (DXCCPSIB >= 81) THEN DXCCPSIB = .;
   IF (DXCCPDAD >= 81) THEN DXCCPDAD = .;
   IF (DXCCPMOM >= 81) THEN DXCCPMOM = .;
   IF (DXCCPREL >= 81) THEN DXCCPREL = .;
   IF (DXCCPSOP >= 81) THEN DXCCPSOP = .;
   IF (DXCCPSP >= 981) THEN DXCCPSP = .;
   IF (DXCCPNR >= 981) THEN DXCCPNR = .;
   IF (DXCCFSEE >= 81) THEN DXCCFSEE = .;
   IF (DXCCFFGD >= 81) THEN DXCCFFGD = .;
   IF (DXCCFFRN >= 81) THEN DXCCFFRN = .;
   IF (DXCCFSPS >= 81) THEN DXCCFSPS = .;
   IF (DXCCFESC >= 81) THEN DXCCFESC = .;
   IF (DXCCFNEW >= 81) THEN DXCCFNEW = .;
   IF (DXCCFREB >= 81) THEN DXCCFREB = .;
   IF (DXCCFSOR >= 81) THEN DXCCFSOR = .;
   IF (DXCCFSP >= 81) THEN DXCCFSP = .;
   IF (DXCCYR >= 81) THEN DXCCYR = .;
   IF (DXCCYFRN >= 81) THEN DXCCYFRN = .;
   IF (DXCCYSPS >= 81) THEN DXCCYSPS = .;
   IF (DXCCYESC >= 81) THEN DXCCYESC = .;
   IF (DXCCYRLX >= 81) THEN DXCCYRLX = .;
   IF (DXCCYDRS >= 81) THEN DXCCYDRS = .;
   IF (DXCCYDRX >= 81) THEN DXCCYDRX = .;
   IF (DXCCYRLF >= 81) THEN DXCCYRLF = .;
   IF (DXCCYSOR >= 81) THEN DXCCYSOR = .;
   IF (DXCCYSP >= 81) THEN DXCCYSP = .;
   IF (DXCCRET1 >= 81) THEN DXCCRET1 = .;
   IF (DXCCDNI >= 81) THEN DXCCDNI = .;
   IF (DXCCDPHY >= 81) THEN DXCCDPHY = .;
   IF (DXCCDSCK >= 81) THEN DXCCDSCK = .;
   IF (DXCCDBLF >= 81) THEN DXCCDBLF = .;
   IF (DXCCDTST >= 81) THEN DXCCDTST = .;
   IF (DXCCDPSY >= 81) THEN DXCCDPSY = .;
   IF (DXCCDDGS >= 81) THEN DXCCDDGS = .;
   IF (DXCCDADD >= 81) THEN DXCCDADD = .;
   IF (DXCCDPRG >= 81) THEN DXCCDPRG = .;
   IF (DXCCDKID >= 81) THEN DXCCDKID = .;
   IF (DXCCDPAR >= 81) THEN DXCCDPAR = .;
   IF (DXCCDSPS >= 81) THEN DXCCDSPS = .;
   IF (DXCCDFRN >= 81) THEN DXCCDFRN = .;
   IF (DXCCDCOS >= 81) THEN DXCCDCOS = .;
   IF (DXCCDGET >= 81) THEN DXCCDGET = .;
   IF (DXCCDDLR >= 81) THEN DXCCDDLR = .;
   IF (DXCCDIGL >= 81) THEN DXCCDIGL = .;
   IF (DXCCDCRM >= 81) THEN DXCCDCRM = .;
   IF (DXCCDSOR >= 81) THEN DXCCDSOR = .;
   IF (DXCCDSP >= 81) THEN DXCCDSP = .;
   IF (DXCCRET2 >= 81) THEN DXCCRET2 = .;
   IF (DXCCNNI >= 81) THEN DXCCNNI = .;
   IF (DXCCNPHY >= 81) THEN DXCCNPHY = .;
   IF (DXCCNLIK >= 81) THEN DXCCNLIK = .;
   IF (DXCCNBLF >= 81) THEN DXCCNBLF = .;
   IF (DXCCNTST >= 81) THEN DXCCNTST = .;
   IF (DXCCNPSY >= 81) THEN DXCCNPSY = .;
   IF (DXCCNDGS >= 81) THEN DXCCNDGS = .;
   IF (DXCCNADD >= 81) THEN DXCCNADD = .;
   IF (DXCCNPRG >= 81) THEN DXCCNPRG = .;
   IF (DXCCNKID >= 81) THEN DXCCNKID = .;
   IF (DXCCNPAR >= 81) THEN DXCCNPAR = .;
   IF (DXCCNSPS >= 81) THEN DXCCNSPS = .;
   IF (DXCCNFRN >= 81) THEN DXCCNFRN = .;
   IF (DXCCNCOS >= 81) THEN DXCCNCOS = .;
   IF (DXCCNGET >= 81) THEN DXCCNGET = .;
   IF (DXCCNDLR >= 81) THEN DXCCNDLR = .;
   IF (DXCCNIGL >= 81) THEN DXCCNIGL = .;
   IF (DXCCNCRM >= 81) THEN DXCCNCRM = .;
   IF (DXCCNSOR >= 81) THEN DXCCNSOR = .;
   IF (DXCCNSP >= 81) THEN DXCCNSP = .;
   IF (SKPYEANS = 9) THEN SKPYEANS = .;
   IF (SKPYEXRD >= 81) THEN SKPYEXRD = .;
   IF (YEXREAD >= 81) THEN YEXREAD = .;
   IF (YEENRLYR >= 81) THEN YEENRLYR = .;
   IF (YEPUBSCH >= 81) THEN YEPUBSCH = .;
   IF (YEPRVSCH >= 81) THEN YEPRVSCH = .;
   IF (YEHOMSCH >= 81) THEN YEHOMSCH = .;
   IF (YE4YRCOL >= 81) THEN YE4YRCOL = .;
   IF (YE2YRCOL >= 81) THEN YE2YRCOL = .;
   IF (YEVOCSCH >= 81) THEN YEVOCSCH = .;
   IF (YESCHOTH >= 81) THEN YESCHOTH = .;
   IF (YESCHSP >= 81) THEN YESCHSP = .;
   IF (YEGRADES >= 81) THEN YEGRADES = .;
   IF (YESCOUTS >= 81) THEN YESCOUTS = .;
   IF (YEPRVLES >= 81) THEN YEPRVLES = .;
   IF (YETEMSPT >= 81) THEN YETEMSPT = .;
   IF (YE4HCLUB >= 81) THEN YE4HCLUB = .;
   IF (YEBAND >= 81) THEN YEBAND = .;
   IF (YESCHCLB >= 81) THEN YESCHCLB = .;
   IF (YESTGOVT >= 81) THEN YESTGOVT = .;
   IF (YEVOLUNT >= 81) THEN YEVOLUNT = .;
   IF (YECHOIR >= 81) THEN YECHOIR = .;
   IF (YEACTOTH >= 81) THEN YEACTOTH = .;
   IF (YEACTSP >= 81) THEN YEACTSP = .;
   IF (YEJOBYR >= 81) THEN YEJOBYR = .;
   IF (YEJOBSCD >= 81) THEN YEJOBSCD = .;
   IF (YEDETCHR >= 81) THEN YEDETCHR = .;
   IF (YEDENTCH >= 81) THEN YEDENTCH = .;
   IF (YEDESPCL >= 81) THEN YEDESPCL = .;
   IF (YEDEOTH >= 81) THEN YEDEOTH = .;
   IF (YEDESP >= 81) THEN YEDESP = .;
   IF (YEMSGYR >= 81) THEN YEMSGYR = .;
   IF (YEPARYR >= 81) THEN YEPARYR = .;
   IF (YEPPKCIG >= 81) THEN YEPPKCIG = .;
   IF (YEPMJEVR >= 81) THEN YEPMJEVR = .;
   IF (YEPMJOCC >= 81) THEN YEPMJOCC = .;
   IF (YEPMJREG >= 81) THEN YEPMJREG = .;
   IF (YEPINEVR >= 81) THEN YEPINEVR = .;
   IF (YEPHEEVR >= 81) THEN YEPHEEVR = .;
   IF (YEPCCOCC >= 81) THEN YEPCCOCC = .;
   IF (YEPBINGE >= 81) THEN YEPBINGE = .;
   IF (YEFPKCIG >= 81) THEN YEFPKCIG = .;
   IF (YEFMJEVR >= 81) THEN YEFMJEVR = .;
   IF (YEFMJOCC >= 81) THEN YEFMJOCC = .;
   IF (YEFMJREG >= 81) THEN YEFMJREG = .;
   IF (YEFINEVR >= 81) THEN YEFINEVR = .;
   IF (YEFHEEVR >= 81) THEN YEFHEEVR = .;
   IF (YEFCCOCC >= 81) THEN YEFCCOCC = .;
   IF (YEFBINGE >= 81) THEN YEFBINGE = .;
   IF (YEFDPKCG >= 81) THEN YEFDPKCG = .;
   IF (YEFDMJEV >= 81) THEN YEFDMJEV = .;
   IF (YEFDMJOC >= 81) THEN YEFDMJOC = .;
   IF (YEFDMJRG >= 81) THEN YEFDMJRG = .;
   IF (YEFDINEV >= 81) THEN YEFDINEV = .;
   IF (YEFDHEEV >= 81) THEN YEFDHEEV = .;
   IF (YEFDCCOC >= 81) THEN YEFDCCOC = .;
   IF (YEFDBING >= 81) THEN YEFDBING = .;
   IF (YETLKNON >= 81) THEN YETLKNON = .;
   IF (YETLKMOM >= 81) THEN YETLKMOM = .;
   IF (YETLKDAD >= 81) THEN YETLKDAD = .;
   IF (YETLKBGF >= 81) THEN YETLKBGF = .;
   IF (YETLKSIB >= 81) THEN YETLKSIB = .;
   IF (YETLKSOR >= 81) THEN YETLKSOR = .;
   IF (YETLKFRN >= 81) THEN YETLKFRN = .;
   IF (YETLKTCH >= 81) THEN YETLKTCH = .;
   IF (YETLKCLG >= 81) THEN YETLKCLG = .;
   IF (YETLKSOP >= 81) THEN YETLKSOP = .;
   IF (YETLKSP >= 981) THEN YETLKSP = .;
   IF (YETLKNR >= 981) THEN YETLKNR = .;
   IF (YEMOSNON >= 81) THEN YEMOSNON = .;
   IF (YEMOSMOM >= 81) THEN YEMOSMOM = .;
   IF (YEMOSDAD >= 81) THEN YEMOSDAD = .;
   IF (YEMOSBGF >= 81) THEN YEMOSBGF = .;
   IF (YEMOSSIB >= 81) THEN YEMOSSIB = .;
   IF (YEMOSSOR >= 81) THEN YEMOSSOR = .;
   IF (YEMOSFRN >= 81) THEN YEMOSFRN = .;
   IF (YEMOSTCH >= 81) THEN YEMOSTCH = .;
   IF (YEMOSCLG >= 81) THEN YEMOSCLG = .;
   IF (YEMOSSOP >= 81) THEN YEMOSSOP = .;
   IF (YEMOSSP >= 981) THEN YEMOSSP = .;
   IF (YEMOSNR >= 981) THEN YEMOSNR = .;
   IF (YESTDRES >= 81) THEN YESTDRES = .;
   IF (YESTLATE >= 81) THEN YESTLATE = .;
   IF (YESTHWRK >= 81) THEN YESTHWRK = .;
   IF (YEARGUP >= 81) THEN YEARGUP = .;
   IF (YEGFITE >= 81) THEN YEGFITE = .;
   IF (YESHPLFT >= 81) THEN YESHPLFT = .;
   IF (MOVESPYR >= 81) THEN MOVESPYR = .;
   IF (EDUC2NDQ >= 81) THEN EDUC2NDQ = .;
   IF (STUDNT97 >= 81) THEN STUDNT97 = .;
   IF (STDT9497 >= 81) THEN STDT9497 = .;
   IF (SKPSCHGR >= 81) THEN SKPSCHGR = .;
   IF (SKPSCHAG >= 81) THEN SKPSCHAG = .;
   IF (LFTSCHRS >= 81) THEN LFTSCHRS = .;
   IF (LFTSCHAG >= 981) THEN LFTSCHAG = .;
   IF (SCHDYS97 >= 81) THEN SCHDYS97 = .;
   IF (SCHD9497 >= 81) THEN SCHD9497 = .;
   IF (SKIPPD97 >= 35) THEN SKIPPD97 = .;
   IF (SKIP9497 >= 35) THEN SKIP9497 = .;
   IF (NJOBSPYR >= 81) THEN NJOBSPYR = .;
   IF (WRKSTAT2 >= 81) THEN WRKSTAT2 = .;
   IF (WKST2NDQ >= 81) THEN WKST2NDQ = .;
   IF (WKSWKST >= 81) THEN WKSWKST = .;
   IF (SKPWKST1 >= 81) THEN SKPWKST1 = .;
   IF (BUSSIZE >= 81) THEN BUSSIZE = .;
   IF (LOCSIZE >= 81) THEN LOCSIZE = .;
   IF (DRGINFO >= 81) THEN DRGINFO = .;
   IF (DRGPLCY >= 81) THEN DRGPLCY = .;
   IF (PLCYCOV >= 81) THEN PLCYCOV = .;
   IF (DRGPRGM >= 81) THEN DRGPRGM = .;
   IF (USALCTST >= 81) THEN USALCTST = .;
   IF (USDRGTST >= 81) THEN USDRGTST = .;
   IF (SKPWKTST >= 81) THEN SKPWKTST = .;
   IF (TSTHIRE >= 81) THEN TSTHIRE = .;
   IF (TSTRAND >= 81) THEN TSTRAND = .;
   IF (TSTSUSP >= 81) THEN TSTSUSP = .;
   IF (TSTACCD >= 81) THEN TSTACCD = .;
   IF (TSTTRMT >= 81) THEN TSTTRMT = .;
   IF (WRKHIRE >= 81) THEN WRKHIRE = .;
   IF (WRKRAND >= 81) THEN WRKRAND = .;
   IF (WRKSUSP >= 81) THEN WRKSUSP = .;
   IF (WRKACCD >= 81) THEN WRKACCD = .;
   IF (PAYMO >= 81) THEN PAYMO = .;
   IF (PAYYR >= 981) THEN PAYYR = .;
   IF (SKPWKST2 >= 81) THEN SKPWKST2 = .;
   IF (WORKDAYS >= 81) THEN WORKDAYS = .;
   IF (WORKBLAH >= 81) THEN WORKBLAH = .;
   IF (SKPPREG = 9) THEN SKPPREG = .;
   IF (PREGNANT >= 81) THEN PREGNANT = .;
   IF (PREGMOS >= 81) THEN PREGMOS = .;
   IF (SKPCWE = 9) THEN SKPCWE = .;
   IF (CWE >= 81) THEN CWE = .;
   IF (CWESC1 >= 981) THEN CWESC1 = .;
   IF (CWESC2 >= 981) THEN CWESC2 = .;
   IF (FULLPART >= 81) THEN FULLPART = .;
   IF (TOTPEOP >= 81) THEN TOTPEOP = .;
   IF (RLGSVCFQ >= 81) THEN RLGSVCFQ = .;
   IF (RLGIMPRT >= 81) THEN RLGIMPRT = .;
   IF (RLGDECSN >= 81) THEN RLGDECSN = .;
   IF (RLGFRNDS >= 81) THEN RLGFRNDS = .;
   IF (SKPMHC = 9) THEN SKPMHC = .;
   IF (DEPRESS >= 81) THEN DEPRESS = .;
   IF (DEPDAYS >= 81) THEN DEPDAYS = .;
   IF (DEPFREQ >= 81) THEN DEPFREQ = .;
   IF (LOSTINT1 >= 81) THEN LOSTINT1 = .;
   IF (TIRED1 >= 81) THEN TIRED1 = .;
   IF (WTCHNG1 >= 81) THEN WTCHNG1 = .;
   IF (LBSCHNG1 >= 981) THEN LBSCHNG1 = .;
   IF (SLPLOSS1 >= 81) THEN SLPLOSS1 = .;
   IF (SLPFREQ1 >= 81) THEN SLPFREQ1 = .;
   IF (CONCEN1 >= 81) THEN CONCEN1 = .;
   IF (DOWN1 >= 81) THEN DOWN1 = .;
   IF (IDEAT1 >= 81) THEN IDEAT1 = .;
   IF (SKPDEP1 >= 81) THEN SKPDEP1 = .;
   IF (DEPWKS1 >= 81) THEN DEPWKS1 = .;
   IF (DEPMO1 >= 81) THEN DEPMO1 = .;
   IF (DEPYR1 >= 981) THEN DEPYR1 = .;
   IF (LOSTINT2 >= 81) THEN LOSTINT2 = .;
   IF (LOSINDAY >= 81) THEN LOSINDAY = .;
   IF (LOSINFRQ >= 81) THEN LOSINFRQ = .;
   IF (TIRED2 >= 81) THEN TIRED2 = .;
   IF (WTCHNG2 >= 81) THEN WTCHNG2 = .;
   IF (LBSCHNG2 >= 981) THEN LBSCHNG2 = .;
   IF (SLPLOSS2 >= 81) THEN SLPLOSS2 = .;
   IF (SLPFREQ2 >= 81) THEN SLPFREQ2 = .;
   IF (CONCEN2 >= 81) THEN CONCEN2 = .;
   IF (DOWN2 >= 81) THEN DOWN2 = .;
   IF (IDEAT2 >= 81) THEN IDEAT2 = .;
   IF (SKPDEP2 >= 81) THEN SKPDEP2 = .;
   IF (DEPWKS2 >= 81) THEN DEPWKS2 = .;
   IF (DEPMO2 >= 81) THEN DEPMO2 = .;
   IF (DEPYR2 >= 981) THEN DEPYR2 = .;
   IF (WORRIED >= 81) THEN WORRIED = .;
   IF (WOREND >= 81) THEN WOREND = .;
   IF (WORNOMO1 >= 9981) THEN WORNOMO1 = .;
   IF (WORHAPN1 >= 81) THEN WORHAPN1 = .;
   IF (WORSERI1 >= 81) THEN WORSERI1 = .;
   IF (WORDIFF1 >= 81) THEN WORDIFF1 = .;
   IF (WORNOMO2 >= 9981) THEN WORNOMO2 = .;
   IF (WORHAPN2 >= 81) THEN WORHAPN2 = .;
   IF (WORSERI2 >= 81) THEN WORSERI2 = .;
   IF (WORDIFF2 >= 81) THEN WORDIFF2 = .;
   IF (SKPWOR >= 81) THEN SKPWOR = .;
   IF (WORREST >= 81) THEN WORREST = .;
   IF (WOREDGE >= 81) THEN WOREDGE = .;
   IF (WORIRRIT >= 81) THEN WORIRRIT = .;
   IF (WORHEART >= 81) THEN WORHEART = .;
   IF (WORTIRED >= 81) THEN WORTIRED = .;
   IF (WORSLEEP >= 81) THEN WORSLEEP = .;
   IF (WORFAINT >= 81) THEN WORFAINT = .;
   IF (FEARPUB >= 81) THEN FEARPUB = .;
   IF (FEAROUT >= 81) THEN FEAROUT = .;
   IF (FEARBRDG >= 81) THEN FEARBRDG = .;
   IF (SKPFEAR1 >= 81) THEN SKPFEAR1 = .;
   IF (FEAROFT >= 81) THEN FEAROFT = .;
   IF (FEARYRS >= 81) THEN FEARYRS = .;
   IF (FEARMOS >= 81) THEN FEARMOS = .;
   IF (FEARFANT >= 81) THEN FEARFANT = .;
   IF (FEARTRAP >= 81) THEN FEARTRAP = .;
   IF (FEARHELP >= 81) THEN FEARHELP = .;
   IF (PANIC1 >= 81) THEN PANIC1 = .;
   IF (PANIC2 >= 81) THEN PANIC2 = .;
   IF (PANICNUM >= 981) THEN PANICNUM = .;
   IF (PANICMO >= 81) THEN PANICMO = .;
   IF (PANICYR >= 981) THEN PANICYR = .;
   IF (PANIDANG >= 81) THEN PANIDANG = .;
   IF (SKPFEAR2 >= 81) THEN SKPFEAR2 = .;
   IF (PANIFEAR >= 81) THEN PANIFEAR = .;
   IF (PANINOFR >= 81) THEN PANINOFR = .;
   IF (PANIHART >= 81) THEN PANIHART = .;
   IF (PANIPAIN >= 81) THEN PANIPAIN = .;
   IF (PANISWET >= 81) THEN PANISWET = .;
   IF (PANISHAK >= 81) THEN PANISHAK = .;
   IF (PANIHOT >= 81) THEN PANIHOT = .;
   IF (PANIUNRL >= 81) THEN PANIUNRL = .;
   IF (NUERTMT >= 81) THEN NUERTMT = .;
   IF (NUHSPOV >= 81) THEN NUHSPOV = .;
   IF (NUHSPPE >= 81) THEN NUHSPPE = .;
   IF (OUTPTPE >= 81) THEN OUTPTPE = .;
   IF (PROXABLE >= 81) THEN PROXABLE = .;
   IF (PROXYREL >= 981) THEN PROXYREL = .;
   IF (PROXHOME >= 81) THEN PROXHOME = .;
   IF (PROXJOIN >= 81) THEN PROXJOIN = .;
   IF (CAREUSU >= 81) THEN CAREUSU = .;
   IF (NCARERSN >= 81) THEN NCARERSN = .;
   IF (NCRRSNSP >= 81) THEN NCRRSNSP = .;
   IF (NCRRSNSC >= 81) THEN NCRRSNSC = .;
   IF (CAREOFT >= 81) THEN CAREOFT = .;
   IF (PYRCARE >= 81) THEN PYRCARE = .;
   IF (PYRCRTYP >= 81) THEN PYRCRTYP = .;
   IF (PYRCRTSP >= 81) THEN PYRCRTSP = .;
   IF (PYRCRTSC >= 81) THEN PYRCRTSC = .;
   IF (CARENOW >= 81) THEN CARENOW = .;
   IF (MNRSNNCR >= 81) THEN MNRSNNCR = .;
   IF (MNRSNNSP >= 81) THEN MNRSNNSP = .;
   IF (MNRSNNSC >= 81) THEN MNRSNNSC = .;
   IF (UCARETYP >= 81) THEN UCARETYP = .;
   IF (UCRTYPSP >= 81) THEN UCRTYPSP = .;
   IF (UCRTYPSC >= 81) THEN UCRTYPSC = .;
   IF (MEDICARE >= 81) THEN MEDICARE = .;
   IF (MEDICAID >= 81) THEN MEDICAID = .;
   IF (CHAMPUS >= 81) THEN CHAMPUS = .;
   IF (PRVHLTIN >= 81) THEN PRVHLTIN = .;
   IF (GRPHLTIN >= 81) THEN GRPHLTIN = .;
   IF (PDHINPRM >= 81) THEN PDHINPRM = .;
   IF (HLTINALC >= 81) THEN HLTINALC = .;
   IF (HLTINDRG >= 81) THEN HLTINDRG = .;
   IF (HLTINMNT >= 81) THEN HLTINMNT = .;
   IF (SOC1 >= 81) THEN SOC1 = .;
   IF (SOC2 >= 81) THEN SOC2 = .;
   IF (SSI1 >= 81) THEN SSI1 = .;
   IF (SSI2 >= 81) THEN SSI2 = .;
   IF (PUB1 >= 81) THEN PUB1 = .;
   IF (PUB2 >= 81) THEN PUB2 = .;
   IF (AFDC >= 81) THEN AFDC = .;
   IF (INT1 >= 81) THEN INT1 = .;
   IF (INT2 >= 81) THEN INT2 = .;
   IF (CHD1 >= 81) THEN CHD1 = .;
   IF (CHD2 >= 81) THEN CHD2 = .;
   IF (OTH1 >= 81) THEN OTH1 = .;
   IF (OTH2 >= 81) THEN OTH2 = .;
   IF (FSTAMP >= 81) THEN FSTAMP = .;
   IF (PINC1 >= 81) THEN PINC1 = .;
   IF (PINC2 >= 81) THEN PINC2 = .;
   IF (SKPTFMIN >= 81) THEN SKPTFMIN = .;
   IF (FINC1 >= 81) THEN FINC1 = .;
   IF (FINC2 >= 81) THEN FINC2 = .;
   IF (TELNO >= 81) THEN TELNO = .;
   IF (IRPINSUR = 9) THEN IRPINSUR = .;
   IF (IIPINSUR = 9) THEN IIPINSUR = .;
   IF (IRINSUR = 9) THEN IRINSUR = .;
   IF (IIINSUR = 9) THEN IIINSUR = .;
   IF (IRSOC1 = 9) THEN IRSOC1 = .;
   IF (IISOC1 = 9) THEN IISOC1 = .;
   IF (IRSSI1 = 9) THEN IRSSI1 = .;
   IF (IISSI1 = 9) THEN IISSI1 = .;
   IF (IRPUB1 = 9) THEN IRPUB1 = .;
   IF (IIPUB1 = 9) THEN IIPUB1 = .;
   IF (IRAFDC >= 81) THEN IRAFDC = .;
   IF (IIAFDC = 9) THEN IIAFDC = .;
   IF (IRINT1 = 9) THEN IRINT1 = .;
   IF (IIINT1 = 9) THEN IIINT1 = .;
   IF (IRCHD1 = 9) THEN IRCHD1 = .;
   IF (IICHD1 = 9) THEN IICHD1 = .;
   IF (IROTH1 = 9) THEN IROTH1 = .;
   IF (IIOTH1 = 9) THEN IIOTH1 = .;
   IF (IRFSTAMP = 9) THEN IRFSTAMP = .;
   IF (IIFSTAMP = 9) THEN IIFSTAMP = .;
   IF (IRPINC1 = 9) THEN IRPINC1 = .;
   IF (IIPINC1 = 9) THEN IIPINC1 = .;
   IF (IRFINC1 >= 81) THEN IRFINC1 = .;
   IF (IIFINC1 = 9) THEN IIFINC1 = .;
   IF (IRSOC2 = 9) THEN IRSOC2 = .;
   IF (IISOC2 = 9) THEN IISOC2 = .;
   IF (IRSSI2 = 9) THEN IRSSI2 = .;
   IF (IISSI2 = 9) THEN IISSI2 = .;
   IF (IRPUB2 = 9) THEN IRPUB2 = .;
   IF (IIPUB2 = 9) THEN IIPUB2 = .;
   IF (IRINT2 = 9) THEN IRINT2 = .;
   IF (IIINT2 = 9) THEN IIINT2 = .;
   IF (IRCHD2 = 9) THEN IRCHD2 = .;
   IF (IICHD2 = 9) THEN IICHD2 = .;
   IF (IROTH2 = 9) THEN IROTH2 = .;
   IF (IIOTH2 = 9) THEN IIOTH2 = .;
   IF (IRPINC2 >= 81) THEN IRPINC2 = .;
   IF (IIPINC2 = 9) THEN IIPINC2 = .;
   IF (IRFINC2 >= 81) THEN IRFINC2 = .;
   IF (IIFINC2 = 9) THEN IIFINC2 = .;
   IF (IRPEOP >= 81) THEN IRPEOP = .;
   IF (EDIRKIDS >= 81) THEN EDIRKIDS = .;
   IF (IRKIDS = 9) THEN IRKIDS = .;
   IF (PARSTAT = 9) THEN PARSTAT = .;
   IF (FEMBABY = 9) THEN FEMBABY = .;
   IF (FEMKIDS = 9) THEN FEMKIDS = .;
   IF (MALEBABY = 9) THEN MALEBABY = .;
   IF (MALEKIDS = 9) THEN MALEKIDS = .;
   IF (F15_44 = 9) THEN F15_44 = .;
   IF (M15_44 = 9) THEN M15_44 = .;
   IF (RELINTHH >= 81) THEN RELINTHH = .;
   IF (PREG = 9) THEN PREG = .;
   IF (PREG2 >= 81) THEN PREG2 = .;
   IF (TRIMEST >= 81) THEN TRIMEST = .;
   IF (INDCAT >= 81) THEN INDCAT = .;
   IF (PERINC = 9) THEN PERINC = .;
   IF (PERINC2 = 9) THEN PERINC2 = .;
   IF (PERINC3 = 9) THEN PERINC3 = .;
   IF (TOTCAT >= 81) THEN TOTCAT = .;
   IF (FAMINC = 9) THEN FAMINC = .;
   IF (FAMINC2 = 9) THEN FAMINC2 = .;
   IF (FAMINC3 = 9) THEN FAMINC3 = .;
   IF (WELFARE = 9) THEN WELFARE = .;
   IF (NEEDLREC >= 81) THEN NEEDLREC = .;
   IF (NEDFLAG4 = 9) THEN NEDFLAG4 = .;
   IF (NEDYR4 = 9) THEN NEDYR4 = .;
   IF (HERSMOK2 = 9) THEN HERSMOK2 = .;
   IF (HERSNIF2 = 9) THEN HERSNIF2 = .;
   IF (CIGARMON >= 81) THEN CIGARMON = .;
   IF (IRCGRLF = 9) THEN IRCGRLF = .;
   IF (IRCGRMN = 9) THEN IRCGRMN = .;
   IF (IICGRLF = 9) THEN IICGRLF = .;
   IF (IICGRMN = 9) THEN IICGRMN = .;
   IF (CGRFLAG = 9) THEN CGRFLAG = .;
   IF (CGRMON = 9) THEN CGRMON = .;
   IF (MJFORMER = 9) THEN MJFORMER = .;
   IF (MJNEVER = 9) THEN MJNEVER = .;
   IF (CCFORMER = 9) THEN CCFORMER = .;
   IF (CCNEVER = 9) THEN CCNEVER = .;
   IF (MDESFS1 >= 81) THEN MDESFS1 = .;
   IF (MDESFS3 >= 81) THEN MDESFS3 = .;
   IF (PROBMDE1 = 99.0000) THEN PROBMDE1 = .;
   IF (PROBMDE3 = 99.0000) THEN PROBMDE3 = .;
   IF (MDE1 >= 81) THEN MDE1 = .;
   IF (MDE3 >= 81) THEN MDE3 = .;
   IF (GADSFS1 >= 81) THEN GADSFS1 = .;
   IF (GADSFS3 >= 81) THEN GADSFS3 = .;
   IF (PROBGAD1 = 99.0000) THEN PROBGAD1 = .;
   IF (PROBGAD3 = 99.0000) THEN PROBGAD3 = .;
   IF (GAD1 >= 81) THEN GAD1 = .;
   IF (GAD3 >= 81) THEN GAD3 = .;
   IF (AGPSFS1 >= 81) THEN AGPSFS1 = .;
   IF (AGPSFS3 >= 81) THEN AGPSFS3 = .;
   IF (PROBAGP1 >= 81) THEN PROBAGP1 = .;
   IF (PROBAGP3 >= 81) THEN PROBAGP3 = .;
   IF (AGP1 >= 81) THEN AGP1 = .;
   IF (AGP3 >= 81) THEN AGP3 = .;
   IF (PASFS1 >= 81) THEN PASFS1 = .;
   IF (PASFS3 >= 81) THEN PASFS3 = .;
   IF (PROBPA1 = 99.0000) THEN PROBPA1 = .;
   IF (PROBPA3 = 99.0000) THEN PROBPA3 = .;
   IF (PA1 >= 81) THEN PA1 = .;
   IF (PA3 >= 81) THEN PA3 = .;
   IF (EIIDATE = 9) THEN EIIDATE = .;
   IF (BHOUR >= 81) THEN BHOUR = .;
   IF (BMIN >= 81) THEN BMIN = .;
   IF (BAP >= 81) THEN BAP = .;
   IF (ETIMEHR >= 81) THEN ETIMEHR = .;
   IF (ETIMEMN >= 81) THEN ETIMEMN = .;
   IF (EAP >= 81) THEN EAP = .;
   IF (LANGVER = 9) THEN LANGVER = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (PPRES >= 81) THEN PPRES = .;
   IF (SPRES >= 81) THEN SPRES = .;
   IF (PARPRES >= 81) THEN PARPRES = .;
   IF (OARPRES >= 81) THEN OARPRES = .;
   IF (OAPRES >= 81) THEN OAPRES = .;
   IF (CPRES >= 81) THEN CPRES = .;
   IF (OPRESNSP >= 81) THEN OPRESNSP = .;
   IF (OPRESSPA >= 981) THEN OPRESSPA = .;
   IF (OPRESSPB >= 981) THEN OPRESSPB = .;
   IF (WHOMARKD >= 81) THEN WHOMARKD = .;
   IF (QUARTER = 9) THEN QUARTER = .;
   IF (FAMSKIP = 9) THEN FAMSKIP = .;
   IF (GQTYPE = 9) THEN GQTYPE = .;
   IF (PDEN = 9) THEN PDEN = .;
   IF (PDEN2 = 9) THEN PDEN2 = .;
   IF (REGION = 9) THEN REGION = .;
   IF (DIVISION = 9) THEN DIVISION = .;
   IF (HSPHCONC = 9) THEN HSPHCONC = .;
   IF (HSPPCONC = 9) THEN HSPPCONC = .;
   IF (NHBHCONC = 9) THEN NHBHCONC = .;
   IF (NHBPCONC = 9) THEN NHBPCONC = .;
   IF (OWNOCONC = 9) THEN OWNOCONC = .;
   IF (RURORURB = 9) THEN RURORURB = .;
   IF (ALCDAYS2 = 9) THEN ALCDAYS2 = .;
   IF (ALCDAYS3 = 9) THEN ALCDAYS3 = .;
   IF (ALCILLL = 9) THEN ALCILLL = .;
   IF (ALCILLM = 9) THEN ALCILLM = .;
   IF (ALCILLY = 9) THEN ALCILLY = .;
   IF (ALCMRJL = 9) THEN ALCMRJL = .;
   IF (ALCMRJM = 9) THEN ALCMRJM = .;
   IF (ALCMRJY = 9) THEN ALCMRJY = .;
   IF (ALCONLYL = 9) THEN ALCONLYL = .;
   IF (ALCONLYM = 9) THEN ALCONLYM = .;
   IF (ALCONLYY = 9) THEN ALCONLYY = .;
   IF (ALCOTHL = 9) THEN ALCOTHL = .;
   IF (ALCOTHM = 9) THEN ALCOTHM = .;
   IF (ALCOTHY = 9) THEN ALCOTHY = .;
   IF (ALCPRBS3 = 9) THEN ALCPRBS3 = .;
   IF (ALC2PRB3 = 9) THEN ALC2PRB3 = .;
   IF (ALC3PRB3 = 9) THEN ALC3PRB3 = .;
   IF (ALCPSYL = 9) THEN ALCPSYL = .;
   IF (ALCPSYM = 9) THEN ALCPSYM = .;
   IF (ALCPSYY = 9) THEN ALCPSYY = .;
   IF (ALCTRY2 >= 81) THEN ALCTRY2 = .;
   IF (ALCUSE = 9) THEN ALCUSE = .;
   IF (ANALAGE2 >= 81) THEN ANALAGE2 = .;
   IF (ANY4MENT >= 81) THEN ANY4MENT = .;
   IF (AVCIG2 = 9) THEN AVCIG2 = .;
   IF (AVCIG3 = 9) THEN AVCIG3 = .;
   IF (BINGDRK2 = 9) THEN BINGDRK2 = .;
   IF (BKAGASL2 = 9) THEN BKAGASL2 = .;
   IF (BKARSON2 = 9) THEN BKARSON2 = .;
   IF (BKBURGL2 = 9) THEN BKBURGL2 = .;
   IF (BKDRUG2 = 9) THEN BKDRUG2 = .;
   IF (BKDRUNK2 = 9) THEN BKDRUNK2 = .;
   IF (BKDRVIN2 = 9) THEN BKDRVIN2 = .;
   IF (BKLARCN2 = 9) THEN BKLARCN2 = .;
   IF (BKMVTHF2 = 9) THEN BKMVTHF2 = .;
   IF (BKROB2 = 9) THEN BKROB2 = .;
   IF (BKSMASL2 = 9) THEN BKSMASL2 = .;
   IF (CIGPRBS3 = 9) THEN CIGPRBS3 = .;
   IF (CIG2PRB3 = 9) THEN CIG2PRB3 = .;
   IF (CIG3PRB3 = 9) THEN CIG3PRB3 = .;
   IF (CIGTRY2 >= 81) THEN CIGTRY2 = .;
   IF (COCAGE2 >= 81) THEN COCAGE2 = .;
   IF (COCPRBS3 = 9) THEN COCPRBS3 = .;
   IF (COC2PRB3 = 9) THEN COC2PRB3 = .;
   IF (COC3PRB3 = 9) THEN COC3PRB3 = .;
   IF (COCTOT3 >= 81) THEN COCTOT3 = .;
   IF (COCUSE = 9) THEN COCUSE = .;
   IF (DRALHLP3 >= 81) THEN DRALHLP3 = .;
   IF (DRINKER2 = 9) THEN DRINKER2 = .;
   IF (DRNKHLP3 >= 81) THEN DRNKHLP3 = .;
   IF (DRUNKYR2 = 9) THEN DRUNKYR2 = .;
   IF (DRUNKYR3 >= 81) THEN DRUNKYR3 = .;
   IF (DUI = 9) THEN DUI = .;
   IF (FERTAGE >= 81) THEN FERTAGE = .;
   IF (HALLAGE2 >= 81) THEN HALLAGE2 = .;
   IF (HERAGE2 >= 81) THEN HERAGE2 = .;
   IF (HERNEED2 = 9) THEN HERNEED2 = .;
   IF (HVYDRK3 = 9) THEN HVYDRK3 = .;
   IF (ILLONLYL = 9) THEN ILLONLYL = .;
   IF (ILLONLYM = 9) THEN ILLONLYM = .;
   IF (ILLONLYY = 9) THEN ILLONLYY = .;
   IF (INHAGE2 >= 81) THEN INHAGE2 = .;
   IF (IRACALC3 = 9) THEN IRACALC3 = .;
   IF (IRACCIG3 = 9) THEN IRACCIG3 = .;
   IF (IRACCOC3 = 9) THEN IRACCOC3 = .;
   IF (IRACMRJ3 = 9) THEN IRACMRJ3 = .;
   IF (IRBTALC3 = 9) THEN IRBTALC3 = .;
   IF (IRBTCIG3 = 9) THEN IRBTCIG3 = .;
   IF (IRBTCOC3 = 9) THEN IRBTCOC3 = .;
   IF (IRBTMRJ3 = 9) THEN IRBTMRJ3 = .;
   IF (IREMALC3 = 9) THEN IREMALC3 = .;
   IF (IREMCIG3 = 9) THEN IREMCIG3 = .;
   IF (IREMCOC3 = 9) THEN IREMCOC3 = .;
   IF (IREMMRJ3 = 9) THEN IREMMRJ3 = .;
   IF (IRGRALC3 = 9) THEN IRGRALC3 = .;
   IF (IRGRCIG3 = 9) THEN IRGRCIG3 = .;
   IF (IRGRCOC3 = 9) THEN IRGRCOC3 = .;
   IF (IRGRMRJ3 = 9) THEN IRGRMRJ3 = .;
   IF (IRHLALC3 = 9) THEN IRHLALC3 = .;
   IF (IRHLCIG3 = 9) THEN IRHLCIG3 = .;
   IF (IRHLCOC3 = 9) THEN IRHLCOC3 = .;
   IF (IRHLMRJ3 = 9) THEN IRHLMRJ3 = .;
   IF (IRLAALC3 = 9) THEN IRLAALC3 = .;
   IF (IRLACIG3 = 9) THEN IRLACIG3 = .;
   IF (IRLACOC3 = 9) THEN IRLACOC3 = .;
   IF (IRLAMRJ3 = 9) THEN IRLAMRJ3 = .;
   IF (IRUCALC3 = 9) THEN IRUCALC3 = .;
   IF (IRUCCIG3 = 9) THEN IRUCCIG3 = .;
   IF (IRUCCOC3 = 9) THEN IRUCCOC3 = .;
   IF (IRUCMRJ3 = 9) THEN IRUCMRJ3 = .;
   IF (MARUSE = 9) THEN MARUSE = .;
   IF (MJAGE2 >= 81) THEN MJAGE2 = .;
   IF (MRJPRBS3 = 9) THEN MRJPRBS3 = .;
   IF (MRJ2PRB3 = 9) THEN MRJ2PRB3 = .;
   IF (MRJ3PRB3 = 9) THEN MRJ3PRB3 = .;
   IF (MJTOT3 >= 81) THEN MJTOT3 = .;
   IF (MRJONLYL = 9) THEN MRJONLYL = .;
   IF (MRJONLYM = 9) THEN MRJONLYM = .;
   IF (MRJONLYY = 9) THEN MRJONLYY = .;
   IF (NOTMARJ = 9) THEN NOTMARJ = .;
   IF (OTHONLYL = 9) THEN OTHONLYL = .;
   IF (OTHONLYM = 9) THEN OTHONLYM = .;
   IF (OTHONLYY = 9) THEN OTHONLYY = .;
   IF (PREG3 >= 81) THEN PREG3 = .;
   IF (PSYAGE >= 81) THEN PSYAGE = .;
   IF (PSYONLYL = 9) THEN PSYONLYL = .;
   IF (PSYONLYM = 9) THEN PSYONLYM = .;
   IF (PSYONLYY = 9) THEN PSYONLYY = .;
   IF (RACESEX >= 81) THEN RACESEX = .;
   IF (RACESEX2 = 9) THEN RACESEX2 = .;
   IF (RDIFCOC >= 81) THEN RDIFCOC = .;
   IF (RDIFCRK >= 81) THEN RDIFCRK = .;
   IF (RDIFHER >= 81) THEN RDIFHER = .;
   IF (RDIFLSD >= 81) THEN RDIFLSD = .;
   IF (RDIFMJ >= 81) THEN RDIFMJ = .;
   IF (RSKALC1 >= 81) THEN RSKALC1 = .;
   IF (RSKALC2 >= 81) THEN RSKALC2 = .;
   IF (RSKCIG >= 81) THEN RSKCIG = .;
   IF (RSKCOC1 >= 81) THEN RSKCOC1 = .;
   IF (RSKCOC2 >= 81) THEN RSKCOC2 = .;
   IF (RSKHER1 >= 81) THEN RSKHER1 = .;
   IF (RSKHER2 >= 81) THEN RSKHER2 = .;
   IF (RSKLSD1 >= 81) THEN RSKLSD1 = .;
   IF (RSKMJ1 >= 81) THEN RSKMJ1 = .;
   IF (RSKMJ2 >= 81) THEN RSKMJ2 = .;
   IF (RSKSELL2 = 9) THEN RSKSELL2 = .;
   IF (SBELTRSK = 9) THEN SBELTRSK = .;
   IF (SEDAGE2 >= 81) THEN SEDAGE2 = .;
   IF (STIMAGE2 >= 81) THEN STIMAGE2 = .;
   IF (SUB1LIF = 9) THEN SUB1LIF = .;
   IF (SUB1MON = 9) THEN SUB1MON = .;
   IF (SUB1YR = 9) THEN SUB1YR = .;
   IF (SUB2LIF = 9) THEN SUB2LIF = .;
   IF (SUB2MON = 9) THEN SUB2MON = .;
   IF (SUB2YR = 9) THEN SUB2YR = .;
   IF (SUB3LIF = 9) THEN SUB3LIF = .;
   IF (SUB3MON = 9) THEN SUB3MON = .;
   IF (SUB3YR = 9) THEN SUB3YR = .;
   IF (TRANAGE2 >= 81) THEN TRANAGE2 = .;
   IF (TRIMEST2 >= 81) THEN TRIMEST2 = .;
   IF (TRMTHLP3 >= 81) THEN TRMTHLP3 = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT SKPMARTL skpmartl. MARITAL marital. NOMARR nomarr.
         SKPMILT skpmilt. SERVICE service. MILSTAT milstat.
         EDUC educ. DIPLOMA diploma. ENROLL97 enroll9f.
         ENRL9497 enrl949f. WORKSTAT workstat. HTININCH htininch.
         POUNDS pounds. HEALTH health. CIGEVER cigever.
         CIGTRY cigtry. CIGTOT cigtot. CIGREC cigrec.
         CIG30USE cig30use. AVCIG avcig. CIG30WOK cig30wok.
         CIGEVYDA cigevyda. CIGAGE cigage. CIGYRS cigyrs.
         SNUFEVER snufever. SNUFREC snufrec. SKPALCRD skpalcrd.
         ALCREAD alcread. ALCEVER alcever. ALCTRY alctry.
         ALCREC alcrec. ALCPAT alcpat. DRUNKYR drunkyr.
         ALCDAYS alcdays. NODR30A nodr30a. DR5DAY dr5day.
         MJEVER mjever. MJAGE mjage. MJTOT mjtot.
         MJREC mjrec. MJYRFREQ mjyrfreq. MJDAY30A mjday30a.
         SKPCOCRD skpcocrd. COCREAD cocread. COCEVER cocever.
         COCAGE cocage. COCTOT coctot. COCREC cocrec.
         COCYRFRQ cocyrfrq. COCUS30A cocus30a. SKPCRKRD skpcrkrd.
         CRKREAD crkread. CRKEVER crkever. CRKAGE crkage.
         CRKTOT crktot. CRAKREC crakrec. CRKYRFRQ crkyrfrq.
         CRKUS30A crkus30a. SKPHERRD skpherrd. HERREAD herread.
         HEREVER herever. HERAGE herage. HERTOT hertot.
         HERREC herrec. HERYRFRQ heryrfrq. HER30USE her30use.
         SKPHALRD skphalrd. HALREAD halread. LSD lsd.
         PCP pcp. PEYOTE peyote. MESC mesc.
         PSILCY psilcy. ECSTASY ecstasy. HALDKNAM haldknam.
         HALNOLST halnolst. HALNEWA halnewa. HALNEWB halnewb.
         HALNEWC halnewc. HALNEWD halnewd. HALNEWE halnewe.
         HALLAGE hallage. HALLTOT halltot. HALLREC hallrec.
         HALYRFRQ halyrfrq. HAL30USE hal30use. LSDREC lsdrec.
         PCPREC pcprec. SKPINHRD skpinhrd. INHREAD inhread.
         AMYLNIT amylnit. CLEFLU cleflu. GAS gas.
         GLUE glue. ETHER ether. SOLVENT solvent.
         LGAS lgas. NITOXID nitoxid. SPPAINT sppaint.
         AEROS aeros. INHDKNAM inhdknam. INHNOLST inhnolst.
         INHNEWA inhnewa. INHNEWB inhnewb. INHNEWC inhnewc.
         INHNEWD inhnewd. INHNEWE inhnewe. INHAGE inhage.
         INHTOT inhtot. INHREC inhrec. INHYRFRQ inhyrfrq.
         INHDY30A inhdy30a. SKPANLRD skpanlrd. ANLREAD anlread.
         CODEINE codeine. DARVON darvon. DEMEROL demerol.
         DILAUD dilaud. METHDON methdon. MORPHINE morphine.
         PERCODAN percodan. TALWIN talwin. TYLCOD tylcod.
         ANLDKNAM anldknam. ANLNOLST anlnolst. ANALNEWA analnewa.
         ANALNEWB analnewb. ANALNEWC analnewc. ANALNEWD analnewd.
         ANALNEWE analnewe. ANALNONE analnone. ANALAGE analage.
         ANALTOT analtot. ANALREC analrec. ANLYRFRQ anlyrfrq.
         SKPTRNRD skptrnrd. TRNREAD trnread. ATARAX atarax.
         ATIVAN ativan. DIAZEPAM diazepam. LIBRIUM librium.
         TRANXENE tranxene. VALIUM valium. XANAX xanax.
         TRDKNAM trdknam. TRNOLST trnolst. TRNEWA trnewa.
         TRNEWB trnewb. TRNEWC trnewc. TRNEWD trnewd.
         TRNEWE trnewe. NOTRANQ notranq. TRANAGE tranage.
         TRANTOT trantot. TRANREC tranrec. TRNYRFRQ trnyrfrq.
         SKPSTMRD skpstmrd. STMREAD stmread. BENZ benz.
         BIPHET biphet. DEXAMYL dexamyl. DEXED dexed.
         FASTIN fastin. IONAMIN ionamin. METHAMP methamp.
         METHI methi. PRELUDIN preludin. STMDKNAM stmdknam.
         STMNOLST stmnolst. STIMNEWA stimnewa. STIMNEWB stimnewb.
         STIMNEWC stimnewc. STIMNEWD stimnewd. STIMNEWE stimnewe.
         NOSTIMS nostims. STIMAGE stimage. STIMTOT stimtot.
         STIMREC stimrec. STMYRFRQ stmyrfrq. SKPSEDRD skpsedrd.
         SEDREAD sedread. DALMANE dalmane. HALCION halcion.
         METHAQ methaq. NEMBUTAL nembutal. PHENOBAR phenobar.
         PLACIDYL placidyl. SECONAL seconal. TUINAL tuinal.
         SEDDKNAM seddknam. SEDNOLST sednolst. SEDNEWA sednewa.
         SEDNEWB sednewb. SEDNEWC sednewc. SEDNEWD sednewd.
         SEDNEWE sednewe. NOSEDAT nosedat. SEDAGE sedage.
         SEDTOT sedtot. SEDREC sedrec. SEDYRFRQ sedyrfrq.
         BIRMONTH birmonth. BIRYEAR biryear. EIBDATE eibdate.
         IIAGE iiage. IRSEX irsex. IISEX iisex.
         IRRACE irrace. IIRACE iirace. IRHOIND irhoind.
         IIHOIND iihoind. IRHOGRP irhogrp. IIHOGRP iihogrp.
         IRHOGRP2 irhogrpf. IIHOGRP2 iihogrpf. IRMARIT irmarit.
         IIMARIT iimarit. IREDUC ireduc. IIEDUC iieduc.
         IRHSGRAD irhsgrad. IIHSGRAD iihsgrad. IRWORKST irworkst.
         IIWORKST iiworkst. IRCIGRC ircigrc. IICIGRC iicigrc.
         IROTBRC irotbrc. IIOTBRC iiotbrc. IRALCRC iralcrc.
         IIALCRC iialcrc. IRMJRC irmjrc. IIMJRC iimjrc.
         IRCOCRC ircocrc. IICOCRC iicocrc. IRCRKRC ircrkrc.
         IICRKRC iicrkrc. IRHERRC irherrc. IIHERRC iiherrc.
         IRHALRC irhalrc. IIHALRC iihalrc. IRLSDRC irlsdrc.
         IILSDRC iilsdrc. IRPCPRC irpcprc. IIPCPRC iipcprc.
         IRINHRC irinhrc. IIINHRC iiinhrc. IRANLRC iranlrc.
         IIANLRC iianlrc. IRTRNRC irtrnrc. IITRNRC iitrnrc.
         IRSTMRC irstmrc. IISTMRC iistmrc. IRSEDRC irsedrc.
         IISEDRC iisedrc. IRALCFQ iralcfq. IIALCFQ iialcfq.
         IRMJFQ irmjfq. IIMJFQ iimjfq. IRCOCFQ ircocfq.
         IICOCFQ iicocfq. IRCRKFQ ircrkfq. IICRKFQ iicrkfq.
         IRHERFQ irherfq. IIHERFQ iiherfq. IRHALFQ irhalfq.
         IIHALFQ iihalfq. IRINHFQ irinhfq. IIINHFQ iiinhfq.
         IRANLFQ iranlfq. IIANLFQ iianlfq. IRTRNFQ irtrnfq.
         IITRNFQ iitrnfq. IRSTMFQ irstmfq. IISTMFQ iistmfq.
         IRSEDFQ irsedfq. IISEDFQ iisedfq. CATAGE catage.
         CATAG2 catag2ff. CATAG3 catag3ff. RACE race.
         HISPRACE hisprace. EDUCCAT2 educcatf. EMPSTAT2 empstatf.
         BUSINES2 businesf. ROCCUP2 roccup2f. MARISTAT maristat.
         NOTMAR notmar. CIGFLAG cigflag. CIGYR cigyr.
         CIGMON cigmon. SMKFLAG smkflag. SMKYR smkyr.
         SMKMON smkmon. ALCFLAG alcflag. ALCYR alcyr.
         ALCMON alcmon. MRJFLAG mrjflag. MRJYR mrjyr.
         MRJMON mrjmon. COCFLAG cocflag. COCYR cocyr.
         COCMON cocmon. CRKFLAG crkflag. CRKYR crkyr.
         CRKMON crkmon. HERFLAG herflag. HERYR heryr.
         HERMON hermon. HALFLAG halflag. HALYR halyr.
         HALMON halmon. LSDFLAG lsdflag. LSDYR lsdyr.
         LSDMON lsdmon. PCPFLAG pcpflag. PCPYR pcpyr.
         PCPMON pcpmon. INHFLAG inhflag. INHYR inhyr.
         INHMON inhmon. ANLFLAG anlflag. ANLYR anlyr.
         ANLMON anlmon. TRQFLAG trqflag. TRQYR trqyr.
         TRQMON trqmon. STMFLAG stmflag. STMYR stmyr.
         STMMON stmmon. SEDFLAG sedflag. SEDYR sedyr.
         SEDMON sedmon. ALCYRF alcyrf. ALCMONF alcmonf.
         ALCWKF alcwkf. ALCOCCF alcoccf. ALCDLYF alcdlyf.
         MRJYRF mrjyrf. MRJMONF mrjmonf. MRJWKF mrjwkf.
         MRJOCCF mrjoccf. MRJDLYF mrjdlyf. COCYRF cocyrf.
         COCMONF cocmonf. COCWKF cocwkf. COCOCCF cococcf.
         COCDLYF cocdlyf. CRKYRF crkyrf. CRKMONF crkmonf.
         CRKWKF crkwkf. CRKOCCF crkoccf. CRKDLYF crkdlyf.
         HERYRF heryrf. HERMONF hermonf. HERWKF herwkf.
         HEROCCF heroccf. HERDLYF herdlyf. HALYRF halyrf.
         HALMONF halmonf. HALWKF halwkf. HALOCCF haloccf.
         HALDLYF haldlyf. INHYRF inhyrf. INHMONF inhmonf.
         INHWKF inhwkf. INHOCCF inhoccf. INHDLYF inhdlyf.
         ANLYRF anlyrf. ANLMONF anlmonf. ANLWKF anlwkf.
         ANLOCCF anloccf. ANLDLYF anldlyf. TRQYRF trqyrf.
         TRQMONF trqmonf. TRQWKF trqwkf. TRQOCCF trqoccf.
         TRQDLYF trqdlyf. STMYRF stmyrf. STMMONF stmmonf.
         STMWKF stmwkf. STMOCCF stmoccf. STMDLYF stmdlyf.
         SEDYRF sedyrf. SEDMONF sedmonf. SEDWKF sedwkf.
         SEDOCCF sedoccf. SEDDLYF seddlyf. PSYFLAG2 psyflagf.
         PSYYR2 psyyr2ff. PSYMON2 psymon2f. SUMFLAG sumflag.
         SUMYR sumyr. SUMMON summon. MJOFLAG mjoflag.
         MJOYR2 mjoyr2ff. MJOMON2 mjomon2f. IEMFLAG iemflag.
         IEMYR iemyr. IEMMON iemmon. BINGEDRK bingedrk.
         HVYDRK2 hvydrk2f. BINGEHVY bingehvy. PEYOTE2 peyote2f.
         MESC2 mesc2fff. PSILCY2 psilcy2f. ECSTASY2 ecstasyf.
         METHAMP2 methampf. AMYLNIT2 amylnitf. CLEFLU2 cleflu2f.
         GAS2 gas2ffff. GLUE2 glue2fff. ETHER2 ether2ff.
         SOLVENT2 solventf. LGAS2 lgas2fff. NITOXID2 nitoxidf.
         SPPAINT2 sppaintf. AEROS2 aeros2ff. MJDY30A3 mjdy30af.
         CG04 cg04ffff. CG12 cg12ffff. AL03 al03ffff.
         AL04 al04ffff. MJ04 mj04ffff. MJ05 mj05ffff.
         CC04 cc04ffff. CC05 cc05ffff. CK04 ck04ffff.
         CK05 ck05ffff. HE04 he04ffff. HE05 he05ffff.
         LS04 ls04ffff. LS05 ls05ffff. LS07 ls07ffff.
         LS08 ls08ffff. IN04 in04ffff. IN05 in05ffff.
         PK04 pk04ffff. PK05 pk05ffff. TR04 tr04ffff.
         TR05 tr05ffff. ST04 st04ffff. ST05 st05ffff.
         SE04 se04ffff. SE05 se05ffff. SKPSDRD skpsdrd.
         SDREAD sdread. HRANYFRM hranyfrm. HERSMOKE hersmoke.
         HRSMKREC hrsmkrec. HERSNIFF hersniff. HRSNFREC hrsnfrec.
         GNNDLLIF gnndllif. COCNEEDL cocneedl. CONDLREC condlrec.
         HERNEEDL herneedl. HRNDLREC hrndlrec. STNEEDLE stneedle.
         STNDLREC stndlrec. GNNDREUS gnndreus. GNNDLSH1 gnndlshf.
         GNNDCLEN gnndclen. GNNDLSH2 gnndls0f. GNNDGET gnndget.
         GNNDGTSP gnndgtsp. SKPRSKRD skprskrd. RSKREAD rskread.
         RSKPKCIG rskpkcig. RSKMJOCC rskmjocc. RSKMJREG rskmjreg.
         RKTRYLSD rktrylsd. RKLSDREG rklsdreg. RKTRYHER rktryher.
         RKHERREG rkherreg. RKCOCOCC rkcococc. RKCOCREG rkcocreg.
         RK5DRINK rk5drink. RSKBINGE rskbinge. RSKDIFMJ rskdifmj.
         RKDIFLSD rkdiflsd. RKDIFCOC rkdifcoc. RKDIFCRK rkdifcrk.
         RKDIFHER rkdifher. RSKSELL rsksell. RKFQDNGR rkfqdngr.
         RKFQRSKY rkfqrsky. RKFQPBLT rkfqpblt. RKFQDBLT rkfqdblt.
         SKPDRGRD skpdrgrd. DRGREAD drgread. USEDCIG usedcig.
         USEDALC usedalc. USEDMRJ usedmrj. USEDCOC usedcoc.
         USEDHER usedher. USEDHAL usedhal. USEDINH usedinh.
         USEDANL usedanl. USEDTRN usedtrn. USEDSTM usedstm.
         USEDSED usedsed. NODRUGYR nodrugyr. GRTMCIG grtmcig.
         GRTMALC grtmalc. GRTMMRJ grtmmrj. GRTMCOC grtmcoc.
         GRTMHER grtmher. GRTMHAL grtmhal. GRTMINH grtminh.
         GRTMANL grtmanl. GRTMTRN grtmtrn. GRTMSTM grtmstm.
         GRTMSED grtmsed. LAMTCIG lamtcig. LAMTALC lamtalc.
         LAMTMRJ lamtmrj. LAMTCOC lamtcoc. LAMTHER lamther.
         LAMTHAL lamthal. LAMTINH lamtinh. LAMTANL lamtanl.
         LAMTTRN lamttrn. LAMTSTM lamtstm. LAMTSED lamtsed.
         BTOLCIG btolcig. BTOLALC btolalc. BTOLMRJ btolmrj.
         BTOLCOC btolcoc. BTOLHER btolher. BTOLHAL btolhal.
         BTOLINH btolinh. BTOLANL btolanl. BTOLTRN btoltrn.
         BTOLSTM btolstm. BTOLSED btolsed. ACRDCIG acrdcig.
         ACRDALC acrdalc. ACRDMRJ acrdmrj. ACRDCOC acrdcoc.
         ACRDHER acrdher. ACRDHAL acrdhal. ACRDINH acrdinh.
         ACRDANL acrdanl. ACRDTRN acrdtrn. ACRDSTM acrdstm.
         ACRDSED acrdsed. EMPBCIG empbcig. EMPBALC empbalc.
         EMPBMRJ empbmrj. EMPBCOC empbcoc. EMPBHER empbher.
         EMPBHAL empbhal. EMPBINH empbinh. EMPBANL empbanl.
         EMPBTRN empbtrn. EMPBSTM empbstm. EMPBSED empbsed.
         HLPBCIG hlpbcig. HLPBALC hlpbalc. HLPBMRJ hlpbmrj.
         HLPBCOC hlpbcoc. HLPBHER hlpbher. HLPBHAL hlpbhal.
         HLPBINH hlpbinh. HLPBANL hlpbanl. HLPBTRN hlpbtrn.
         HLPBSTM hlpbstm. HLPBSED hlpbsed. UCDCIG ucdcig.
         UCDALC ucdalc. UCDMRJ ucdmrj. UCDCOC ucdcoc.
         UCDHER ucdher. UCDHAL ucdhal. UCDINH ucdinh.
         UCDANL ucdanl. UCDTRN ucdtrn. UCDSTM ucdstm.
         UCDSED ucdsed. SKPSPTRD skpsptrd. SPTREAD sptread.
         NDTXRCVD ndtxrcvd. NDTXNEED ndtxneed. NDTXALC ndtxalc.
         NDTXMJ ndtxmj. NDTXCOC ndtxcoc. NDTXHER ndtxher.
         NDTXHAL ndtxhal. NDTXINH ndtxinh. NDTXANL ndtxanl.
         NDTXTRAN ndtxtran. NDTXSTIM ndtxstim. NDTXSED ndtxsed.
         NDTXSOD ndtxsod. NDTXDRG1 ndtxdrgf. NDTXDRG2 ndtxdr0f.
         NDTXDRG3 ndtxdr1f. NDTXDRG4 ndtxdr2f. NDTXDRG5 ndtxdr3f.
         NDTXSTEP ndtxstep. NDTXTRSP ndtxtrsp. NDTXTFAR ndtxtfar.
         NDTXBDHR ndtxbdhr. NDTXOPEN ndtxopen. NDTXTYPE ndtxtype.
         NDTXMONY ndtxmony. NDTXHCAP ndtxhcap. NDTXTCMP ndtxtcmp.
         NDTXLANG ndtxlang. NDTXSPSV ndtxspsv. NDTXSOR ndtxsor.
         NDTXRSC1 ndtxrscf. BOOKED booked. NOBOOKYR nobookyr.
         BKLARCNY bklarcny. BKBURGL bkburgl. BKAGASLT bkagaslt.
         BKSMASLT bksmaslt. BKMVTHFT bkmvthft. BKROB bkrob.
         BKRAPE bkrape. BKMURDER bkmurder. BKARSON bkarson.
         BKDRVINF bkdrvinf. BKDRUNK bkdrunk. BKDRUG bkdrug.
         BKPROS bkpros. BKVANDAL bkvandal. BKOTH bkoth.
         BKOTHOFF bkothoff. PROBATON probaton. PAROLE parole.
         DRVALDR drvaldr. DRIVEAL driveal. DRIVEDR drivedr.
         SKPTMTRD skptmtrd. TMTREAD tmtread. TXEVER txever.
         TXSTRTLF txstrtlf. TXSTRTYR txstrtyr. TXALHOSP txalhosp.
         TXALRFIN txalrfin. TXALRFOP txalrfop. TXALMHC txalmhc.
         TXALEMRG txalemrg. TXALDOC txaldoc. TXALJAIL txaljail.
         TXALSHG txalshg. TXALSOP txalsop. TXALSP txalsp.
         TXDRHOSP txdrhosp. TXDRFIN txdrfin. TXDRFOP txdrfop.
         TXDRMHC txdrmhc. TXDREMRG txdremrg. TXDRDOC txdrdoc.
         TXDRJAIL txdrjail. TXDRSHG txdrshg. TXDRSOP txdrsop.
         TXDRSP txdrsp. TXYREMRG txyremrg. TXADGREC txadgrec.
         TXLTHOSP txlthosp. TXLTRFIN txltrfin. TXLTRFOP txltrfop.
         TXLTMHC txltmhc. TXLTEMRG txltemrg. TXLTDOC txltdoc.
         TXLTJAIL txltjail. TXLTSHG txltshg. TXLTSOP txltsop.
         TXLTSP txltsp. TXLTALC txltalc. TXLTMJ txltmj.
         TXLTCOC txltcoc. TXLTHER txlther. TXLTHAL txlthal.
         TXLTINH txltinh. TXLTANL txltanl. TXLTRAN txltran.
         TXLTSTIM txltstim. TXLTSED txltsed. TXLTSOD txltsod.
         TXLTA txlta. TXLTB txltb. TXLTC txltc.
         TXLTD txltd. TXLTE txlte. TXDRGA txdrga.
         TXDRGB txdrgb. TXDRGC txdrgc. TXDRGD txdrgd.
         TXDRGE txdrge. TXOUTC txoutc. TXTIME txtime.
         TXPDINS txpdins. TXPDCARE txpdcare. TXPDCAID txpdcaid.
         TXPDSAVE txpdsave. TXPDFMLY txpdfmly. TXPDEMPL txpdempl.
         TXPDFREE txpdfree. TXPDSOS txpdsos. TXPDSP txpdsp.
         TXENROLL txenroll. SKPWRKRD skpwrkrd. WRKREAD wrkread.
         WKEVRACC wkevracc. WKYRACC wkyracc. WKYRTEST wkyrtest.
         WK30ACC wk30acc. WK30TEST wk30test. WKYRVOL wkyrvol.
         WKYRFIRE wkyrfire. WKYRLOFF wkyrloff. WKYROTHR wkyrothr.
         WKYRSPEC wkyrspec. SKPDEXRD skpdexrd. DEXREAD dexread.
         DXVERSN dxversn. DXCGRLF dxcgrlf. DXCG50LF dxcg50lf.
         DXCG30US dxcg30us. DXMJOFFR dxmjoffr. DXMJEVER dxmjever.
         DXMJPALN dxmjpaln. DXMJPSPS dxmjpsps. DXMJPFRN dxmjpfrn.
         DXMJPMET dxmjpmet. DXMJPSIB dxmjpsib. DXMJPDAD dxmjpdad.
         DXMJPMOM dxmjpmom. DXMJPREL dxmjprel. DXMJPSOP dxmjpsop.
         DXMJPSP dxmjpsp. DXMJPNR dxmjpnr. DXMJFSEE dxmjfsee.
         DXMJFFGD dxmjffgd. DXMJFFRN dxmjffrn. DXMJFSPS dxmjfsps.
         DXMJFESC dxmjfesc. DXMJFNEW dxmjfnew. DXMJFREB dxmjfreb.
         DXMJFSOR dxmjfsor. DXMJFSP dxmjfsp. DXMJYR dxmjyr.
         DXMJYFRN dxmjyfrn. DXMJYSPS dxmjysps. DXMJYESC dxmjyesc.
         DXMJYRLX dxmjyrlx. DXMJYDRS dxmjydrs. DXMJYDRX dxmjydrx.
         DXMJYRLF dxmjyrlf. DXMJYSOR dxmjysor. DXMJYSP dxmjysp.
         DXMJRET1 dxmjretf. DXMJDNI dxmjdni. DXMJDPHY dxmjdphy.
         DXMJDSCK dxmjdsck. DXMJDBLF dxmjdblf. DXMJDTST dxmjdtst.
         DXMJDPSY dxmjdpsy. DXMJDDGS dxmjddgs. DXMJDADD dxmjdadd.
         DXMJDPRG dxmjdprg. DXMJDKID dxmjdkid. DXMJDPAR dxmjdpar.
         DXMJDSPS dxmjdsps. DXMJDFRN dxmjdfrn. DXMJDCOS dxmjdcos.
         DXMJDGET dxmjdget. DXMJDDLR dxmjddlr. DXMJDIGL dxmjdigl.
         DXMJDCRM dxmjdcrm. DXMJDSOR dxmjdsor. DXMJDSP dxmjdsp.
         DXMJRET2 dxmjre0f. DXMJNNI dxmjnni. DXMJNPHY dxmjnphy.
         DXMJNLIK dxmjnlik. DXMJNBLF dxmjnblf. DXMJNTST dxmjntst.
         DXMJNPSY dxmjnpsy. DXMJNDGS dxmjndgs. DXMJNADD dxmjnadd.
         DXMJNPRG dxmjnprg. DXMJNKID dxmjnkid. DXMJNPAR dxmjnpar.
         DXMJNSPS dxmjnsps. DXMJNFRN dxmjnfrn. DXMJNCOS dxmjncos.
         DXMJNGET dxmjnget. DXMJNDLR dxmjndlr. DXMJNIGL dxmjnigl.
         DXMJNCRM dxmjncrm. DXMJNSOR dxmjnsor. DXMJNSP dxmjnsp.
         DXCCOFFR dxccoffr. DXCCEVER dxccever. DXCCPALN dxccpaln.
         DXCCPSPS dxccpsps. DXCCPFRN dxccpfrn. DXCCPMET dxccpmet.
         DXCCPSIB dxccpsib. DXCCPDAD dxccpdad. DXCCPMOM dxccpmom.
         DXCCPREL dxccprel. DXCCPSOP dxccpsop. DXCCPSP dxccpsp.
         DXCCPNR dxccpnr. DXCCFSEE dxccfsee. DXCCFFGD dxccffgd.
         DXCCFFRN dxccffrn. DXCCFSPS dxccfsps. DXCCFESC dxccfesc.
         DXCCFNEW dxccfnew. DXCCFREB dxccfreb. DXCCFSOR dxccfsor.
         DXCCFSP dxccfsp. DXCCYR dxccyr. DXCCYFRN dxccyfrn.
         DXCCYSPS dxccysps. DXCCYESC dxccyesc. DXCCYRLX dxccyrlx.
         DXCCYDRS dxccydrs. DXCCYDRX dxccydrx. DXCCYRLF dxccyrlf.
         DXCCYSOR dxccysor. DXCCYSP dxccysp. DXCCRET1 dxccretf.
         DXCCDNI dxccdni. DXCCDPHY dxccdphy. DXCCDSCK dxccdsck.
         DXCCDBLF dxccdblf. DXCCDTST dxccdtst. DXCCDPSY dxccdpsy.
         DXCCDDGS dxccddgs. DXCCDADD dxccdadd. DXCCDPRG dxccdprg.
         DXCCDKID dxccdkid. DXCCDPAR dxccdpar. DXCCDSPS dxccdsps.
         DXCCDFRN dxccdfrn. DXCCDCOS dxccdcos. DXCCDGET dxccdget.
         DXCCDDLR dxccddlr. DXCCDIGL dxccdigl. DXCCDCRM dxccdcrm.
         DXCCDSOR dxccdsor. DXCCDSP dxccdsp. DXCCRET2 dxccre0f.
         DXCCNNI dxccnni. DXCCNPHY dxccnphy. DXCCNLIK dxccnlik.
         DXCCNBLF dxccnblf. DXCCNTST dxccntst. DXCCNPSY dxccnpsy.
         DXCCNDGS dxccndgs. DXCCNADD dxccnadd. DXCCNPRG dxccnprg.
         DXCCNKID dxccnkid. DXCCNPAR dxccnpar. DXCCNSPS dxccnsps.
         DXCCNFRN dxccnfrn. DXCCNCOS dxccncos. DXCCNGET dxccnget.
         DXCCNDLR dxccndlr. DXCCNIGL dxccnigl. DXCCNCRM dxccncrm.
         DXCCNSOR dxccnsor. DXCCNSP dxccnsp. SKPYEANS skpyeans.
         SKPYEXRD skpyexrd. YEXREAD yexread. YEENRLYR yeenrlyr.
         YEPUBSCH yepubsch. YEPRVSCH yeprvsch. YEHOMSCH yehomsch.
         YE4YRCOL ye4yrcol. YE2YRCOL ye2yrcol. YEVOCSCH yevocsch.
         YESCHOTH yeschoth. YESCHSP yeschsp. YEGRADES yegrades.
         YESCOUTS yescouts. YEPRVLES yeprvles. YETEMSPT yetemspt.
         YE4HCLUB ye4hclub. YEBAND yeband. YESCHCLB yeschclb.
         YESTGOVT yestgovt. YEVOLUNT yevolunt. YECHOIR yechoir.
         YEACTOTH yeactoth. YEACTSP yeactsp. YEJOBYR yejobyr.
         YEJOBSCD yejobscd. YEDETCHR yedetchr. YEDENTCH yedentch.
         YEDESPCL yedespcl. YEDEOTH yedeoth. YEDESP yedesp.
         YEMSGYR yemsgyr. YEPARYR yeparyr. YEPPKCIG yeppkcig.
         YEPMJEVR yepmjevr. YEPMJOCC yepmjocc. YEPMJREG yepmjreg.
         YEPINEVR yepinevr. YEPHEEVR yepheevr. YEPCCOCC yepccocc.
         YEPBINGE yepbinge. YEFPKCIG yefpkcig. YEFMJEVR yefmjevr.
         YEFMJOCC yefmjocc. YEFMJREG yefmjreg. YEFINEVR yefinevr.
         YEFHEEVR yefheevr. YEFCCOCC yefccocc. YEFBINGE yefbinge.
         YEFDPKCG yefdpkcg. YEFDMJEV yefdmjev. YEFDMJOC yefdmjoc.
         YEFDMJRG yefdmjrg. YEFDINEV yefdinev. YEFDHEEV yefdheev.
         YEFDCCOC yefdccoc. YEFDBING yefdbing. YETLKNON yetlknon.
         YETLKMOM yetlkmom. YETLKDAD yetlkdad. YETLKBGF yetlkbgf.
         YETLKSIB yetlksib. YETLKSOR yetlksor. YETLKFRN yetlkfrn.
         YETLKTCH yetlktch. YETLKCLG yetlkclg. YETLKSOP yetlksop.
         YETLKSP yetlksp. YETLKNR yetlknr. YEMOSNON yemosnon.
         YEMOSMOM yemosmom. YEMOSDAD yemosdad. YEMOSBGF yemosbgf.
         YEMOSSIB yemossib. YEMOSSOR yemossor. YEMOSFRN yemosfrn.
         YEMOSTCH yemostch. YEMOSCLG yemosclg. YEMOSSOP yemossop.
         YEMOSSP yemossp. YEMOSNR yemosnr. YESTDRES yestdres.
         YESTLATE yestlate. YESTHWRK yesthwrk. YEARGUP yeargup.
         YEGFITE yegfite. YESHPLFT yeshplft. MOVESPYR movespyr.
         EDUC2NDQ educ2ndq. STUDNT97 studnt9f. STDT9497 stdt949f.
         SKPSCHGR skpschgr. SKPSCHAG skpschag. LFTSCHRS lftschrs.
         LFTSCHAG lftschag. SCHDYS97 schdys9f. SCHD9497 schd949f.
         SKIPPD97 skippd9f. SKIP9497 skip949f. NJOBSPYR njobspyr.
         WRKSTAT2 wrkstatf. WKST2NDQ wkst2ndq. WKSWKST wkswkst.
         SKPWKST1 skpwkstf. BUSSIZE bussize. LOCSIZE locsize.
         DRGINFO drginfo. DRGPLCY drgplcy. PLCYCOV plcycov.
         DRGPRGM drgprgm. USALCTST usalctst. USDRGTST usdrgtst.
         SKPWKTST skpwktst. TSTHIRE tsthire. TSTRAND tstrand.
         TSTSUSP tstsusp. TSTACCD tstaccd. TSTTRMT tsttrmt.
         WRKHIRE wrkhire. WRKRAND wrkrand. WRKSUSP wrksusp.
         WRKACCD wrkaccd. PAYMO paymo. PAYYR payyr.
         SKPWKST2 skpwks0f. WORKDAYS workdays. WORKBLAH workblah.
         SKPPREG skppreg. PREGNANT pregnant. PREGMOS pregmos.
         SKPCWE skpcwe. CWE cwe. CWESC1 cwesc1ff.
         CWESC2 cwesc2ff. FULLPART fullpart. RLGSVCFQ rlgsvcfq.
         RLGIMPRT rlgimprt. RLGDECSN rlgdecsn. RLGFRNDS rlgfrnds.
         SKPMHC skpmhc. DEPRESS depress. DEPDAYS depdays.
         DEPFREQ depfreq. LOSTINT1 lostintf. TIRED1 tired1ff.
         WTCHNG1 wtchng1f. LBSCHNG1 lbschngf. SLPLOSS1 slplossf.
         SLPFREQ1 slpfreqf. CONCEN1 concen1f. DOWN1 down1fff.
         IDEAT1 ideat1ff. SKPDEP1 skpdep1f. DEPWKS1 depwks1f.
         DEPMO1 depmo1ff. DEPYR1 depyr1ff. LOSTINT2 lostin0f.
         LOSINDAY losinday. LOSINFRQ losinfrq. TIRED2 tired2ff.
         WTCHNG2 wtchng2f. LBSCHNG2 lbschn0f. SLPLOSS2 slplos0f.
         SLPFREQ2 slpfre0f. CONCEN2 concen2f. DOWN2 down2fff.
         IDEAT2 ideat2ff. SKPDEP2 skpdep2f. DEPWKS2 depwks2f.
         DEPMO2 depmo2ff. DEPYR2 depyr2ff. WORRIED worried.
         WOREND worend. WORNOMO1 wornomof. WORHAPN1 worhapnf.
         WORSERI1 worserif. WORDIFF1 wordifff. WORNOMO2 wornom0f.
         WORHAPN2 worhap0f. WORSERI2 worser0f. WORDIFF2 wordif0f.
         SKPWOR skpwor. WORREST worrest. WOREDGE woredge.
         WORIRRIT worirrit. WORHEART worheart. WORTIRED wortired.
         WORSLEEP worsleep. WORFAINT worfaint. FEARPUB fearpub.
         FEAROUT fearout. FEARBRDG fearbrdg. SKPFEAR1 skpfearf.
         FEAROFT fearoft. FEARYRS fearyrs. FEARMOS fearmos.
         FEARFANT fearfant. FEARTRAP feartrap. FEARHELP fearhelp.
         PANIC1 panic1ff. PANIC2 panic2ff. PANICNUM panicnum.
         PANICMO panicmo. PANICYR panicyr. PANIDANG panidang.
         SKPFEAR2 skpfea0f. PANIFEAR panifear. PANINOFR paninofr.
         PANIHART panihart. PANIPAIN panipain. PANISWET paniswet.
         PANISHAK panishak. PANIHOT panihot. PANIUNRL paniunrl.
         NUERTMT nuertmt. NUHSPOV nuhspov. NUHSPPE nuhsppe.
         OUTPTPE outptpe. PROXABLE proxable. PROXYREL proxyrel.
         PROXHOME proxhome. PROXJOIN proxjoin. CAREUSU careusu.
         NCARERSN ncarersn. NCRRSNSP ncrrsnsp. NCRRSNSC ncrrsnsc.
         CAREOFT careoft. PYRCARE pyrcare. PYRCRTYP pyrcrtyp.
         PYRCRTSP pyrcrtsp. PYRCRTSC pyrcrtsc. CARENOW carenow.
         MNRSNNCR mnrsnncr. MNRSNNSP mnrsnnsp. MNRSNNSC mnrsnnsc.
         UCARETYP ucaretyp. UCRTYPSP ucrtypsp. UCRTYPSC ucrtypsc.
         MEDICARE medicare. MEDICAID medicaid. CHAMPUS champus.
         PRVHLTIN prvhltin. GRPHLTIN grphltin. PDHINPRM pdhinprm.
         HLTINALC hltinalc. HLTINDRG hltindrg. HLTINMNT hltinmnt.
         SOC1 soc1ffff. SOC2 soc2ffff. SSI1 ssi1ffff.
         SSI2 ssi2ffff. PUB1 pub1ffff. PUB2 pub2ffff.
         AFDC afdc. INT1 int1ffff. INT2 int2ffff.
         CHD1 chd1ffff. CHD2 chd2ffff. OTH1 oth1ffff.
         OTH2 oth2ffff. FSTAMP fstamp. PINC1 pinc1fff.
         PINC2 pinc2fff. SKPTFMIN skptfmin. FINC1 finc1fff.
         FINC2 finc2fff. TELNO telno. IRPINSUR irpinsur.
         IIPINSUR iipinsur. IRINSUR irinsur. IIINSUR iiinsur.
         IRSOC1 irsoc1ff. IISOC1 iisoc1ff. IRSSI1 irssi1ff.
         IISSI1 iissi1ff. IRPUB1 irpub1ff. IIPUB1 iipub1ff.
         IRAFDC irafdc. IIAFDC iiafdc. IRINT1 irint1ff.
         IIINT1 iiint1ff. IRCHD1 irchd1ff. IICHD1 iichd1ff.
         IROTH1 iroth1ff. IIOTH1 iioth1ff. IRFSTAMP irfstamp.
         IIFSTAMP iifstamp. IRPINC1 irpinc1f. IIPINC1 iipinc1f.
         IRFINC1 irfinc1f. IIFINC1 iifinc1f. IRSOC2 irsoc2ff.
         IISOC2 iisoc2ff. IRSSI2 irssi2ff. IISSI2 iissi2ff.
         IRPUB2 irpub2ff. IIPUB2 iipub2ff. IRINT2 irint2ff.
         IIINT2 iiint2ff. IRCHD2 irchd2ff. IICHD2 iichd2ff.
         IROTH2 iroth2ff. IIOTH2 iioth2ff. IRPINC2 irpinc2f.
         IIPINC2 iipinc2f. IRFINC2 irfinc2f. IIFINC2 iifinc2f.
         EDIRKIDS edirkids. IRKIDS irkids. PARSTAT parstat.
         FEMBABY fembaby. FEMKIDS femkids. MALEBABY malebaby.
         MALEKIDS malekids. F15_44 f15_44ff. M15_44 m15_44ff.
         RELINTHH relinthh. PREG preg. PREG2 preg2fff.
         TRIMEST trimest. INDCAT indcat. PERINC perinc.
         PERINC2 perinc2f. PERINC3 perinc3f. TOTCAT totcat.
         FAMINC faminc. FAMINC2 faminc2f. FAMINC3 faminc3f.
         WELFARE welfare. NEEDLREC needlrec. NEDFLAG4 nedflagf.
         NEDYR4 nedyr4ff. HERSMOK2 hersmokf. HERSNIF2 hersni0f.
         CIGARMON cigarmon. IRCGRLF ircgrlf. IRCGRMN ircgrmn.
         IICGRLF iicgrlf. IICGRMN iicgrmn. CGRFLAG cgrflag.
         CGRMON cgrmon. MJFORMER mjformer. MJNEVER mjnever.
         CCFORMER ccformer. CCNEVER ccnever. MDESFS1 mdesfs1f.
         MDESFS3 mdesfs3f. PROBMDE1 probmdef. PROBMDE3 probmd0f.
         MDE1 mde1ffff. MDE3 mde3ffff. GADSFS1 gadsfs1f.
         GADSFS3 gadsfs3f. PROBGAD1 probgadf. PROBGAD3 probga0f.
         GAD1 gad1ffff. GAD3 gad3ffff. AGPSFS1 agpsfs1f.
         AGPSFS3 agpsfs3f. PROBAGP1 probagpf. PROBAGP3 probag0f.
         AGP1 agp1ffff. AGP3 agp3ffff. PASFS1 pasfs1ff.
         PASFS3 pasfs3ff. PROBPA1 probpa1f. PROBPA3 probpa3f.
         PA1 pa1fffff. PA3 pa3fffff. EIIDATE eiidate.
         BHOUR bhour. BMIN bmin. BAP bap.
         ETIMEHR etimehr. ETIMEMN etimemn. EAP eap.
         LANGVER langver. UNDINT undint. COOPINT coopint.
         PRIVACY privacy. PPRES ppres. SPRES spres.
         PARPRES parpres. OARPRES oarpres. OAPRES oapres.
         CPRES cpres. OPRESNSP opresnsp. OPRESSPA opresspa.
         OPRESSPB opresspb. WHOMARKD whomarkd. QUARTER quarter.
         FAMSKIP famskip. GQTYPE gqtype. PDEN pden.
         PDEN2 pden2fff. REGION region. DIVISION division.
         HSPHCONC hsphconc. HSPPCONC hsppconc. NHBHCONC nhbhconc.
         NHBPCONC nhbpconc. OWNOCONC ownoconc. RURORURB rurorurb.
         ALCDAYS2 alcdaysf. ALCDAYS3 alcday0f. ALCILLL alcilll.
         ALCILLM alcillm. ALCILLY alcilly. ALCMRJL alcmrjl.
         ALCMRJM alcmrjm. ALCMRJY alcmrjy. ALCONLYL alconlyl.
         ALCONLYM alconlym. ALCONLYY alconlyy. ALCOTHL alcothl.
         ALCOTHM alcothm. ALCOTHY alcothy. ALCPRBS3 alcprbsf.
         ALC2PRB3 alc2prbf. ALC3PRB3 alc3prbf. ALCPSYL alcpsyl.
         ALCPSYM alcpsym. ALCPSYY alcpsyy. ALCTRY2 alctry2f.
         ALCUSE alcuse. ANALAGE2 analagef. ANY4MENT any4ment.
         AVCIG2 avcig2ff. AVCIG3 avcig3ff. BINGDRK2 bingdrkf.
         BKAGASL2 bkagaslf. BKARSON2 bkarsonf. BKBURGL2 bkburglf.
         BKDRUG2 bkdrug2f. BKDRUNK2 bkdrunkf. BKDRVIN2 bkdrvi0f.
         BKLARCN2 bklarcnf. BKMVTHF2 bkmvthff. BKROB2 bkrob2ff.
         BKSMASL2 bksmaslf. CIGPRBS3 cigprbsf. CIG2PRB3 cig2prbf.
         CIG3PRB3 cig3prbf. CIGTRY2 cigtry2f. COCAGE2 cocage2f.
         COCPRBS3 cocprbsf. COC2PRB3 coc2prbf. COC3PRB3 coc3prbf.
         COCTOT3 coctot3f. COCUSE cocuse. DRALHLP3 dralhlpf.
         DRINKER2 drinkerf. DRNKHLP3 drnkhlpf. DRUNKYR2 drunkyrf.
         DRUNKYR3 drunky0f. DUI dui. FERTAGE fertage.
         HALLAGE2 hallagef. HERAGE2 herage2f. HERNEED2 herneedf.
         HVYDRK3 hvydrk3f. ILLONLYL illonlyl. ILLONLYM illonlym.
         ILLONLYY illonlyy. INHAGE2 inhage2f. IRACALC3 iracalcf.
         IRACCIG3 iraccigf. IRACCOC3 iraccocf. IRACMRJ3 iracmrjf.
         IRBTALC3 irbtalcf. IRBTCIG3 irbtcigf. IRBTCOC3 irbtcocf.
         IRBTMRJ3 irbtmrjf. IREMALC3 iremalcf. IREMCIG3 iremcigf.
         IREMCOC3 iremcocf. IREMMRJ3 iremmrjf. IRGRALC3 irgralcf.
         IRGRCIG3 irgrcigf. IRGRCOC3 irgrcocf. IRGRMRJ3 irgrmrjf.
         IRHLALC3 irhlalcf. IRHLCIG3 irhlcigf. IRHLCOC3 irhlcocf.
         IRHLMRJ3 irhlmrjf. IRLAALC3 irlaalcf. IRLACIG3 irlacigf.
         IRLACOC3 irlacocf. IRLAMRJ3 irlamrjf. IRUCALC3 irucalcf.
         IRUCCIG3 iruccigf. IRUCCOC3 iruccocf. IRUCMRJ3 irucmrjf.
         MARUSE maruse. MJAGE2 mjage2ff. MRJPRBS3 mrjprbsf.
         MRJ2PRB3 mrj2prbf. MRJ3PRB3 mrj3prbf. MJTOT3 mjtot3ff.
         MRJONLYL mrjonlyl. MRJONLYM mrjonlym. MRJONLYY mrjonlyy.
         NOTMARJ notmarj. OTHONLYL othonlyl. OTHONLYM othonlym.
         OTHONLYY othonlyy. PREG3 preg3fff. PSYAGE psyage.
         PSYONLYL psyonlyl. PSYONLYM psyonlym. PSYONLYY psyonlyy.
         RACESEX racesex. RACESEX2 racesexf. RDIFCOC rdifcoc.
         RDIFCRK rdifcrk. RDIFHER rdifher. RDIFLSD rdiflsd.
         RDIFMJ rdifmj. RSKALC1 rskalc1f. RSKALC2 rskalc2f.
         RSKCIG rskcig. RSKCOC1 rskcoc1f. RSKCOC2 rskcoc2f.
         RSKHER1 rskher1f. RSKHER2 rskher2f. RSKLSD1 rsklsd1f.
         RSKMJ1 rskmj1ff. RSKMJ2 rskmj2ff. RSKSELL2 rsksellf.
         SBELTRSK sbeltrsk. SEDAGE2 sedage2f. STIMAGE2 stimagef.
         SUB1LIF sub1lif. SUB1MON sub1mon. SUB1YR sub1yr.
         SUB2LIF sub2lif. SUB2MON sub2mon. SUB2YR sub2yr.
         SUB3LIF sub3lif. SUB3MON sub3mon. SUB3YR sub3yr.
         TRANAGE2 tranagef. TRIMEST2 trimestf. TRMTHLP3 trmthlpf.
          ;

RUN ;
